/*
 * Descriptions for errors generated from
 * [MS-ERREF] https://msdn.microsoft.com/en-us/library/cc231199.aspx
 */

#ifndef _WERR_GEN_H
#define _WERR_GEN_H
#define WERR_SUCCESS W_ERROR(0x0)
#define WERR_NERR_SUCCESS W_ERROR(0x0)
#define WERR_INVALID_FUNCTION W_ERROR(0x1)
#define WERR_FILE_NOT_FOUND W_ERROR(0x2)
#define WERR_PATH_NOT_FOUND W_ERROR(0x3)
#define WERR_TOO_MANY_OPEN_FILES W_ERROR(0x4)
#define WERR_ACCESS_DENIED W_ERROR(0x5)
#define WERR_INVALID_HANDLE W_ERROR(0x6)
#define WERR_ARENA_TRASHED W_ERROR(0x7)
#define WERR_NOT_ENOUGH_MEMORY W_ERROR(0x8)
#define WERR_INVALID_BLOCK W_ERROR(0x9)
#define WERR_BAD_ENVIRONMENT W_ERROR(0xa)
#define WERR_BAD_FORMAT W_ERROR(0xb)
#define WERR_INVALID_ACCESS W_ERROR(0xc)
#define WERR_INVALID_DATA W_ERROR(0xd)
#define WERR_OUTOFMEMORY W_ERROR(0xe)
#define WERR_INVALID_DRIVE W_ERROR(0xf)
#define WERR_CURRENT_DIRECTORY W_ERROR(0x10)
#define WERR_NOT_SAME_DEVICE W_ERROR(0x11)
#define WERR_NO_MORE_FILES W_ERROR(0x12)
#define WERR_WRITE_PROTECT W_ERROR(0x13)
#define WERR_BAD_UNIT W_ERROR(0x14)
#define WERR_NOT_READY W_ERROR(0x15)
#define WERR_BAD_COMMAND W_ERROR(0x16)
#define WERR_CRC W_ERROR(0x17)
#define WERR_BAD_LENGTH W_ERROR(0x18)
#define WERR_SEEK W_ERROR(0x19)
#define WERR_NOT_DOS_DISK W_ERROR(0x1a)
#define WERR_SECTOR_NOT_FOUND W_ERROR(0x1b)
#define WERR_OUT_OF_PAPER W_ERROR(0x1c)
#define WERR_WRITE_FAULT W_ERROR(0x1d)
#define WERR_READ_FAULT W_ERROR(0x1e)
#define WERR_GEN_FAILURE W_ERROR(0x1f)
#define WERR_SHARING_VIOLATION W_ERROR(0x20)
#define WERR_LOCK_VIOLATION W_ERROR(0x21)
#define WERR_WRONG_DISK W_ERROR(0x22)
#define WERR_SHARING_BUFFER_EXCEEDED W_ERROR(0x24)
#define WERR_HANDLE_EOF W_ERROR(0x26)
#define WERR_HANDLE_DISK_FULL W_ERROR(0x27)
#define WERR_NOT_SUPPORTED W_ERROR(0x32)
#define WERR_REM_NOT_LIST W_ERROR(0x33)
#define WERR_DUP_NAME W_ERROR(0x34)
#define WERR_BAD_NETPATH W_ERROR(0x35)
#define WERR_NETWORK_BUSY W_ERROR(0x36)
#define WERR_DEV_NOT_EXIST W_ERROR(0x37)
#define WERR_TOO_MANY_CMDS W_ERROR(0x38)
#define WERR_ADAP_HDW_ERR W_ERROR(0x39)
#define WERR_BAD_NET_RESP W_ERROR(0x3a)
#define WERR_UNEXP_NET_ERR W_ERROR(0x3b)
#define WERR_BAD_REM_ADAP W_ERROR(0x3c)
#define WERR_PRINTQ_FULL W_ERROR(0x3d)
#define WERR_NO_SPOOL_SPACE W_ERROR(0x3e)
#define WERR_PRINT_CANCELLED W_ERROR(0x3f)
#define WERR_NETNAME_DELETED W_ERROR(0x40)
#define WERR_NETWORK_ACCESS_DENIED W_ERROR(0x41)
#define WERR_BAD_DEV_TYPE W_ERROR(0x42)
#define WERR_BAD_NET_NAME W_ERROR(0x43)
#define WERR_TOO_MANY_NAMES W_ERROR(0x44)
#define WERR_TOO_MANY_SESS W_ERROR(0x45)
#define WERR_SHARING_PAUSED W_ERROR(0x46)
#define WERR_REQ_NOT_ACCEP W_ERROR(0x47)
#define WERR_REDIR_PAUSED W_ERROR(0x48)
#define WERR_FILE_EXISTS W_ERROR(0x50)
#define WERR_CANNOT_MAKE W_ERROR(0x52)
#define WERR_FAIL_I24 W_ERROR(0x53)
#define WERR_OUT_OF_STRUCTURES W_ERROR(0x54)
#define WERR_ALREADY_ASSIGNED W_ERROR(0x55)
#define WERR_INVALID_PASSWORD W_ERROR(0x56)
#define WERR_INVALID_PARAMETER W_ERROR(0x57)
#define WERR_NET_WRITE_FAULT W_ERROR(0x58)
#define WERR_NO_PROC_SLOTS W_ERROR(0x59)
#define WERR_TOO_MANY_SEMAPHORES W_ERROR(0x64)
#define WERR_EXCL_SEM_ALREADY_OWNED W_ERROR(0x65)
#define WERR_SEM_IS_SET W_ERROR(0x66)
#define WERR_TOO_MANY_SEM_REQUESTS W_ERROR(0x67)
#define WERR_INVALID_AT_INTERRUPT_TIME W_ERROR(0x68)
#define WERR_SEM_OWNER_DIED W_ERROR(0x69)
#define WERR_SEM_USER_LIMIT W_ERROR(0x6a)
#define WERR_DISK_CHANGE W_ERROR(0x6b)
#define WERR_DRIVE_LOCKED W_ERROR(0x6c)
#define WERR_BROKEN_PIPE W_ERROR(0x6d)
#define WERR_OPEN_FAILED W_ERROR(0x6e)
#define WERR_BUFFER_OVERFLOW W_ERROR(0x6f)
#define WERR_DISK_FULL W_ERROR(0x70)
#define WERR_NO_MORE_SEARCH_HANDLES W_ERROR(0x71)
#define WERR_INVALID_TARGET_HANDLE W_ERROR(0x72)
#define WERR_INVALID_CATEGORY W_ERROR(0x75)
#define WERR_INVALID_VERIFY_SWITCH W_ERROR(0x76)
#define WERR_BAD_DRIVER_LEVEL W_ERROR(0x77)
#define WERR_CALL_NOT_IMPLEMENTED W_ERROR(0x78)
#define WERR_SEM_TIMEOUT W_ERROR(0x79)
#define WERR_INSUFFICIENT_BUFFER W_ERROR(0x7a)
#define WERR_INVALID_NAME W_ERROR(0x7b)
#define WERR_INVALID_LEVEL W_ERROR(0x7c)
#define WERR_NO_VOLUME_LABEL W_ERROR(0x7d)
#define WERR_MOD_NOT_FOUND W_ERROR(0x7e)
#define WERR_PROC_NOT_FOUND W_ERROR(0x7f)
#define WERR_WAIT_NO_CHILDREN W_ERROR(0x80)
#define WERR_CHILD_NOT_COMPLETE W_ERROR(0x81)
#define WERR_DIRECT_ACCESS_HANDLE W_ERROR(0x82)
#define WERR_NEGATIVE_SEEK W_ERROR(0x83)
#define WERR_SEEK_ON_DEVICE W_ERROR(0x84)
#define WERR_IS_JOIN_TARGET W_ERROR(0x85)
#define WERR_IS_JOINED W_ERROR(0x86)
#define WERR_IS_SUBSTED W_ERROR(0x87)
#define WERR_NOT_JOINED W_ERROR(0x88)
#define WERR_NOT_SUBSTED W_ERROR(0x89)
#define WERR_JOIN_TO_JOIN W_ERROR(0x8a)
#define WERR_SUBST_TO_SUBST W_ERROR(0x8b)
#define WERR_JOIN_TO_SUBST W_ERROR(0x8c)
#define WERR_SUBST_TO_JOIN W_ERROR(0x8d)
#define WERR_BUSY_DRIVE W_ERROR(0x8e)
#define WERR_SAME_DRIVE W_ERROR(0x8f)
#define WERR_DIR_NOT_ROOT W_ERROR(0x90)
#define WERR_DIR_NOT_EMPTY W_ERROR(0x91)
#define WERR_IS_SUBST_PATH W_ERROR(0x92)
#define WERR_IS_JOIN_PATH W_ERROR(0x93)
#define WERR_PATH_BUSY W_ERROR(0x94)
#define WERR_IS_SUBST_TARGET W_ERROR(0x95)
#define WERR_SYSTEM_TRACE W_ERROR(0x96)
#define WERR_INVALID_EVENT_COUNT W_ERROR(0x97)
#define WERR_TOO_MANY_MUXWAITERS W_ERROR(0x98)
#define WERR_INVALID_LIST_FORMAT W_ERROR(0x99)
#define WERR_LABEL_TOO_LONG W_ERROR(0x9a)
#define WERR_TOO_MANY_TCBS W_ERROR(0x9b)
#define WERR_SIGNAL_REFUSED W_ERROR(0x9c)
#define WERR_DISCARDED W_ERROR(0x9d)
#define WERR_NOT_LOCKED W_ERROR(0x9e)
#define WERR_BAD_THREADID_ADDR W_ERROR(0x9f)
#define WERR_BAD_ARGUMENTS W_ERROR(0xa0)
#define WERR_BAD_PATHNAME W_ERROR(0xa1)
#define WERR_SIGNAL_PENDING W_ERROR(0xa2)
#define WERR_MAX_THRDS_REACHED W_ERROR(0xa4)
#define WERR_LOCK_FAILED W_ERROR(0xa7)
#define WERR_BUSY W_ERROR(0xaa)
#define WERR_CANCEL_VIOLATION W_ERROR(0xad)
#define WERR_ATOMIC_LOCKS_NOT_SUPPORTED W_ERROR(0xae)
#define WERR_INVALID_SEGMENT_NUMBER W_ERROR(0xb4)
#define WERR_INVALID_ORDINAL W_ERROR(0xb6)
#define WERR_ALREADY_EXISTS W_ERROR(0xb7)
#define WERR_INVALID_FLAG_NUMBER W_ERROR(0xba)
#define WERR_SEM_NOT_FOUND W_ERROR(0xbb)
#define WERR_INVALID_STARTING_CODESEG W_ERROR(0xbc)
#define WERR_INVALID_STACKSEG W_ERROR(0xbd)
#define WERR_INVALID_MODULETYPE W_ERROR(0xbe)
#define WERR_INVALID_EXE_SIGNATURE W_ERROR(0xbf)
#define WERR_EXE_MARKED_INVALID W_ERROR(0xc0)
#define WERR_BAD_EXE_FORMAT W_ERROR(0xc1)
#define WERR_ITERATED_DATA_EXCEEDS_64K W_ERROR(0xc2)
#define WERR_INVALID_MINALLOCSIZE W_ERROR(0xc3)
#define WERR_DYNLINK_FROM_INVALID_RING W_ERROR(0xc4)
#define WERR_IOPL_NOT_ENABLED W_ERROR(0xc5)
#define WERR_INVALID_SEGDPL W_ERROR(0xc6)
#define WERR_AUTODATASEG_EXCEEDS_64K W_ERROR(0xc7)
#define WERR_RING2SEG_MUST_BE_MOVABLE W_ERROR(0xc8)
#define WERR_RELOC_CHAIN_XEEDS_SEGLIM W_ERROR(0xc9)
#define WERR_INFLOOP_IN_RELOC_CHAIN W_ERROR(0xca)
#define WERR_ENVVAR_NOT_FOUND W_ERROR(0xcb)
#define WERR_NO_SIGNAL_SENT W_ERROR(0xcd)
#define WERR_FILENAME_EXCED_RANGE W_ERROR(0xce)
#define WERR_RING2_STACK_IN_USE W_ERROR(0xcf)
#define WERR_META_EXPANSION_TOO_LONG W_ERROR(0xd0)
#define WERR_INVALID_SIGNAL_NUMBER W_ERROR(0xd1)
#define WERR_THREAD_1_INACTIVE W_ERROR(0xd2)
#define WERR_LOCKED W_ERROR(0xd4)
#define WERR_TOO_MANY_MODULES W_ERROR(0xd6)
#define WERR_NESTING_NOT_ALLOWED W_ERROR(0xd7)
#define WERR_EXE_MACHINE_TYPE_MISMATCH W_ERROR(0xd8)
#define WERR_EXE_CANNOT_MODIFY_SIGNED_BINARY W_ERROR(0xd9)
#define WERR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY W_ERROR(0xda)
#define WERR_FILE_CHECKED_OUT W_ERROR(0xdc)
#define WERR_CHECKOUT_REQUIRED W_ERROR(0xdd)
#define WERR_BAD_FILE_TYPE W_ERROR(0xde)
#define WERR_FILE_TOO_LARGE W_ERROR(0xdf)
#define WERR_FORMS_AUTH_REQUIRED W_ERROR(0xe0)
#define WERR_VIRUS_INFECTED W_ERROR(0xe1)
#define WERR_VIRUS_DELETED W_ERROR(0xe2)
#define WERR_PIPE_LOCAL W_ERROR(0xe5)
#define WERR_BAD_PIPE W_ERROR(0xe6)
#define WERR_PIPE_BUSY W_ERROR(0xe7)
#define WERR_NO_DATA W_ERROR(0xe8)
#define WERR_PIPE_NOT_CONNECTED W_ERROR(0xe9)
#define WERR_MORE_DATA W_ERROR(0xea)
#define WERR_VC_DISCONNECTED W_ERROR(0xf0)
#define WERR_INVALID_EA_NAME W_ERROR(0xfe)
#define WERR_EA_LIST_INCONSISTENT W_ERROR(0xff)
#define WERR_WAIT_TIMEOUT W_ERROR(0x102)
#define WERR_NO_MORE_ITEMS W_ERROR(0x103)
#define WERR_CANNOT_COPY W_ERROR(0x10a)
#define WERR_DIRECTORY W_ERROR(0x10b)
#define WERR_EAS_DIDNT_FIT W_ERROR(0x113)
#define WERR_EA_FILE_CORRUPT W_ERROR(0x114)
#define WERR_EA_TABLE_FULL W_ERROR(0x115)
#define WERR_INVALID_EA_HANDLE W_ERROR(0x116)
#define WERR_EAS_NOT_SUPPORTED W_ERROR(0x11a)
#define WERR_NOT_OWNER W_ERROR(0x120)
#define WERR_TOO_MANY_POSTS W_ERROR(0x12a)
#define WERR_PARTIAL_COPY W_ERROR(0x12b)
#define WERR_OPLOCK_NOT_GRANTED W_ERROR(0x12c)
#define WERR_INVALID_OPLOCK_PROTOCOL W_ERROR(0x12d)
#define WERR_DISK_TOO_FRAGMENTED W_ERROR(0x12e)
#define WERR_DELETE_PENDING W_ERROR(0x12f)
#define WERR_MR_MID_NOT_FOUND W_ERROR(0x13d)
#define WERR_SCOPE_NOT_FOUND W_ERROR(0x13e)
#define WERR_FAIL_NOACTION_REBOOT W_ERROR(0x15e)
#define WERR_FAIL_SHUTDOWN W_ERROR(0x15f)
#define WERR_FAIL_RESTART W_ERROR(0x160)
#define WERR_MAX_SESSIONS_REACHED W_ERROR(0x161)
#define WERR_THREAD_MODE_ALREADY_BACKGROUND W_ERROR(0x190)
#define WERR_THREAD_MODE_NOT_BACKGROUND W_ERROR(0x191)
#define WERR_PROCESS_MODE_ALREADY_BACKGROUND W_ERROR(0x192)
#define WERR_PROCESS_MODE_NOT_BACKGROUND W_ERROR(0x193)
#define WERR_INVALID_ADDRESS W_ERROR(0x1e7)
#define WERR_USER_PROFILE_LOAD W_ERROR(0x1f4)
#define WERR_ARITHMETIC_OVERFLOW W_ERROR(0x216)
#define WERR_PIPE_CONNECTED W_ERROR(0x217)
#define WERR_PIPE_LISTENING W_ERROR(0x218)
#define WERR_VERIFIER_STOP W_ERROR(0x219)
#define WERR_ABIOS_ERROR W_ERROR(0x21a)
#define WERR_WX86_WARNING W_ERROR(0x21b)
#define WERR_WX86_ERROR W_ERROR(0x21c)
#define WERR_TIMER_NOT_CANCELED W_ERROR(0x21d)
#define WERR_UNWIND W_ERROR(0x21e)
#define WERR_BAD_STACK W_ERROR(0x21f)
#define WERR_INVALID_UNWIND_TARGET W_ERROR(0x220)
#define WERR_INVALID_PORT_ATTRIBUTES W_ERROR(0x221)
#define WERR_PORT_MESSAGE_TOO_LONG W_ERROR(0x222)
#define WERR_INVALID_QUOTA_LOWER W_ERROR(0x223)
#define WERR_DEVICE_ALREADY_ATTACHED W_ERROR(0x224)
#define WERR_INSTRUCTION_MISALIGNMENT W_ERROR(0x225)
#define WERR_PROFILING_NOT_STARTED W_ERROR(0x226)
#define WERR_PROFILING_NOT_STOPPED W_ERROR(0x227)
#define WERR_COULD_NOT_INTERPRET W_ERROR(0x228)
#define WERR_PROFILING_AT_LIMIT W_ERROR(0x229)
#define WERR_CANT_WAIT W_ERROR(0x22a)
#define WERR_CANT_TERMINATE_SELF W_ERROR(0x22b)
#define WERR_UNEXPECTED_MM_CREATE_ERR W_ERROR(0x22c)
#define WERR_UNEXPECTED_MM_MAP_ERROR W_ERROR(0x22d)
#define WERR_UNEXPECTED_MM_EXTEND_ERR W_ERROR(0x22e)
#define WERR_BAD_FUNCTION_TABLE W_ERROR(0x22f)
#define WERR_NO_GUID_TRANSLATION W_ERROR(0x230)
#define WERR_INVALID_LDT_SIZE W_ERROR(0x231)
#define WERR_INVALID_LDT_OFFSET W_ERROR(0x233)
#define WERR_INVALID_LDT_DESCRIPTOR W_ERROR(0x234)
#define WERR_TOO_MANY_THREADS W_ERROR(0x235)
#define WERR_THREAD_NOT_IN_PROCESS W_ERROR(0x236)
#define WERR_PAGEFILE_QUOTA_EXCEEDED W_ERROR(0x237)
#define WERR_LOGON_SERVER_CONFLICT W_ERROR(0x238)
#define WERR_SYNCHRONIZATION_REQUIRED W_ERROR(0x239)
#define WERR_NET_OPEN_FAILED W_ERROR(0x23a)
#define WERR_IO_PRIVILEGE_FAILED W_ERROR(0x23b)
#define WERR_CONTROL_C_EXIT W_ERROR(0x23c)
#define WERR_MISSING_SYSTEMFILE W_ERROR(0x23d)
#define WERR_UNHANDLED_EXCEPTION W_ERROR(0x23e)
#define WERR_APP_INIT_FAILURE W_ERROR(0x23f)
#define WERR_PAGEFILE_CREATE_FAILED W_ERROR(0x240)
#define WERR_INVALID_IMAGE_HASH W_ERROR(0x241)
#define WERR_NO_PAGEFILE W_ERROR(0x242)
#define WERR_ILLEGAL_FLOAT_CONTEXT W_ERROR(0x243)
#define WERR_NO_EVENT_PAIR W_ERROR(0x244)
#define WERR_DOMAIN_CTRLR_CONFIG_ERROR W_ERROR(0x245)
#define WERR_ILLEGAL_CHARACTER W_ERROR(0x246)
#define WERR_UNDEFINED_CHARACTER W_ERROR(0x247)
#define WERR_FLOPPY_VOLUME W_ERROR(0x248)
#define WERR_BIOS_FAILED_TO_CONNECT_INTERRUPT W_ERROR(0x249)
#define WERR_BACKUP_CONTROLLER W_ERROR(0x24a)
#define WERR_MUTANT_LIMIT_EXCEEDED W_ERROR(0x24b)
#define WERR_FS_DRIVER_REQUIRED W_ERROR(0x24c)
#define WERR_CANNOT_LOAD_REGISTRY_FILE W_ERROR(0x24d)
#define WERR_DEBUG_ATTACH_FAILED W_ERROR(0x24e)
#define WERR_SYSTEM_PROCESS_TERMINATED W_ERROR(0x24f)
#define WERR_DATA_NOT_ACCEPTED W_ERROR(0x250)
#define WERR_VDM_HARD_ERROR W_ERROR(0x251)
#define WERR_DRIVER_CANCEL_TIMEOUT W_ERROR(0x252)
#define WERR_REPLY_MESSAGE_MISMATCH W_ERROR(0x253)
#define WERR_LOST_WRITEBEHIND_DATA W_ERROR(0x254)
#define WERR_CLIENT_SERVER_PARAMETERS_INVALID W_ERROR(0x255)
#define WERR_NOT_TINY_STREAM W_ERROR(0x256)
#define WERR_STACK_OVERFLOW_READ W_ERROR(0x257)
#define WERR_CONVERT_TO_LARGE W_ERROR(0x258)
#define WERR_FOUND_OUT_OF_SCOPE W_ERROR(0x259)
#define WERR_ALLOCATE_BUCKET W_ERROR(0x25a)
#define WERR_MARSHALL_OVERFLOW W_ERROR(0x25b)
#define WERR_INVALID_VARIANT W_ERROR(0x25c)
#define WERR_BAD_COMPRESSION_BUFFER W_ERROR(0x25d)
#define WERR_AUDIT_FAILED W_ERROR(0x25e)
#define WERR_TIMER_RESOLUTION_NOT_SET W_ERROR(0x25f)
#define WERR_INSUFFICIENT_LOGON_INFO W_ERROR(0x260)
#define WERR_BAD_DLL_ENTRYPOINT W_ERROR(0x261)
#define WERR_BAD_SERVICE_ENTRYPOINT W_ERROR(0x262)
#define WERR_IP_ADDRESS_CONFLICT1 W_ERROR(0x263)
#define WERR_IP_ADDRESS_CONFLICT2 W_ERROR(0x264)
#define WERR_REGISTRY_QUOTA_LIMIT W_ERROR(0x265)
#define WERR_NO_CALLBACK_ACTIVE W_ERROR(0x266)
#define WERR_PWD_TOO_SHORT W_ERROR(0x267)
#define WERR_PWD_TOO_RECENT W_ERROR(0x268)
#define WERR_PWD_HISTORY_CONFLICT W_ERROR(0x269)
#define WERR_UNSUPPORTED_COMPRESSION W_ERROR(0x26a)
#define WERR_INVALID_HW_PROFILE W_ERROR(0x26b)
#define WERR_INVALID_PLUGPLAY_DEVICE_PATH W_ERROR(0x26c)
#define WERR_QUOTA_LIST_INCONSISTENT W_ERROR(0x26d)
#define WERR_EVALUATION_EXPIRATION W_ERROR(0x26e)
#define WERR_ILLEGAL_DLL_RELOCATION W_ERROR(0x26f)
#define WERR_DLL_INIT_FAILED_LOGOFF W_ERROR(0x270)
#define WERR_VALIDATE_CONTINUE W_ERROR(0x271)
#define WERR_NO_MORE_MATCHES W_ERROR(0x272)
#define WERR_RANGE_LIST_CONFLICT W_ERROR(0x273)
#define WERR_SERVER_SID_MISMATCH W_ERROR(0x274)
#define WERR_CANT_ENABLE_DENY_ONLY W_ERROR(0x275)
#define WERR_FLOAT_MULTIPLE_FAULTS W_ERROR(0x276)
#define WERR_FLOAT_MULTIPLE_TRAPS W_ERROR(0x277)
#define WERR_NOINTERFACE W_ERROR(0x278)
#define WERR_DRIVER_FAILED_SLEEP W_ERROR(0x279)
#define WERR_CORRUPT_SYSTEM_FILE W_ERROR(0x27a)
#define WERR_COMMITMENT_MINIMUM W_ERROR(0x27b)
#define WERR_PNP_RESTART_ENUMERATION W_ERROR(0x27c)
#define WERR_SYSTEM_IMAGE_BAD_SIGNATURE W_ERROR(0x27d)
#define WERR_PNP_REBOOT_REQUIRED W_ERROR(0x27e)
#define WERR_INSUFFICIENT_POWER W_ERROR(0x27f)
#define WERR_SYSTEM_SHUTDOWN W_ERROR(0x281)
#define WERR_PORT_NOT_SET W_ERROR(0x282)
#define WERR_DS_VERSION_CHECK_FAILURE W_ERROR(0x283)
#define WERR_RANGE_NOT_FOUND W_ERROR(0x284)
#define WERR_NOT_SAFE_MODE_DRIVER W_ERROR(0x286)
#define WERR_FAILED_DRIVER_ENTRY W_ERROR(0x287)
#define WERR_DEVICE_ENUMERATION_ERROR W_ERROR(0x288)
#define WERR_MOUNT_POINT_NOT_RESOLVED W_ERROR(0x289)
#define WERR_INVALID_DEVICE_OBJECT_PARAMETER W_ERROR(0x28a)
#define WERR_MCA_OCCURED W_ERROR(0x28b)
#define WERR_DRIVER_DATABASE_ERROR W_ERROR(0x28c)
#define WERR_SYSTEM_HIVE_TOO_LARGE W_ERROR(0x28d)
#define WERR_DRIVER_FAILED_PRIOR_UNLOAD W_ERROR(0x28e)
#define WERR_VOLSNAP_PREPARE_HIBERNATE W_ERROR(0x28f)
#define WERR_HIBERNATION_FAILURE W_ERROR(0x290)
#define WERR_FILE_SYSTEM_LIMITATION W_ERROR(0x299)
#define WERR_ASSERTION_FAILURE W_ERROR(0x29c)
#define WERR_ACPI_ERROR W_ERROR(0x29d)
#define WERR_WOW_ASSERTION W_ERROR(0x29e)
#define WERR_PNP_BAD_MPS_TABLE W_ERROR(0x29f)
#define WERR_PNP_TRANSLATION_FAILED W_ERROR(0x2a0)
#define WERR_PNP_IRQ_TRANSLATION_FAILED W_ERROR(0x2a1)
#define WERR_PNP_INVALID_ID W_ERROR(0x2a2)
#define WERR_WAKE_SYSTEM_DEBUGGER W_ERROR(0x2a3)
#define WERR_HANDLES_CLOSED W_ERROR(0x2a4)
#define WERR_EXTRANEOUS_INFORMATION W_ERROR(0x2a5)
#define WERR_RXACT_COMMIT_NECESSARY W_ERROR(0x2a6)
#define WERR_MEDIA_CHECK W_ERROR(0x2a7)
#define WERR_GUID_SUBSTITUTION_MADE W_ERROR(0x2a8)
#define WERR_STOPPED_ON_SYMLINK W_ERROR(0x2a9)
#define WERR_LONGJUMP W_ERROR(0x2aa)
#define WERR_PLUGPLAY_QUERY_VETOED W_ERROR(0x2ab)
#define WERR_UNWIND_CONSOLIDATE W_ERROR(0x2ac)
#define WERR_REGISTRY_HIVE_RECOVERED W_ERROR(0x2ad)
#define WERR_DLL_MIGHT_BE_INSECURE W_ERROR(0x2ae)
#define WERR_DLL_MIGHT_BE_INCOMPATIBLE W_ERROR(0x2af)
#define WERR_DBG_EXCEPTION_NOT_HANDLED W_ERROR(0x2b0)
#define WERR_DBG_REPLY_LATER W_ERROR(0x2b1)
#define WERR_DBG_UNABLE_TO_PROVIDE_HANDLE W_ERROR(0x2b2)
#define WERR_DBG_TERMINATE_THREAD W_ERROR(0x2b3)
#define WERR_DBG_TERMINATE_PROCESS W_ERROR(0x2b4)
#define WERR_DBG_CONTROL_C W_ERROR(0x2b5)
#define WERR_DBG_PRINTEXCEPTION_C W_ERROR(0x2b6)
#define WERR_DBG_RIPEXCEPTION W_ERROR(0x2b7)
#define WERR_DBG_CONTROL_BREAK W_ERROR(0x2b8)
#define WERR_DBG_COMMAND_EXCEPTION W_ERROR(0x2b9)
#define WERR_OBJECT_NAME_EXISTS W_ERROR(0x2ba)
#define WERR_THREAD_WAS_SUSPENDED W_ERROR(0x2bb)
#define WERR_IMAGE_NOT_AT_BASE W_ERROR(0x2bc)
#define WERR_RXACT_STATE_CREATED W_ERROR(0x2bd)
#define WERR_SEGMENT_NOTIFICATION W_ERROR(0x2be)
#define WERR_BAD_CURRENT_DIRECTORY W_ERROR(0x2bf)
#define WERR_FT_READ_RECOVERY_FROM_BACKUP W_ERROR(0x2c0)
#define WERR_FT_WRITE_RECOVERY W_ERROR(0x2c1)
#define WERR_IMAGE_MACHINE_TYPE_MISMATCH W_ERROR(0x2c2)
#define WERR_RECEIVE_PARTIAL W_ERROR(0x2c3)
#define WERR_RECEIVE_EXPEDITED W_ERROR(0x2c4)
#define WERR_RECEIVE_PARTIAL_EXPEDITED W_ERROR(0x2c5)
#define WERR_EVENT_DONE W_ERROR(0x2c6)
#define WERR_EVENT_PENDING W_ERROR(0x2c7)
#define WERR_CHECKING_FILE_SYSTEM W_ERROR(0x2c8)
#define WERR_FATAL_APP_EXIT W_ERROR(0x2c9)
#define WERR_PREDEFINED_HANDLE W_ERROR(0x2ca)
#define WERR_WAS_UNLOCKED W_ERROR(0x2cb)
#define WERR_WAS_LOCKED W_ERROR(0x2cd)
#define WERR_ALREADY_WIN32 W_ERROR(0x2cf)
#define WERR_IMAGE_MACHINE_TYPE_MISMATCH_EXE W_ERROR(0x2d0)
#define WERR_NO_YIELD_PERFORMED W_ERROR(0x2d1)
#define WERR_TIMER_RESUME_IGNORED W_ERROR(0x2d2)
#define WERR_ARBITRATION_UNHANDLED W_ERROR(0x2d3)
#define WERR_CARDBUS_NOT_SUPPORTED W_ERROR(0x2d4)
#define WERR_MP_PROCESSOR_MISMATCH W_ERROR(0x2d5)
#define WERR_HIBERNATED W_ERROR(0x2d6)
#define WERR_RESUME_HIBERNATION W_ERROR(0x2d7)
#define WERR_FIRMWARE_UPDATED W_ERROR(0x2d8)
#define WERR_DRIVERS_LEAKING_LOCKED_PAGES W_ERROR(0x2d9)
#define WERR_WAKE_SYSTEM W_ERROR(0x2da)
#define WERR_ABANDONED_WAIT_0 W_ERROR(0x2df)
#define WERR_ELEVATION_REQUIRED W_ERROR(0x2e4)
#define WERR_REPARSE W_ERROR(0x2e5)
#define WERR_OPLOCK_BREAK_IN_PROGRESS W_ERROR(0x2e6)
#define WERR_VOLUME_MOUNTED W_ERROR(0x2e7)
#define WERR_RXACT_COMMITTED W_ERROR(0x2e8)
#define WERR_NOTIFY_CLEANUP W_ERROR(0x2e9)
#define WERR_PRIMARY_TRANSPORT_CONNECT_FAILED W_ERROR(0x2ea)
#define WERR_PAGE_FAULT_TRANSITION W_ERROR(0x2eb)
#define WERR_PAGE_FAULT_DEMAND_ZERO W_ERROR(0x2ec)
#define WERR_PAGE_FAULT_COPY_ON_WRITE W_ERROR(0x2ed)
#define WERR_PAGE_FAULT_GUARD_PAGE W_ERROR(0x2ee)
#define WERR_PAGE_FAULT_PAGING_FILE W_ERROR(0x2ef)
#define WERR_CACHE_PAGE_LOCKED W_ERROR(0x2f0)
#define WERR_CRASH_DUMP W_ERROR(0x2f1)
#define WERR_BUFFER_ALL_ZEROS W_ERROR(0x2f2)
#define WERR_REPARSE_OBJECT W_ERROR(0x2f3)
#define WERR_RESOURCE_REQUIREMENTS_CHANGED W_ERROR(0x2f4)
#define WERR_TRANSLATION_COMPLETE W_ERROR(0x2f5)
#define WERR_NOTHING_TO_TERMINATE W_ERROR(0x2f6)
#define WERR_PROCESS_NOT_IN_JOB W_ERROR(0x2f7)
#define WERR_PROCESS_IN_JOB W_ERROR(0x2f8)
#define WERR_VOLSNAP_HIBERNATE_READY W_ERROR(0x2f9)
#define WERR_FSFILTER_OP_COMPLETED_SUCCESSFULLY W_ERROR(0x2fa)
#define WERR_INTERRUPT_VECTOR_ALREADY_CONNECTED W_ERROR(0x2fb)
#define WERR_INTERRUPT_STILL_CONNECTED W_ERROR(0x2fc)
#define WERR_WAIT_FOR_OPLOCK W_ERROR(0x2fd)
#define WERR_DBG_EXCEPTION_HANDLED W_ERROR(0x2fe)
#define WERR_DBG_CONTINUE W_ERROR(0x2ff)
#define WERR_CALLBACK_POP_STACK W_ERROR(0x300)
#define WERR_COMPRESSION_DISABLED W_ERROR(0x301)
#define WERR_CANTFETCHBACKWARDS W_ERROR(0x302)
#define WERR_CANTSCROLLBACKWARDS W_ERROR(0x303)
#define WERR_ROWSNOTRELEASED W_ERROR(0x304)
#define WERR_BAD_ACCESSOR_FLAGS W_ERROR(0x305)
#define WERR_ERRORS_ENCOUNTERED W_ERROR(0x306)
#define WERR_NOT_CAPABLE W_ERROR(0x307)
#define WERR_REQUEST_OUT_OF_SEQUENCE W_ERROR(0x308)
#define WERR_VERSION_PARSE_ERROR W_ERROR(0x309)
#define WERR_BADSTARTPOSITION W_ERROR(0x30a)
#define WERR_MEMORY_HARDWARE W_ERROR(0x30b)
#define WERR_DISK_REPAIR_DISABLED W_ERROR(0x30c)
#define WERR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE W_ERROR(0x30d)
#define WERR_SYSTEM_POWERSTATE_TRANSITION W_ERROR(0x30e)
#define WERR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION W_ERROR(0x30f)
#define WERR_MCA_EXCEPTION W_ERROR(0x310)
#define WERR_ACCESS_AUDIT_BY_POLICY W_ERROR(0x311)
#define WERR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY W_ERROR(0x312)
#define WERR_ABANDON_HIBERFILE W_ERROR(0x313)
#define WERR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED W_ERROR(0x314)
#define WERR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR W_ERROR(0x315)
#define WERR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR W_ERROR(0x316)
#define WERR_EA_ACCESS_DENIED W_ERROR(0x3e2)
#define WERR_OPERATION_ABORTED W_ERROR(0x3e3)
#define WERR_IO_INCOMPLETE W_ERROR(0x3e4)
#define WERR_IO_PENDING W_ERROR(0x3e5)
#define WERR_NOACCESS W_ERROR(0x3e6)
#define WERR_SWAPERROR W_ERROR(0x3e7)
#define WERR_STACK_OVERFLOW W_ERROR(0x3e9)
#define WERR_INVALID_MESSAGE W_ERROR(0x3ea)
#define WERR_CAN_NOT_COMPLETE W_ERROR(0x3eb)
#define WERR_INVALID_FLAGS W_ERROR(0x3ec)
#define WERR_UNRECOGNIZED_VOLUME W_ERROR(0x3ed)
#define WERR_FILE_INVALID W_ERROR(0x3ee)
#define WERR_FULLSCREEN_MODE W_ERROR(0x3ef)
#define WERR_NO_TOKEN W_ERROR(0x3f0)
#define WERR_BADDB W_ERROR(0x3f1)
#define WERR_BADKEY W_ERROR(0x3f2)
#define WERR_CANTOPEN W_ERROR(0x3f3)
#define WERR_CANTREAD W_ERROR(0x3f4)
#define WERR_CANTWRITE W_ERROR(0x3f5)
#define WERR_REGISTRY_RECOVERED W_ERROR(0x3f6)
#define WERR_REGISTRY_CORRUPT W_ERROR(0x3f7)
#define WERR_REGISTRY_IO_FAILED W_ERROR(0x3f8)
#define WERR_NOT_REGISTRY_FILE W_ERROR(0x3f9)
#define WERR_KEY_DELETED W_ERROR(0x3fa)
#define WERR_NO_LOG_SPACE W_ERROR(0x3fb)
#define WERR_KEY_HAS_CHILDREN W_ERROR(0x3fc)
#define WERR_CHILD_MUST_BE_VOLATILE W_ERROR(0x3fd)
#define WERR_NOTIFY_ENUM_DIR W_ERROR(0x3fe)
#define WERR_DEPENDENT_SERVICES_RUNNING W_ERROR(0x41b)
#define WERR_INVALID_SERVICE_CONTROL W_ERROR(0x41c)
#define WERR_SERVICE_REQUEST_TIMEOUT W_ERROR(0x41d)
#define WERR_SERVICE_NO_THREAD W_ERROR(0x41e)
#define WERR_SERVICE_DATABASE_LOCKED W_ERROR(0x41f)
#define WERR_SERVICE_ALREADY_RUNNING W_ERROR(0x420)
#define WERR_INVALID_SERVICE_ACCOUNT W_ERROR(0x421)
#define WERR_SERVICE_DISABLED W_ERROR(0x422)
#define WERR_CIRCULAR_DEPENDENCY W_ERROR(0x423)
#define WERR_SERVICE_DOES_NOT_EXIST W_ERROR(0x424)
#define WERR_SERVICE_CANNOT_ACCEPT_CTRL W_ERROR(0x425)
#define WERR_SERVICE_NOT_ACTIVE W_ERROR(0x426)
#define WERR_FAILED_SERVICE_CONTROLLER_CONNECT W_ERROR(0x427)
#define WERR_EXCEPTION_IN_SERVICE W_ERROR(0x428)
#define WERR_DATABASE_DOES_NOT_EXIST W_ERROR(0x429)
#define WERR_SERVICE_SPECIFIC_ERROR W_ERROR(0x42a)
#define WERR_PROCESS_ABORTED W_ERROR(0x42b)
#define WERR_SERVICE_DEPENDENCY_FAIL W_ERROR(0x42c)
#define WERR_SERVICE_LOGON_FAILED W_ERROR(0x42d)
#define WERR_SERVICE_START_HANG W_ERROR(0x42e)
#define WERR_INVALID_SERVICE_LOCK W_ERROR(0x42f)
#define WERR_SERVICE_MARKED_FOR_DELETE W_ERROR(0x430)
#define WERR_SERVICE_EXISTS W_ERROR(0x431)
#define WERR_ALREADY_RUNNING_LKG W_ERROR(0x432)
#define WERR_SERVICE_DEPENDENCY_DELETED W_ERROR(0x433)
#define WERR_BOOT_ALREADY_ACCEPTED W_ERROR(0x434)
#define WERR_SERVICE_NEVER_STARTED W_ERROR(0x435)
#define WERR_DUPLICATE_SERVICE_NAME W_ERROR(0x436)
#define WERR_DIFFERENT_SERVICE_ACCOUNT W_ERROR(0x437)
#define WERR_CANNOT_DETECT_DRIVER_FAILURE W_ERROR(0x438)
#define WERR_CANNOT_DETECT_PROCESS_ABORT W_ERROR(0x439)
#define WERR_NO_RECOVERY_PROGRAM W_ERROR(0x43a)
#define WERR_SERVICE_NOT_IN_EXE W_ERROR(0x43b)
#define WERR_NOT_SAFEBOOT_SERVICE W_ERROR(0x43c)
#define WERR_END_OF_MEDIA W_ERROR(0x44c)
#define WERR_FILEMARK_DETECTED W_ERROR(0x44d)
#define WERR_BEGINNING_OF_MEDIA W_ERROR(0x44e)
#define WERR_SETMARK_DETECTED W_ERROR(0x44f)
#define WERR_NO_DATA_DETECTED W_ERROR(0x450)
#define WERR_PARTITION_FAILURE W_ERROR(0x451)
#define WERR_INVALID_BLOCK_LENGTH W_ERROR(0x452)
#define WERR_DEVICE_NOT_PARTITIONED W_ERROR(0x453)
#define WERR_UNABLE_TO_LOCK_MEDIA W_ERROR(0x454)
#define WERR_UNABLE_TO_UNLOAD_MEDIA W_ERROR(0x455)
#define WERR_MEDIA_CHANGED W_ERROR(0x456)
#define WERR_BUS_RESET W_ERROR(0x457)
#define WERR_NO_MEDIA_IN_DRIVE W_ERROR(0x458)
#define WERR_NO_UNICODE_TRANSLATION W_ERROR(0x459)
#define WERR_DLL_INIT_FAILED W_ERROR(0x45a)
#define WERR_SHUTDOWN_IN_PROGRESS W_ERROR(0x45b)
#define WERR_NO_SHUTDOWN_IN_PROGRESS W_ERROR(0x45c)
#define WERR_IO_DEVICE W_ERROR(0x45d)
#define WERR_SERIAL_NO_DEVICE W_ERROR(0x45e)
#define WERR_IRQ_BUSY W_ERROR(0x45f)
#define WERR_MORE_WRITES W_ERROR(0x460)
#define WERR_COUNTER_TIMEOUT W_ERROR(0x461)
#define WERR_FLOPPY_ID_MARK_NOT_FOUND W_ERROR(0x462)
#define WERR_FLOPPY_WRONG_CYLINDER W_ERROR(0x463)
#define WERR_FLOPPY_UNKNOWN_ERROR W_ERROR(0x464)
#define WERR_FLOPPY_BAD_REGISTERS W_ERROR(0x465)
#define WERR_DISK_RECALIBRATE_FAILED W_ERROR(0x466)
#define WERR_DISK_OPERATION_FAILED W_ERROR(0x467)
#define WERR_DISK_RESET_FAILED W_ERROR(0x468)
#define WERR_EOM_OVERFLOW W_ERROR(0x469)
#define WERR_NOT_ENOUGH_SERVER_MEMORY W_ERROR(0x46a)
#define WERR_POSSIBLE_DEADLOCK W_ERROR(0x46b)
#define WERR_MAPPED_ALIGNMENT W_ERROR(0x46c)
#define WERR_SET_POWER_STATE_VETOED W_ERROR(0x474)
#define WERR_SET_POWER_STATE_FAILED W_ERROR(0x475)
#define WERR_TOO_MANY_LINKS W_ERROR(0x476)
#define WERR_OLD_WIN_VERSION W_ERROR(0x47e)
#define WERR_APP_WRONG_OS W_ERROR(0x47f)
#define WERR_SINGLE_INSTANCE_APP W_ERROR(0x480)
#define WERR_RMODE_APP W_ERROR(0x481)
#define WERR_INVALID_DLL W_ERROR(0x482)
#define WERR_NO_ASSOCIATION W_ERROR(0x483)
#define WERR_DDE_FAIL W_ERROR(0x484)
#define WERR_DLL_NOT_FOUND W_ERROR(0x485)
#define WERR_NO_MORE_USER_HANDLES W_ERROR(0x486)
#define WERR_MESSAGE_SYNC_ONLY W_ERROR(0x487)
#define WERR_SOURCE_ELEMENT_EMPTY W_ERROR(0x488)
#define WERR_DESTINATION_ELEMENT_FULL W_ERROR(0x489)
#define WERR_ILLEGAL_ELEMENT_ADDRESS W_ERROR(0x48a)
#define WERR_MAGAZINE_NOT_PRESENT W_ERROR(0x48b)
#define WERR_DEVICE_REINITIALIZATION_NEEDED W_ERROR(0x48c)
#define WERR_DEVICE_REQUIRES_CLEANING W_ERROR(0x48d)
#define WERR_DEVICE_DOOR_OPEN W_ERROR(0x48e)
#define WERR_DEVICE_NOT_CONNECTED W_ERROR(0x48f)
#define WERR_NOT_FOUND W_ERROR(0x490)
#define WERR_NO_MATCH W_ERROR(0x491)
#define WERR_SET_NOT_FOUND W_ERROR(0x492)
#define WERR_POINT_NOT_FOUND W_ERROR(0x493)
#define WERR_NO_TRACKING_SERVICE W_ERROR(0x494)
#define WERR_NO_VOLUME_ID W_ERROR(0x495)
#define WERR_UNABLE_TO_REMOVE_REPLACED W_ERROR(0x497)
#define WERR_UNABLE_TO_MOVE_REPLACEMENT W_ERROR(0x498)
#define WERR_UNABLE_TO_MOVE_REPLACEMENT_2 W_ERROR(0x499)
#define WERR_JOURNAL_DELETE_IN_PROGRESS W_ERROR(0x49a)
#define WERR_JOURNAL_NOT_ACTIVE W_ERROR(0x49b)
#define WERR_POTENTIAL_FILE_FOUND W_ERROR(0x49c)
#define WERR_JOURNAL_ENTRY_DELETED W_ERROR(0x49d)
#define WERR_SHUTDOWN_IS_SCHEDULED W_ERROR(0x4a6)
#define WERR_SHUTDOWN_USERS_LOGGED_ON W_ERROR(0x4a7)
#define WERR_BAD_DEVICE W_ERROR(0x4b0)
#define WERR_CONNECTION_UNAVAIL W_ERROR(0x4b1)
#define WERR_DEVICE_ALREADY_REMEMBERED W_ERROR(0x4b2)
#define WERR_NO_NET_OR_BAD_PATH W_ERROR(0x4b3)
#define WERR_BAD_PROVIDER W_ERROR(0x4b4)
#define WERR_CANNOT_OPEN_PROFILE W_ERROR(0x4b5)
#define WERR_BAD_PROFILE W_ERROR(0x4b6)
#define WERR_NOT_CONTAINER W_ERROR(0x4b7)
#define WERR_EXTENDED_ERROR W_ERROR(0x4b8)
#define WERR_INVALID_GROUPNAME W_ERROR(0x4b9)
#define WERR_INVALID_COMPUTERNAME W_ERROR(0x4ba)
#define WERR_INVALID_EVENTNAME W_ERROR(0x4bb)
#define WERR_INVALID_DOMAINNAME W_ERROR(0x4bc)
#define WERR_INVALID_SERVICENAME W_ERROR(0x4bd)
#define WERR_INVALID_NETNAME W_ERROR(0x4be)
#define WERR_INVALID_SHARENAME W_ERROR(0x4bf)
#define WERR_INVALID_PASSWORDNAME W_ERROR(0x4c0)
#define WERR_INVALID_MESSAGENAME W_ERROR(0x4c1)
#define WERR_INVALID_MESSAGEDEST W_ERROR(0x4c2)
#define WERR_SESSION_CREDENTIAL_CONFLICT W_ERROR(0x4c3)
#define WERR_REMOTE_SESSION_LIMIT_EXCEEDED W_ERROR(0x4c4)
#define WERR_DUP_DOMAINNAME W_ERROR(0x4c5)
#define WERR_NO_NETWORK W_ERROR(0x4c6)
#define WERR_CANCELLED W_ERROR(0x4c7)
#define WERR_USER_MAPPED_FILE W_ERROR(0x4c8)
#define WERR_CONNECTION_REFUSED W_ERROR(0x4c9)
#define WERR_GRACEFUL_DISCONNECT W_ERROR(0x4ca)
#define WERR_ADDRESS_ALREADY_ASSOCIATED W_ERROR(0x4cb)
#define WERR_ADDRESS_NOT_ASSOCIATED W_ERROR(0x4cc)
#define WERR_CONNECTION_INVALID W_ERROR(0x4cd)
#define WERR_CONNECTION_ACTIVE W_ERROR(0x4ce)
#define WERR_NETWORK_UNREACHABLE W_ERROR(0x4cf)
#define WERR_HOST_UNREACHABLE W_ERROR(0x4d0)
#define WERR_PROTOCOL_UNREACHABLE W_ERROR(0x4d1)
#define WERR_PORT_UNREACHABLE W_ERROR(0x4d2)
#define WERR_REQUEST_ABORTED W_ERROR(0x4d3)
#define WERR_CONNECTION_ABORTED W_ERROR(0x4d4)
#define WERR_RETRY W_ERROR(0x4d5)
#define WERR_CONNECTION_COUNT_LIMIT W_ERROR(0x4d6)
#define WERR_LOGIN_TIME_RESTRICTION W_ERROR(0x4d7)
#define WERR_LOGIN_WKSTA_RESTRICTION W_ERROR(0x4d8)
#define WERR_INCORRECT_ADDRESS W_ERROR(0x4d9)
#define WERR_ALREADY_REGISTERED W_ERROR(0x4da)
#define WERR_SERVICE_NOT_FOUND W_ERROR(0x4db)
#define WERR_NOT_AUTHENTICATED W_ERROR(0x4dc)
#define WERR_NOT_LOGGED_ON W_ERROR(0x4dd)
#define WERR_CONTINUE W_ERROR(0x4de)
#define WERR_ALREADY_INITIALIZED W_ERROR(0x4df)
#define WERR_NO_MORE_DEVICES W_ERROR(0x4e0)
#define WERR_NO_SUCH_SITE W_ERROR(0x4e1)
#define WERR_DOMAIN_CONTROLLER_EXISTS W_ERROR(0x4e2)
#define WERR_ONLY_IF_CONNECTED W_ERROR(0x4e3)
#define WERR_OVERRIDE_NOCHANGES W_ERROR(0x4e4)
#define WERR_BAD_USER_PROFILE W_ERROR(0x4e5)
#define WERR_NOT_SUPPORTED_ON_SBS W_ERROR(0x4e6)
#define WERR_SERVER_SHUTDOWN_IN_PROGRESS W_ERROR(0x4e7)
#define WERR_HOST_DOWN W_ERROR(0x4e8)
#define WERR_NON_ACCOUNT_SID W_ERROR(0x4e9)
#define WERR_NON_DOMAIN_SID W_ERROR(0x4ea)
#define WERR_APPHELP_BLOCK W_ERROR(0x4eb)
#define WERR_ACCESS_DISABLED_BY_POLICY W_ERROR(0x4ec)
#define WERR_REG_NAT_CONSUMPTION W_ERROR(0x4ed)
#define WERR_CSCSHARE_OFFLINE W_ERROR(0x4ee)
#define WERR_PKINIT_FAILURE W_ERROR(0x4ef)
#define WERR_SMARTCARD_SUBSYSTEM_FAILURE W_ERROR(0x4f0)
#define WERR_DOWNGRADE_DETECTED W_ERROR(0x4f1)
#define WERR_MACHINE_LOCKED W_ERROR(0x4f7)
#define WERR_CALLBACK_SUPPLIED_INVALID_DATA W_ERROR(0x4f9)
#define WERR_SYNC_FOREGROUND_REFRESH_REQUIRED W_ERROR(0x4fa)
#define WERR_DRIVER_BLOCKED W_ERROR(0x4fb)
#define WERR_INVALID_IMPORT_OF_NON_DLL W_ERROR(0x4fc)
#define WERR_ACCESS_DISABLED_WEBBLADE W_ERROR(0x4fd)
#define WERR_ACCESS_DISABLED_WEBBLADE_TAMPER W_ERROR(0x4fe)
#define WERR_RECOVERY_FAILURE W_ERROR(0x4ff)
#define WERR_ALREADY_FIBER W_ERROR(0x500)
#define WERR_ALREADY_THREAD W_ERROR(0x501)
#define WERR_STACK_BUFFER_OVERRUN W_ERROR(0x502)
#define WERR_PARAMETER_QUOTA_EXCEEDED W_ERROR(0x503)
#define WERR_DEBUGGER_INACTIVE W_ERROR(0x504)
#define WERR_DELAY_LOAD_FAILED W_ERROR(0x505)
#define WERR_VDM_DISALLOWED W_ERROR(0x506)
#define WERR_UNIDENTIFIED_ERROR W_ERROR(0x507)
#define WERR_INVALID_CRUNTIME_PARAMETER W_ERROR(0x508)
#define WERR_BEYOND_VDL W_ERROR(0x509)
#define WERR_INCOMPATIBLE_SERVICE_SID_TYPE W_ERROR(0x50a)
#define WERR_DRIVER_PROCESS_TERMINATED W_ERROR(0x50b)
#define WERR_IMPLEMENTATION_LIMIT W_ERROR(0x50c)
#define WERR_PROCESS_IS_PROTECTED W_ERROR(0x50d)
#define WERR_SERVICE_NOTIFY_CLIENT_LAGGING W_ERROR(0x50e)
#define WERR_DISK_QUOTA_EXCEEDED W_ERROR(0x50f)
#define WERR_CONTENT_BLOCKED W_ERROR(0x510)
#define WERR_INCOMPATIBLE_SERVICE_PRIVILEGE W_ERROR(0x511)
#define WERR_INVALID_LABEL W_ERROR(0x513)
#define WERR_NOT_ALL_ASSIGNED W_ERROR(0x514)
#define WERR_SOME_NOT_MAPPED W_ERROR(0x515)
#define WERR_NO_QUOTAS_FOR_ACCOUNT W_ERROR(0x516)
#define WERR_LOCAL_USER_SESSION_KEY W_ERROR(0x517)
#define WERR_NULL_LM_PASSWORD W_ERROR(0x518)
#define WERR_UNKNOWN_REVISION W_ERROR(0x519)
#define WERR_REVISION_MISMATCH W_ERROR(0x51a)
#define WERR_INVALID_OWNER W_ERROR(0x51b)
#define WERR_NO_IMPERSONATION_TOKEN W_ERROR(0x51d)
#define WERR_CANT_DISABLE_MANDATORY W_ERROR(0x51e)
#define WERR_NO_LOGON_SERVERS W_ERROR(0x51f)
#define WERR_NO_SUCH_LOGON_SESSION W_ERROR(0x520)
#define WERR_NO_SUCH_PRIVILEGE W_ERROR(0x521)
#define WERR_PRIVILEGE_NOT_HELD W_ERROR(0x522)
#define WERR_INVALID_ACCOUNT_NAME W_ERROR(0x523)
#define WERR_USER_EXISTS W_ERROR(0x524)
#define WERR_NO_SUCH_USER W_ERROR(0x525)
#define WERR_GROUP_EXISTS W_ERROR(0x526)
#define WERR_NO_SUCH_GROUP W_ERROR(0x527)
#define WERR_MEMBER_IN_GROUP W_ERROR(0x528)
#define WERR_MEMBER_NOT_IN_GROUP W_ERROR(0x529)
#define WERR_LAST_ADMIN W_ERROR(0x52a)
#define WERR_WRONG_PASSWORD W_ERROR(0x52b)
#define WERR_ILL_FORMED_PASSWORD W_ERROR(0x52c)
#define WERR_PASSWORD_RESTRICTION W_ERROR(0x52d)
#define WERR_LOGON_FAILURE W_ERROR(0x52e)
#define WERR_ACCOUNT_RESTRICTION W_ERROR(0x52f)
#define WERR_INVALID_LOGON_HOURS W_ERROR(0x530)
#define WERR_INVALID_WORKSTATION W_ERROR(0x531)
#define WERR_PASSWORD_EXPIRED W_ERROR(0x532)
#define WERR_ACCOUNT_DISABLED W_ERROR(0x533)
#define WERR_NONE_MAPPED W_ERROR(0x534)
#define WERR_TOO_MANY_LUIDS_REQUESTED W_ERROR(0x535)
#define WERR_LUIDS_EXHAUSTED W_ERROR(0x536)
#define WERR_INVALID_SUB_AUTHORITY W_ERROR(0x537)
#define WERR_INVALID_ACL W_ERROR(0x538)
#define WERR_INVALID_SID W_ERROR(0x539)
#define WERR_INVALID_SECURITY_DESCR W_ERROR(0x53a)
#define WERR_BAD_INHERITANCE_ACL W_ERROR(0x53c)
#define WERR_SERVER_DISABLED W_ERROR(0x53d)
#define WERR_SERVER_NOT_DISABLED W_ERROR(0x53e)
#define WERR_INVALID_ID_AUTHORITY W_ERROR(0x53f)
#define WERR_ALLOTTED_SPACE_EXCEEDED W_ERROR(0x540)
#define WERR_INVALID_GROUP_ATTRIBUTES W_ERROR(0x541)
#define WERR_BAD_IMPERSONATION_LEVEL W_ERROR(0x542)
#define WERR_CANT_OPEN_ANONYMOUS W_ERROR(0x543)
#define WERR_BAD_VALIDATION_CLASS W_ERROR(0x544)
#define WERR_BAD_TOKEN_TYPE W_ERROR(0x545)
#define WERR_NO_SECURITY_ON_OBJECT W_ERROR(0x546)
#define WERR_CANT_ACCESS_DOMAIN_INFO W_ERROR(0x547)
#define WERR_INVALID_SERVER_STATE W_ERROR(0x548)
#define WERR_INVALID_DOMAIN_STATE W_ERROR(0x549)
#define WERR_INVALID_DOMAIN_ROLE W_ERROR(0x54a)
#define WERR_NO_SUCH_DOMAIN W_ERROR(0x54b)
#define WERR_DOMAIN_EXISTS W_ERROR(0x54c)
#define WERR_DOMAIN_LIMIT_EXCEEDED W_ERROR(0x54d)
#define WERR_INTERNAL_DB_CORRUPTION W_ERROR(0x54e)
#define WERR_INTERNAL_ERROR W_ERROR(0x54f)
#define WERR_GENERIC_NOT_MAPPED W_ERROR(0x550)
#define WERR_BAD_DESCRIPTOR_FORMAT W_ERROR(0x551)
#define WERR_NOT_LOGON_PROCESS W_ERROR(0x552)
#define WERR_LOGON_SESSION_EXISTS W_ERROR(0x553)
#define WERR_NO_SUCH_PACKAGE W_ERROR(0x554)
#define WERR_BAD_LOGON_SESSION_STATE W_ERROR(0x555)
#define WERR_LOGON_SESSION_COLLISION W_ERROR(0x556)
#define WERR_INVALID_LOGON_TYPE W_ERROR(0x557)
#define WERR_CANNOT_IMPERSONATE W_ERROR(0x558)
#define WERR_RXACT_INVALID_STATE W_ERROR(0x559)
#define WERR_RXACT_COMMIT_FAILURE W_ERROR(0x55a)
#define WERR_SPECIAL_ACCOUNT W_ERROR(0x55b)
#define WERR_SPECIAL_GROUP W_ERROR(0x55c)
#define WERR_SPECIAL_USER W_ERROR(0x55d)
#define WERR_MEMBERS_PRIMARY_GROUP W_ERROR(0x55e)
#define WERR_TOKEN_ALREADY_IN_USE W_ERROR(0x55f)
#define WERR_NO_SUCH_ALIAS W_ERROR(0x560)
#define WERR_MEMBER_NOT_IN_ALIAS W_ERROR(0x561)
#define WERR_MEMBER_IN_ALIAS W_ERROR(0x562)
#define WERR_ALIAS_EXISTS W_ERROR(0x563)
#define WERR_LOGON_NOT_GRANTED W_ERROR(0x564)
#define WERR_TOO_MANY_SECRETS W_ERROR(0x565)
#define WERR_SECRET_TOO_LONG W_ERROR(0x566)
#define WERR_INTERNAL_DB_ERROR W_ERROR(0x567)
#define WERR_TOO_MANY_CONTEXT_IDS W_ERROR(0x568)
#define WERR_LOGON_TYPE_NOT_GRANTED W_ERROR(0x569)
#define WERR_NT_CROSS_ENCRYPTION_REQUIRED W_ERROR(0x56a)
#define WERR_NO_SUCH_MEMBER W_ERROR(0x56b)
#define WERR_INVALID_MEMBER W_ERROR(0x56c)
#define WERR_TOO_MANY_SIDS W_ERROR(0x56d)
#define WERR_LM_CROSS_ENCRYPTION_REQUIRED W_ERROR(0x56e)
#define WERR_NO_INHERITANCE W_ERROR(0x56f)
#define WERR_FILE_CORRUPT W_ERROR(0x570)
#define WERR_DISK_CORRUPT W_ERROR(0x571)
#define WERR_NO_USER_SESSION_KEY W_ERROR(0x572)
#define WERR_LICENSE_QUOTA_EXCEEDED W_ERROR(0x573)
#define WERR_WRONG_TARGET_NAME W_ERROR(0x574)
#define WERR_MUTUAL_AUTH_FAILED W_ERROR(0x575)
#define WERR_TIME_SKEW W_ERROR(0x576)
#define WERR_CURRENT_DOMAIN_NOT_ALLOWED W_ERROR(0x577)
#define WERR_INVALID_WINDOW_HANDLE W_ERROR(0x578)
#define WERR_INVALID_MENU_HANDLE W_ERROR(0x579)
#define WERR_INVALID_CURSOR_HANDLE W_ERROR(0x57a)
#define WERR_INVALID_ACCEL_HANDLE W_ERROR(0x57b)
#define WERR_INVALID_HOOK_HANDLE W_ERROR(0x57c)
#define WERR_INVALID_DWP_HANDLE W_ERROR(0x57d)
#define WERR_TLW_WITH_WSCHILD W_ERROR(0x57e)
#define WERR_CANNOT_FIND_WND_CLASS W_ERROR(0x57f)
#define WERR_WINDOW_OF_OTHER_THREAD W_ERROR(0x580)
#define WERR_HOTKEY_ALREADY_REGISTERED W_ERROR(0x581)
#define WERR_CLASS_ALREADY_EXISTS W_ERROR(0x582)
#define WERR_CLASS_DOES_NOT_EXIST W_ERROR(0x583)
#define WERR_CLASS_HAS_WINDOWS W_ERROR(0x584)
#define WERR_INVALID_INDEX W_ERROR(0x585)
#define WERR_INVALID_ICON_HANDLE W_ERROR(0x586)
#define WERR_PRIVATE_DIALOG_INDEX W_ERROR(0x587)
#define WERR_LISTBOX_ID_NOT_FOUND W_ERROR(0x588)
#define WERR_NO_WILDCARD_CHARACTERS W_ERROR(0x589)
#define WERR_CLIPBOARD_NOT_OPEN W_ERROR(0x58a)
#define WERR_HOTKEY_NOT_REGISTERED W_ERROR(0x58b)
#define WERR_WINDOW_NOT_DIALOG W_ERROR(0x58c)
#define WERR_CONTROL_ID_NOT_FOUND W_ERROR(0x58d)
#define WERR_INVALID_COMBOBOX_MESSAGE W_ERROR(0x58e)
#define WERR_WINDOW_NOT_COMBOBOX W_ERROR(0x58f)
#define WERR_INVALID_EDIT_HEIGHT W_ERROR(0x590)
#define WERR_DC_NOT_FOUND W_ERROR(0x591)
#define WERR_INVALID_HOOK_FILTER W_ERROR(0x592)
#define WERR_INVALID_FILTER_PROC W_ERROR(0x593)
#define WERR_HOOK_NEEDS_HMOD W_ERROR(0x594)
#define WERR_GLOBAL_ONLY_HOOK W_ERROR(0x595)
#define WERR_JOURNAL_HOOK_SET W_ERROR(0x596)
#define WERR_HOOK_NOT_INSTALLED W_ERROR(0x597)
#define WERR_INVALID_LB_MESSAGE W_ERROR(0x598)
#define WERR_SETCOUNT_ON_BAD_LB W_ERROR(0x599)
#define WERR_LB_WITHOUT_TABSTOPS W_ERROR(0x59a)
#define WERR_DESTROY_OBJECT_OF_OTHER_THREAD W_ERROR(0x59b)
#define WERR_CHILD_WINDOW_MENU W_ERROR(0x59c)
#define WERR_NO_SYSTEM_MENU W_ERROR(0x59d)
#define WERR_INVALID_MSGBOX_STYLE W_ERROR(0x59e)
#define WERR_INVALID_SPI_VALUE W_ERROR(0x59f)
#define WERR_SCREEN_ALREADY_LOCKED W_ERROR(0x5a0)
#define WERR_HWNDS_HAVE_DIFF_PARENT W_ERROR(0x5a1)
#define WERR_NOT_CHILD_WINDOW W_ERROR(0x5a2)
#define WERR_INVALID_GW_COMMAND W_ERROR(0x5a3)
#define WERR_INVALID_THREAD_ID W_ERROR(0x5a4)
#define WERR_NON_MDICHILD_WINDOW W_ERROR(0x5a5)
#define WERR_POPUP_ALREADY_ACTIVE W_ERROR(0x5a6)
#define WERR_NO_SCROLLBARS W_ERROR(0x5a7)
#define WERR_INVALID_SCROLLBAR_RANGE W_ERROR(0x5a8)
#define WERR_INVALID_SHOWWIN_COMMAND W_ERROR(0x5a9)
#define WERR_NO_SYSTEM_RESOURCES W_ERROR(0x5aa)
#define WERR_NONPAGED_SYSTEM_RESOURCES W_ERROR(0x5ab)
#define WERR_PAGED_SYSTEM_RESOURCES W_ERROR(0x5ac)
#define WERR_WORKING_SET_QUOTA W_ERROR(0x5ad)
#define WERR_PAGEFILE_QUOTA W_ERROR(0x5ae)
#define WERR_COMMITMENT_LIMIT W_ERROR(0x5af)
#define WERR_MENU_ITEM_NOT_FOUND W_ERROR(0x5b0)
#define WERR_INVALID_KEYBOARD_HANDLE W_ERROR(0x5b1)
#define WERR_HOOK_TYPE_NOT_ALLOWED W_ERROR(0x5b2)
#define WERR_REQUIRES_INTERACTIVE_WINDOWSTATION W_ERROR(0x5b3)
#define WERR_TIMEOUT W_ERROR(0x5b4)
#define WERR_INVALID_MONITOR_HANDLE W_ERROR(0x5b5)
#define WERR_INCORRECT_SIZE W_ERROR(0x5b6)
#define WERR_SYMLINK_CLASS_DISABLED W_ERROR(0x5b7)
#define WERR_SYMLINK_NOT_SUPPORTED W_ERROR(0x5b8)
#define WERR_EVENTLOG_FILE_CORRUPT W_ERROR(0x5dc)
#define WERR_EVENTLOG_CANT_START W_ERROR(0x5dd)
#define WERR_LOG_FILE_FULL W_ERROR(0x5de)
#define WERR_EVENTLOG_FILE_CHANGED W_ERROR(0x5df)
#define WERR_INVALID_TASK_NAME W_ERROR(0x60e)
#define WERR_INVALID_TASK_INDEX W_ERROR(0x60f)
#define WERR_THREAD_ALREADY_IN_TASK W_ERROR(0x610)
#define WERR_INSTALL_SERVICE_FAILURE W_ERROR(0x641)
#define WERR_INSTALL_USEREXIT W_ERROR(0x642)
#define WERR_INSTALL_FAILURE W_ERROR(0x643)
#define WERR_INSTALL_SUSPEND W_ERROR(0x644)
#define WERR_UNKNOWN_PRODUCT W_ERROR(0x645)
#define WERR_UNKNOWN_FEATURE W_ERROR(0x646)
#define WERR_UNKNOWN_COMPONENT W_ERROR(0x647)
#define WERR_UNKNOWN_PROPERTY W_ERROR(0x648)
#define WERR_INVALID_HANDLE_STATE W_ERROR(0x649)
#define WERR_BAD_CONFIGURATION W_ERROR(0x64a)
#define WERR_INDEX_ABSENT W_ERROR(0x64b)
#define WERR_INSTALL_SOURCE_ABSENT W_ERROR(0x64c)
#define WERR_INSTALL_PACKAGE_VERSION W_ERROR(0x64d)
#define WERR_PRODUCT_UNINSTALLED W_ERROR(0x64e)
#define WERR_BAD_QUERY_SYNTAX W_ERROR(0x64f)
#define WERR_INVALID_FIELD W_ERROR(0x650)
#define WERR_DEVICE_REMOVED W_ERROR(0x651)
#define WERR_INSTALL_ALREADY_RUNNING W_ERROR(0x652)
#define WERR_INSTALL_PACKAGE_OPEN_FAILED W_ERROR(0x653)
#define WERR_INSTALL_PACKAGE_INVALID W_ERROR(0x654)
#define WERR_INSTALL_UI_FAILURE W_ERROR(0x655)
#define WERR_INSTALL_LOG_FAILURE W_ERROR(0x656)
#define WERR_INSTALL_LANGUAGE_UNSUPPORTED W_ERROR(0x657)
#define WERR_INSTALL_TRANSFORM_FAILURE W_ERROR(0x658)
#define WERR_INSTALL_PACKAGE_REJECTED W_ERROR(0x659)
#define WERR_FUNCTION_NOT_CALLED W_ERROR(0x65a)
#define WERR_FUNCTION_FAILED W_ERROR(0x65b)
#define WERR_INVALID_TABLE W_ERROR(0x65c)
#define WERR_DATATYPE_MISMATCH W_ERROR(0x65d)
#define WERR_UNSUPPORTED_TYPE W_ERROR(0x65e)
#define WERR_CREATE_FAILED W_ERROR(0x65f)
#define WERR_INSTALL_TEMP_UNWRITABLE W_ERROR(0x660)
#define WERR_INSTALL_PLATFORM_UNSUPPORTED W_ERROR(0x661)
#define WERR_INSTALL_NOTUSED W_ERROR(0x662)
#define WERR_PATCH_PACKAGE_OPEN_FAILED W_ERROR(0x663)
#define WERR_PATCH_PACKAGE_INVALID W_ERROR(0x664)
#define WERR_PATCH_PACKAGE_UNSUPPORTED W_ERROR(0x665)
#define WERR_PRODUCT_VERSION W_ERROR(0x666)
#define WERR_INVALID_COMMAND_LINE W_ERROR(0x667)
#define WERR_INSTALL_REMOTE_DISALLOWED W_ERROR(0x668)
#define WERR_SUCCESS_REBOOT_INITIATED W_ERROR(0x669)
#define WERR_PATCH_TARGET_NOT_FOUND W_ERROR(0x66a)
#define WERR_PATCH_PACKAGE_REJECTED W_ERROR(0x66b)
#define WERR_INSTALL_TRANSFORM_REJECTED W_ERROR(0x66c)
#define WERR_INSTALL_REMOTE_PROHIBITED W_ERROR(0x66d)
#define WERR_PATCH_REMOVAL_UNSUPPORTED W_ERROR(0x66e)
#define WERR_UNKNOWN_PATCH W_ERROR(0x66f)
#define WERR_PATCH_NO_SEQUENCE W_ERROR(0x670)
#define WERR_PATCH_REMOVAL_DISALLOWED W_ERROR(0x671)
#define WERR_INVALID_PATCH_XML W_ERROR(0x672)
#define WERR_PATCH_MANAGED_ADVERTISED_PRODUCT W_ERROR(0x673)
#define WERR_INSTALL_SERVICE_SAFEBOOT W_ERROR(0x674)
#define WERR_RPC_S_INVALID_STRING_BINDING W_ERROR(0x6a4)
#define WERR_RPC_S_WRONG_KIND_OF_BINDING W_ERROR(0x6a5)
#define WERR_RPC_S_INVALID_BINDING W_ERROR(0x6a6)
#define WERR_RPC_S_PROTSEQ_NOT_SUPPORTED W_ERROR(0x6a7)
#define WERR_RPC_S_INVALID_RPC_PROTSEQ W_ERROR(0x6a8)
#define WERR_RPC_S_INVALID_STRING_UUID W_ERROR(0x6a9)
#define WERR_RPC_S_INVALID_ENDPOINT_FORMAT W_ERROR(0x6aa)
#define WERR_RPC_S_INVALID_NET_ADDR W_ERROR(0x6ab)
#define WERR_RPC_S_NO_ENDPOINT_FOUND W_ERROR(0x6ac)
#define WERR_RPC_S_INVALID_TIMEOUT W_ERROR(0x6ad)
#define WERR_RPC_S_OBJECT_NOT_FOUND W_ERROR(0x6ae)
#define WERR_RPC_S_ALREADY_REGISTERED W_ERROR(0x6af)
#define WERR_RPC_S_TYPE_ALREADY_REGISTERED W_ERROR(0x6b0)
#define WERR_RPC_S_ALREADY_LISTENING W_ERROR(0x6b1)
#define WERR_RPC_S_NO_PROTSEQS_REGISTERED W_ERROR(0x6b2)
#define WERR_RPC_S_NOT_LISTENING W_ERROR(0x6b3)
#define WERR_RPC_S_UNKNOWN_MGR_TYPE W_ERROR(0x6b4)
#define WERR_RPC_S_UNKNOWN_IF W_ERROR(0x6b5)
#define WERR_RPC_S_NO_BINDINGS W_ERROR(0x6b6)
#define WERR_RPC_S_NO_PROTSEQS W_ERROR(0x6b7)
#define WERR_RPC_S_CANT_CREATE_ENDPOINT W_ERROR(0x6b8)
#define WERR_RPC_S_OUT_OF_RESOURCES W_ERROR(0x6b9)
#define WERR_RPC_S_SERVER_UNAVAILABLE W_ERROR(0x6ba)
#define WERR_RPC_S_SERVER_TOO_BUSY W_ERROR(0x6bb)
#define WERR_RPC_S_INVALID_NETWORK_OPTIONS W_ERROR(0x6bc)
#define WERR_RPC_S_NO_CALL_ACTIVE W_ERROR(0x6bd)
#define WERR_RPC_S_CALL_FAILED W_ERROR(0x6be)
#define WERR_RPC_S_CALL_FAILED_DNE W_ERROR(0x6bf)
#define WERR_RPC_S_PROTOCOL_ERROR W_ERROR(0x6c0)
#define WERR_RPC_S_PROXY_ACCESS_DENIED W_ERROR(0x6c1)
#define WERR_RPC_S_UNSUPPORTED_TRANS_SYN W_ERROR(0x6c2)
#define WERR_RPC_S_UNSUPPORTED_TYPE W_ERROR(0x6c4)
#define WERR_RPC_S_INVALID_TAG W_ERROR(0x6c5)
#define WERR_RPC_S_INVALID_BOUND W_ERROR(0x6c6)
#define WERR_RPC_S_NO_ENTRY_NAME W_ERROR(0x6c7)
#define WERR_RPC_S_INVALID_NAME_SYNTAX W_ERROR(0x6c8)
#define WERR_RPC_S_UNSUPPORTED_NAME_SYNTAX W_ERROR(0x6c9)
#define WERR_RPC_S_UUID_NO_ADDRESS W_ERROR(0x6cb)
#define WERR_RPC_S_DUPLICATE_ENDPOINT W_ERROR(0x6cc)
#define WERR_RPC_S_UNKNOWN_AUTHN_TYPE W_ERROR(0x6cd)
#define WERR_RPC_S_MAX_CALLS_TOO_SMALL W_ERROR(0x6ce)
#define WERR_RPC_S_STRING_TOO_LONG W_ERROR(0x6cf)
#define WERR_RPC_S_PROTSEQ_NOT_FOUND W_ERROR(0x6d0)
#define WERR_RPC_S_PROCNUM_OUT_OF_RANGE W_ERROR(0x6d1)
#define WERR_RPC_S_BINDING_HAS_NO_AUTH W_ERROR(0x6d2)
#define WERR_RPC_S_UNKNOWN_AUTHN_SERVICE W_ERROR(0x6d3)
#define WERR_RPC_S_UNKNOWN_AUTHN_LEVEL W_ERROR(0x6d4)
#define WERR_RPC_S_INVALID_AUTH_IDENTITY W_ERROR(0x6d5)
#define WERR_RPC_S_UNKNOWN_AUTHZ_SERVICE W_ERROR(0x6d6)
#define WERR_EPT_S_INVALID_ENTRY W_ERROR(0x6d7)
#define WERR_EPT_S_CANT_PERFORM_OP W_ERROR(0x6d8)
#define WERR_EPT_S_NOT_REGISTERED W_ERROR(0x6d9)
#define WERR_RPC_S_NOTHING_TO_EXPORT W_ERROR(0x6da)
#define WERR_RPC_S_INCOMPLETE_NAME W_ERROR(0x6db)
#define WERR_RPC_S_INVALID_VERS_OPTION W_ERROR(0x6dc)
#define WERR_RPC_S_NO_MORE_MEMBERS W_ERROR(0x6dd)
#define WERR_RPC_S_NOT_ALL_OBJS_UNEXPORTED W_ERROR(0x6de)
#define WERR_RPC_S_INTERFACE_NOT_FOUND W_ERROR(0x6df)
#define WERR_RPC_S_ENTRY_ALREADY_EXISTS W_ERROR(0x6e0)
#define WERR_RPC_S_ENTRY_NOT_FOUND W_ERROR(0x6e1)
#define WERR_RPC_S_NAME_SERVICE_UNAVAILABLE W_ERROR(0x6e2)
#define WERR_RPC_S_INVALID_NAF_ID W_ERROR(0x6e3)
#define WERR_RPC_S_CANNOT_SUPPORT W_ERROR(0x6e4)
#define WERR_RPC_S_NO_CONTEXT_AVAILABLE W_ERROR(0x6e5)
#define WERR_RPC_S_INTERNAL_ERROR W_ERROR(0x6e6)
#define WERR_RPC_S_ZERO_DIVIDE W_ERROR(0x6e7)
#define WERR_RPC_S_ADDRESS_ERROR W_ERROR(0x6e8)
#define WERR_RPC_S_FP_DIV_ZERO W_ERROR(0x6e9)
#define WERR_RPC_S_FP_UNDERFLOW W_ERROR(0x6ea)
#define WERR_RPC_S_FP_OVERFLOW W_ERROR(0x6eb)
#define WERR_RPC_X_NO_MORE_ENTRIES W_ERROR(0x6ec)
#define WERR_RPC_X_SS_CHAR_TRANS_OPEN_FAIL W_ERROR(0x6ed)
#define WERR_RPC_X_SS_CHAR_TRANS_SHORT_FILE W_ERROR(0x6ee)
#define WERR_RPC_X_SS_IN_NULL_CONTEXT W_ERROR(0x6ef)
#define WERR_RPC_X_SS_CONTEXT_DAMAGED W_ERROR(0x6f1)
#define WERR_RPC_X_SS_HANDLES_MISMATCH W_ERROR(0x6f2)
#define WERR_RPC_X_SS_CANNOT_GET_CALL_HANDLE W_ERROR(0x6f3)
#define WERR_RPC_X_NULL_REF_POINTER W_ERROR(0x6f4)
#define WERR_RPC_X_ENUM_VALUE_OUT_OF_RANGE W_ERROR(0x6f5)
#define WERR_RPC_X_BYTE_COUNT_TOO_SMALL W_ERROR(0x6f6)
#define WERR_RPC_X_BAD_STUB_DATA W_ERROR(0x6f7)
#define WERR_INVALID_USER_BUFFER W_ERROR(0x6f8)
#define WERR_UNRECOGNIZED_MEDIA W_ERROR(0x6f9)
#define WERR_NO_TRUST_LSA_SECRET W_ERROR(0x6fa)
#define WERR_NO_TRUST_SAM_ACCOUNT W_ERROR(0x6fb)
#define WERR_TRUSTED_DOMAIN_FAILURE W_ERROR(0x6fc)
#define WERR_TRUSTED_RELATIONSHIP_FAILURE W_ERROR(0x6fd)
#define WERR_TRUST_FAILURE W_ERROR(0x6fe)
#define WERR_RPC_S_CALL_IN_PROGRESS W_ERROR(0x6ff)
#define WERR_NETLOGON_NOT_STARTED W_ERROR(0x700)
#define WERR_ACCOUNT_EXPIRED W_ERROR(0x701)
#define WERR_REDIRECTOR_HAS_OPEN_HANDLES W_ERROR(0x702)
#define WERR_PRINTER_DRIVER_ALREADY_INSTALLED W_ERROR(0x703)
#define WERR_UNKNOWN_PORT W_ERROR(0x704)
#define WERR_UNKNOWN_PRINTER_DRIVER W_ERROR(0x705)
#define WERR_UNKNOWN_PRINTPROCESSOR W_ERROR(0x706)
#define WERR_INVALID_SEPARATOR_FILE W_ERROR(0x707)
#define WERR_INVALID_PRIORITY W_ERROR(0x708)
#define WERR_INVALID_PRINTER_NAME W_ERROR(0x709)
#define WERR_PRINTER_ALREADY_EXISTS W_ERROR(0x70a)
#define WERR_INVALID_PRINTER_COMMAND W_ERROR(0x70b)
#define WERR_INVALID_DATATYPE W_ERROR(0x70c)
#define WERR_INVALID_ENVIRONMENT W_ERROR(0x70d)
#define WERR_RPC_S_NO_MORE_BINDINGS W_ERROR(0x70e)
#define WERR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT W_ERROR(0x70f)
#define WERR_NOLOGON_WORKSTATION_TRUST_ACCOUNT W_ERROR(0x710)
#define WERR_NOLOGON_SERVER_TRUST_ACCOUNT W_ERROR(0x711)
#define WERR_DOMAIN_TRUST_INCONSISTENT W_ERROR(0x712)
#define WERR_SERVER_HAS_OPEN_HANDLES W_ERROR(0x713)
#define WERR_RESOURCE_DATA_NOT_FOUND W_ERROR(0x714)
#define WERR_RESOURCE_TYPE_NOT_FOUND W_ERROR(0x715)
#define WERR_RESOURCE_NAME_NOT_FOUND W_ERROR(0x716)
#define WERR_RESOURCE_LANG_NOT_FOUND W_ERROR(0x717)
#define WERR_NOT_ENOUGH_QUOTA W_ERROR(0x718)
#define WERR_RPC_S_NO_INTERFACES W_ERROR(0x719)
#define WERR_RPC_S_CALL_CANCELLED W_ERROR(0x71a)
#define WERR_RPC_S_BINDING_INCOMPLETE W_ERROR(0x71b)
#define WERR_RPC_S_COMM_FAILURE W_ERROR(0x71c)
#define WERR_RPC_S_UNSUPPORTED_AUTHN_LEVEL W_ERROR(0x71d)
#define WERR_RPC_S_NO_PRINC_NAME W_ERROR(0x71e)
#define WERR_RPC_S_NOT_RPC_ERROR W_ERROR(0x71f)
#define WERR_RPC_S_UUID_LOCAL_ONLY W_ERROR(0x720)
#define WERR_RPC_S_SEC_PKG_ERROR W_ERROR(0x721)
#define WERR_RPC_S_NOT_CANCELLED W_ERROR(0x722)
#define WERR_RPC_X_INVALID_ES_ACTION W_ERROR(0x723)
#define WERR_RPC_X_WRONG_ES_VERSION W_ERROR(0x724)
#define WERR_RPC_X_WRONG_STUB_VERSION W_ERROR(0x725)
#define WERR_RPC_X_INVALID_PIPE_OBJECT W_ERROR(0x726)
#define WERR_RPC_X_WRONG_PIPE_ORDER W_ERROR(0x727)
#define WERR_RPC_X_WRONG_PIPE_VERSION W_ERROR(0x728)
#define WERR_RPC_S_GROUP_MEMBER_NOT_FOUND W_ERROR(0x76a)
#define WERR_EPT_S_CANT_CREATE W_ERROR(0x76b)
#define WERR_RPC_S_INVALID_OBJECT W_ERROR(0x76c)
#define WERR_INVALID_TIME W_ERROR(0x76d)
#define WERR_INVALID_FORM_NAME W_ERROR(0x76e)
#define WERR_INVALID_FORM_SIZE W_ERROR(0x76f)
#define WERR_ALREADY_WAITING W_ERROR(0x770)
#define WERR_PRINTER_DELETED W_ERROR(0x771)
#define WERR_INVALID_PRINTER_STATE W_ERROR(0x772)
#define WERR_PASSWORD_MUST_CHANGE W_ERROR(0x773)
#define WERR_DOMAIN_CONTROLLER_NOT_FOUND W_ERROR(0x774)
#define WERR_ACCOUNT_LOCKED_OUT W_ERROR(0x775)
#define WERR_OR_INVALID_OXID W_ERROR(0x776)
#define WERR_OR_INVALID_OID W_ERROR(0x777)
#define WERR_OR_INVALID_SET W_ERROR(0x778)
#define WERR_RPC_S_SEND_INCOMPLETE W_ERROR(0x779)
#define WERR_RPC_S_INVALID_ASYNC_HANDLE W_ERROR(0x77a)
#define WERR_RPC_S_INVALID_ASYNC_CALL W_ERROR(0x77b)
#define WERR_RPC_X_PIPE_CLOSED W_ERROR(0x77c)
#define WERR_RPC_X_PIPE_DISCIPLINE_ERROR W_ERROR(0x77d)
#define WERR_RPC_X_PIPE_EMPTY W_ERROR(0x77e)
#define WERR_NO_SITENAME W_ERROR(0x77f)
#define WERR_CANT_ACCESS_FILE W_ERROR(0x780)
#define WERR_CANT_RESOLVE_FILENAME W_ERROR(0x781)
#define WERR_RPC_S_ENTRY_TYPE_MISMATCH W_ERROR(0x782)
#define WERR_RPC_S_NOT_ALL_OBJS_EXPORTED W_ERROR(0x783)
#define WERR_RPC_S_INTERFACE_NOT_EXPORTED W_ERROR(0x784)
#define WERR_RPC_S_PROFILE_NOT_ADDED W_ERROR(0x785)
#define WERR_RPC_S_PRF_ELT_NOT_ADDED W_ERROR(0x786)
#define WERR_RPC_S_PRF_ELT_NOT_REMOVED W_ERROR(0x787)
#define WERR_RPC_S_GRP_ELT_NOT_ADDED W_ERROR(0x788)
#define WERR_RPC_S_GRP_ELT_NOT_REMOVED W_ERROR(0x789)
#define WERR_KM_DRIVER_BLOCKED W_ERROR(0x78a)
#define WERR_CONTEXT_EXPIRED W_ERROR(0x78b)
#define WERR_PER_USER_TRUST_QUOTA_EXCEEDED W_ERROR(0x78c)
#define WERR_ALL_USER_TRUST_QUOTA_EXCEEDED W_ERROR(0x78d)
#define WERR_USER_DELETE_TRUST_QUOTA_EXCEEDED W_ERROR(0x78e)
#define WERR_AUTHENTICATION_FIREWALL_FAILED W_ERROR(0x78f)
#define WERR_REMOTE_PRINT_CONNECTIONS_BLOCKED W_ERROR(0x790)
#define WERR_INVALID_PIXEL_FORMAT W_ERROR(0x7d0)
#define WERR_BAD_DRIVER W_ERROR(0x7d1)
#define WERR_INVALID_WINDOW_STYLE W_ERROR(0x7d2)
#define WERR_METAFILE_NOT_SUPPORTED W_ERROR(0x7d3)
#define WERR_TRANSFORM_NOT_SUPPORTED W_ERROR(0x7d4)
#define WERR_CLIPPING_NOT_SUPPORTED W_ERROR(0x7d5)
#define WERR_INVALID_CMM W_ERROR(0x7da)
#define WERR_INVALID_PROFILE W_ERROR(0x7db)
#define WERR_TAG_NOT_FOUND W_ERROR(0x7dc)
#define WERR_TAG_NOT_PRESENT W_ERROR(0x7dd)
#define WERR_DUPLICATE_TAG W_ERROR(0x7de)
#define WERR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE W_ERROR(0x7df)
#define WERR_PROFILE_NOT_FOUND W_ERROR(0x7e0)
#define WERR_INVALID_COLORSPACE W_ERROR(0x7e1)
#define WERR_ICM_NOT_ENABLED W_ERROR(0x7e2)
#define WERR_DELETING_ICM_XFORM W_ERROR(0x7e3)
#define WERR_INVALID_TRANSFORM W_ERROR(0x7e4)
#define WERR_COLORSPACE_MISMATCH W_ERROR(0x7e5)
#define WERR_INVALID_COLORINDEX W_ERROR(0x7e6)
#define WERR_PROFILE_DOES_NOT_MATCH_DEVICE W_ERROR(0x7e7)
#define WERR_NERR_NETNOTSTARTED W_ERROR(0x836)
#define WERR_NERR_UNKNOWNSERVER W_ERROR(0x837)
#define WERR_NERR_SHAREMEM W_ERROR(0x838)
#define WERR_NERR_NONETWORKRESOURCE W_ERROR(0x839)
#define WERR_NERR_REMOTEONLY W_ERROR(0x83a)
#define WERR_NERR_DEVNOTREDIRECTED W_ERROR(0x83b)
#define WERR_CONNECTED_OTHER_PASSWORD W_ERROR(0x83c)
#define WERR_CONNECTED_OTHER_PASSWORD_DEFAULT W_ERROR(0x83d)
#define WERR_NERR_SERVERNOTSTARTED W_ERROR(0x842)
#define WERR_NERR_ITEMNOTFOUND W_ERROR(0x843)
#define WERR_NERR_UNKNOWNDEVDIR W_ERROR(0x844)
#define WERR_NERR_REDIRECTEDPATH W_ERROR(0x845)
#define WERR_NERR_DUPLICATESHARE W_ERROR(0x846)
#define WERR_NERR_NOROOM W_ERROR(0x847)
#define WERR_NERR_TOOMANYITEMS W_ERROR(0x849)
#define WERR_NERR_INVALIDMAXUSERS W_ERROR(0x84a)
#define WERR_NERR_BUFTOOSMALL W_ERROR(0x84b)
#define WERR_NERR_REMOTEERR W_ERROR(0x84f)
#define WERR_NERR_LANMANINIERROR W_ERROR(0x853)
#define WERR_NERR_NETWORKERROR W_ERROR(0x858)
#define WERR_NERR_WKSTAINCONSISTENTSTATE W_ERROR(0x859)
#define WERR_NERR_WKSTANOTSTARTED W_ERROR(0x85a)
#define WERR_NERR_BROWSERNOTSTARTED W_ERROR(0x85b)
#define WERR_NERR_INTERNALERROR W_ERROR(0x85c)
#define WERR_NERR_BADTRANSACTCONFIG W_ERROR(0x85d)
#define WERR_NERR_INVALIDAPI W_ERROR(0x85e)
#define WERR_NERR_BADEVENTNAME W_ERROR(0x85f)
#define WERR_NERR_DUPNAMEREBOOT W_ERROR(0x860)
#define WERR_NERR_CFGCOMPNOTFOUND W_ERROR(0x862)
#define WERR_NERR_CFGPARAMNOTFOUND W_ERROR(0x863)
#define WERR_NERR_LINETOOLONG W_ERROR(0x865)
#define WERR_NERR_QNOTFOUND W_ERROR(0x866)
#define WERR_NERR_JOBNOTFOUND W_ERROR(0x867)
#define WERR_NERR_DESTNOTFOUND W_ERROR(0x868)
#define WERR_NERR_DESTEXISTS W_ERROR(0x869)
#define WERR_NERR_QEXISTS W_ERROR(0x86a)
#define WERR_NERR_QNOROOM W_ERROR(0x86b)
#define WERR_NERR_JOBNOROOM W_ERROR(0x86c)
#define WERR_NERR_DESTNOROOM W_ERROR(0x86d)
#define WERR_NERR_DESTIDLE W_ERROR(0x86e)
#define WERR_NERR_DESTINVALIDOP W_ERROR(0x86f)
#define WERR_NERR_PROCNORESPOND W_ERROR(0x870)
#define WERR_NERR_SPOOLERNOTLOADED W_ERROR(0x871)
#define WERR_NERR_DESTINVALIDSTATE W_ERROR(0x872)
#define WERR_NERR_QINVALIDSTATE W_ERROR(0x873)
#define WERR_NERR_JOBINVALIDSTATE W_ERROR(0x874)
#define WERR_NERR_SPOOLNOMEMORY W_ERROR(0x875)
#define WERR_NERR_DRIVERNOTFOUND W_ERROR(0x876)
#define WERR_NERR_DATATYPEINVALID W_ERROR(0x877)
#define WERR_NERR_PROCNOTFOUND W_ERROR(0x878)
#define WERR_NERR_SERVICETABLELOCKED W_ERROR(0x884)
#define WERR_NERR_SERVICETABLEFULL W_ERROR(0x885)
#define WERR_NERR_SERVICEINSTALLED W_ERROR(0x886)
#define WERR_NERR_SERVICEENTRYLOCKED W_ERROR(0x887)
#define WERR_NERR_SERVICENOTINSTALLED W_ERROR(0x888)
#define WERR_NERR_BADSERVICENAME W_ERROR(0x889)
#define WERR_NERR_SERVICECTLTIMEOUT W_ERROR(0x88a)
#define WERR_NERR_SERVICECTLBUSY W_ERROR(0x88b)
#define WERR_NERR_BADSERVICEPROGNAME W_ERROR(0x88c)
#define WERR_NERR_SERVICENOTCTRL W_ERROR(0x88d)
#define WERR_NERR_SERVICEKILLPROC W_ERROR(0x88e)
#define WERR_NERR_SERVICECTLNOTVALID W_ERROR(0x88f)
#define WERR_NERR_NOTINDISPATCHTBL W_ERROR(0x890)
#define WERR_NERR_BADCONTROLRECV W_ERROR(0x891)
#define WERR_NERR_SERVICENOTSTARTING W_ERROR(0x892)
#define WERR_NERR_ALREADYLOGGEDON W_ERROR(0x898)
#define WERR_NERR_NOTLOGGEDON W_ERROR(0x899)
#define WERR_NERR_BADUSERNAME W_ERROR(0x89a)
#define WERR_NERR_BADPASSWORD W_ERROR(0x89b)
#define WERR_NERR_UNABLETOADDNAME_W W_ERROR(0x89c)
#define WERR_NERR_UNABLETOADDNAME_F W_ERROR(0x89d)
#define WERR_NERR_UNABLETODELNAME_W W_ERROR(0x89e)
#define WERR_NERR_UNABLETODELNAME_F W_ERROR(0x89f)
#define WERR_NERR_LOGONSPAUSED W_ERROR(0x8a1)
#define WERR_NERR_LOGONSERVERCONFLICT W_ERROR(0x8a2)
#define WERR_NERR_LOGONNOUSERPATH W_ERROR(0x8a3)
#define WERR_NERR_LOGONSCRIPTERROR W_ERROR(0x8a4)
#define WERR_NERR_STANDALONELOGON W_ERROR(0x8a6)
#define WERR_NERR_LOGONSERVERNOTFOUND W_ERROR(0x8a7)
#define WERR_NERR_LOGONDOMAINEXISTS W_ERROR(0x8a8)
#define WERR_NERR_NONVALIDATEDLOGON W_ERROR(0x8a9)
#define WERR_NERR_ACFNOTFOUND W_ERROR(0x8ab)
#define WERR_NERR_GROUPNOTFOUND W_ERROR(0x8ac)
#define WERR_NERR_USERNOTFOUND W_ERROR(0x8ad)
#define WERR_NERR_RESOURCENOTFOUND W_ERROR(0x8ae)
#define WERR_NERR_GROUPEXISTS W_ERROR(0x8af)
#define WERR_NERR_USEREXISTS W_ERROR(0x8b0)
#define WERR_NERR_RESOURCEEXISTS W_ERROR(0x8b1)
#define WERR_NERR_NOTPRIMARY W_ERROR(0x8b2)
#define WERR_NERR_ACFNOTLOADED W_ERROR(0x8b3)
#define WERR_NERR_ACFNOROOM W_ERROR(0x8b4)
#define WERR_NERR_ACFFILEIOFAIL W_ERROR(0x8b5)
#define WERR_NERR_ACFTOOMANYLISTS W_ERROR(0x8b6)
#define WERR_NERR_USERLOGON W_ERROR(0x8b7)
#define WERR_NERR_ACFNOPARENT W_ERROR(0x8b8)
#define WERR_NERR_CANNOTGROWSEGMENT W_ERROR(0x8b9)
#define WERR_NERR_SPEGROUPOP W_ERROR(0x8ba)
#define WERR_NERR_NOTINCACHE W_ERROR(0x8bb)
#define WERR_NERR_USERINGROUP W_ERROR(0x8bc)
#define WERR_NERR_USERNOTINGROUP W_ERROR(0x8bd)
#define WERR_NERR_ACCOUNTUNDEFINED W_ERROR(0x8be)
#define WERR_NERR_ACCOUNTEXPIRED W_ERROR(0x8bf)
#define WERR_NERR_INVALIDWORKSTATION W_ERROR(0x8c0)
#define WERR_NERR_INVALIDLOGONHOURS W_ERROR(0x8c1)
#define WERR_NERR_PASSWORDEXPIRED W_ERROR(0x8c2)
#define WERR_NERR_PASSWORDCANTCHANGE W_ERROR(0x8c3)
#define WERR_NERR_PASSWORDHISTCONFLICT W_ERROR(0x8c4)
#define WERR_NERR_PASSWORDTOOSHORT W_ERROR(0x8c5)
#define WERR_NERR_PASSWORDTOORECENT W_ERROR(0x8c6)
#define WERR_NERR_INVALIDDATABASE W_ERROR(0x8c7)
#define WERR_NERR_DATABASEUPTODATE W_ERROR(0x8c8)
#define WERR_NERR_SYNCREQUIRED W_ERROR(0x8c9)
#define WERR_NERR_USENOTFOUND W_ERROR(0x8ca)
#define WERR_NERR_BADASGTYPE W_ERROR(0x8cb)
#define WERR_NERR_DEVICEISSHARED W_ERROR(0x8cc)
#define WERR_NERR_NOCOMPUTERNAME W_ERROR(0x8de)
#define WERR_NERR_MSGALREADYSTARTED W_ERROR(0x8df)
#define WERR_NERR_MSGINITFAILED W_ERROR(0x8e0)
#define WERR_NERR_NAMENOTFOUND W_ERROR(0x8e1)
#define WERR_NERR_ALREADYFORWARDED W_ERROR(0x8e2)
#define WERR_NERR_ADDFORWARDED W_ERROR(0x8e3)
#define WERR_NERR_ALREADYEXISTS W_ERROR(0x8e4)
#define WERR_NERR_TOOMANYNAMES W_ERROR(0x8e5)
#define WERR_NERR_DELCOMPUTERNAME W_ERROR(0x8e6)
#define WERR_NERR_LOCALFORWARD W_ERROR(0x8e7)
#define WERR_NERR_GRPMSGPROCESSOR W_ERROR(0x8e8)
#define WERR_NERR_PAUSEDREMOTE W_ERROR(0x8e9)
#define WERR_NERR_BADRECEIVE W_ERROR(0x8ea)
#define WERR_NERR_NAMEINUSE W_ERROR(0x8eb)
#define WERR_NERR_MSGNOTSTARTED W_ERROR(0x8ec)
#define WERR_NERR_NOTLOCALNAME W_ERROR(0x8ed)
#define WERR_NERR_NOFORWARDNAME W_ERROR(0x8ee)
#define WERR_NERR_REMOTEFULL W_ERROR(0x8ef)
#define WERR_NERR_NAMENOTFORWARDED W_ERROR(0x8f0)
#define WERR_NERR_TRUNCATEDBROADCAST W_ERROR(0x8f1)
#define WERR_NERR_INVALIDDEVICE W_ERROR(0x8f6)
#define WERR_NERR_WRITEFAULT W_ERROR(0x8f7)
#define WERR_NERR_DUPLICATENAME W_ERROR(0x8f9)
#define WERR_NERR_DELETELATER W_ERROR(0x8fa)
#define WERR_NERR_INCOMPLETEDEL W_ERROR(0x8fb)
#define WERR_NERR_MULTIPLENETS W_ERROR(0x8fc)
#define WERR_NERR_NETNAMENOTFOUND W_ERROR(0x906)
#define WERR_NERR_DEVICENOTSHARED W_ERROR(0x907)
#define WERR_NERR_CLIENTNAMENOTFOUND W_ERROR(0x908)
#define WERR_NERR_FILEIDNOTFOUND W_ERROR(0x90a)
#define WERR_NERR_EXECFAILURE W_ERROR(0x90b)
#define WERR_NERR_TMPFILE W_ERROR(0x90c)
#define WERR_NERR_TOOMUCHDATA W_ERROR(0x90d)
#define WERR_NERR_DEVICESHARECONFLICT W_ERROR(0x90e)
#define WERR_NERR_BROWSERTABLEINCOMPLETE W_ERROR(0x90f)
#define WERR_NERR_NOTLOCALDOMAIN W_ERROR(0x910)
#define WERR_NERR_ISDFSSHARE W_ERROR(0x911)
#define WERR_NERR_DEVINVALIDOPCODE W_ERROR(0x91b)
#define WERR_NERR_DEVNOTFOUND W_ERROR(0x91c)
#define WERR_NERR_DEVNOTOPEN W_ERROR(0x91d)
#define WERR_NERR_BADQUEUEDEVSTRING W_ERROR(0x91e)
#define WERR_NERR_BADQUEUEPRIORITY W_ERROR(0x91f)
#define WERR_NERR_NOCOMMDEVS W_ERROR(0x921)
#define WERR_NERR_QUEUENOTFOUND W_ERROR(0x922)
#define WERR_NERR_BADDEVSTRING W_ERROR(0x924)
#define WERR_NERR_BADDEV W_ERROR(0x925)
#define WERR_NERR_INUSEBYSPOOLER W_ERROR(0x926)
#define WERR_NERR_COMMDEVINUSE W_ERROR(0x927)
#define WERR_NERR_INVALIDCOMPUTER W_ERROR(0x92f)
#define WERR_NERR_MAXLENEXCEEDED W_ERROR(0x932)
#define WERR_NERR_BADCOMPONENT W_ERROR(0x934)
#define WERR_NERR_CANTTYPE W_ERROR(0x935)
#define WERR_NERR_TOOMANYENTRIES W_ERROR(0x93a)
#define WERR_NERR_PROFILEFILETOOBIG W_ERROR(0x942)
#define WERR_NERR_PROFILEOFFSET W_ERROR(0x943)
#define WERR_NERR_PROFILECLEANUP W_ERROR(0x944)
#define WERR_NERR_PROFILEUNKNOWNCMD W_ERROR(0x945)
#define WERR_NERR_PROFILELOADERR W_ERROR(0x946)
#define WERR_NERR_PROFILESAVEERR W_ERROR(0x947)
#define WERR_NERR_LOGOVERFLOW W_ERROR(0x949)
#define WERR_NERR_LOGFILECHANGED W_ERROR(0x94a)
#define WERR_NERR_LOGFILECORRUPT W_ERROR(0x94b)
#define WERR_NERR_SOURCEISDIR W_ERROR(0x94c)
#define WERR_NERR_BADSOURCE W_ERROR(0x94d)
#define WERR_NERR_BADDEST W_ERROR(0x94e)
#define WERR_NERR_DIFFERENTSERVERS W_ERROR(0x94f)
#define WERR_NERR_RUNSRVPAUSED W_ERROR(0x951)
#define WERR_NERR_ERRCOMMRUNSRV W_ERROR(0x955)
#define WERR_NERR_ERROREXECINGGHOST W_ERROR(0x957)
#define WERR_NERR_SHARENOTFOUND W_ERROR(0x958)
#define WERR_NERR_INVALIDLANA W_ERROR(0x960)
#define WERR_NERR_OPENFILES W_ERROR(0x961)
#define WERR_NERR_ACTIVECONNS W_ERROR(0x962)
#define WERR_NERR_BADPASSWORDCORE W_ERROR(0x963)
#define WERR_NERR_DEVINUSE W_ERROR(0x964)
#define WERR_NERR_LOCALDRIVE W_ERROR(0x965)
#define WERR_NERR_ALERTEXISTS W_ERROR(0x97e)
#define WERR_NERR_TOOMANYALERTS W_ERROR(0x97f)
#define WERR_NERR_NOSUCHALERT W_ERROR(0x980)
#define WERR_NERR_BADRECIPIENT W_ERROR(0x981)
#define WERR_NERR_ACCTLIMITEXCEEDED W_ERROR(0x982)
#define WERR_NERR_INVALIDLOGSEEK W_ERROR(0x988)
#define WERR_NERR_BADUASCONFIG W_ERROR(0x992)
#define WERR_NERR_INVALIDUASOP W_ERROR(0x993)
#define WERR_NERR_LASTADMIN W_ERROR(0x994)
#define WERR_NERR_DCNOTFOUND W_ERROR(0x995)
#define WERR_NERR_LOGONTRACKINGERROR W_ERROR(0x996)
#define WERR_NERR_NETLOGONNOTSTARTED W_ERROR(0x997)
#define WERR_NERR_CANNOTGROWUASFILE W_ERROR(0x998)
#define WERR_NERR_TIMEDIFFATDC W_ERROR(0x999)
#define WERR_NERR_PASSWORDMISMATCH W_ERROR(0x99a)
#define WERR_NERR_NOSUCHSERVER W_ERROR(0x99c)
#define WERR_NERR_NOSUCHSESSION W_ERROR(0x99d)
#define WERR_NERR_NOSUCHCONNECTION W_ERROR(0x99e)
#define WERR_NERR_TOOMANYSERVERS W_ERROR(0x99f)
#define WERR_NERR_TOOMANYSESSIONS W_ERROR(0x9a0)
#define WERR_NERR_TOOMANYCONNECTIONS W_ERROR(0x9a1)
#define WERR_NERR_TOOMANYFILES W_ERROR(0x9a2)
#define WERR_NERR_NOALTERNATESERVERS W_ERROR(0x9a3)
#define WERR_NERR_TRYDOWNLEVEL W_ERROR(0x9a6)
#define WERR_NERR_UPSDRIVERNOTSTARTED W_ERROR(0x9b0)
#define WERR_NERR_UPSINVALIDCONFIG W_ERROR(0x9b1)
#define WERR_NERR_UPSINVALIDCOMMPORT W_ERROR(0x9b2)
#define WERR_NERR_UPSSIGNALASSERTED W_ERROR(0x9b3)
#define WERR_NERR_UPSSHUTDOWNFAILED W_ERROR(0x9b4)
#define WERR_NERR_BADDOSRETCODE W_ERROR(0x9c4)
#define WERR_NERR_PROGNEEDSEXTRAMEM W_ERROR(0x9c5)
#define WERR_NERR_BADDOSFUNCTION W_ERROR(0x9c6)
#define WERR_NERR_REMOTEBOOTFAILED W_ERROR(0x9c7)
#define WERR_NERR_BADFILECHECKSUM W_ERROR(0x9c8)
#define WERR_NERR_NORPLBOOTSYSTEM W_ERROR(0x9c9)
#define WERR_NERR_RPLLOADRNETBIOSERR W_ERROR(0x9ca)
#define WERR_NERR_RPLLOADRDISKERR W_ERROR(0x9cb)
#define WERR_NERR_IMAGEPARAMERR W_ERROR(0x9cc)
#define WERR_NERR_TOOMANYIMAGEPARAMS W_ERROR(0x9cd)
#define WERR_NERR_NONDOSFLOPPYUSED W_ERROR(0x9ce)
#define WERR_NERR_RPLBOOTRESTART W_ERROR(0x9cf)
#define WERR_NERR_RPLSRVRCALLFAILED W_ERROR(0x9d0)
#define WERR_NERR_CANTCONNECTRPLSRVR W_ERROR(0x9d1)
#define WERR_NERR_CANTOPENIMAGEFILE W_ERROR(0x9d2)
#define WERR_NERR_CALLINGRPLSRVR W_ERROR(0x9d3)
#define WERR_NERR_STARTINGRPLBOOT W_ERROR(0x9d4)
#define WERR_NERR_RPLBOOTSERVICETERM W_ERROR(0x9d5)
#define WERR_NERR_RPLBOOTSTARTFAILED W_ERROR(0x9d6)
#define WERR_NERR_RPL_CONNECTED W_ERROR(0x9d7)
#define WERR_NERR_BROWSERCONFIGUREDTONOTRUN W_ERROR(0x9f6)
#define WERR_NERR_RPLNOADAPTERSSTARTED W_ERROR(0xa32)
#define WERR_NERR_RPLBADREGISTRY W_ERROR(0xa33)
#define WERR_NERR_RPLBADDATABASE W_ERROR(0xa34)
#define WERR_NERR_RPLRPLFILESSHARE W_ERROR(0xa35)
#define WERR_NERR_RPLNOTRPLSERVER W_ERROR(0xa36)
#define WERR_NERR_RPLCANNOTENUM W_ERROR(0xa37)
#define WERR_NERR_RPLWKSTAINFOCORRUPTED W_ERROR(0xa38)
#define WERR_NERR_RPLWKSTANOTFOUND W_ERROR(0xa39)
#define WERR_NERR_RPLWKSTANAMEUNAVAILABLE W_ERROR(0xa3a)
#define WERR_NERR_RPLPROFILEINFOCORRUPTED W_ERROR(0xa3b)
#define WERR_NERR_RPLPROFILENOTFOUND W_ERROR(0xa3c)
#define WERR_NERR_RPLPROFILENAMEUNAVAILABLE W_ERROR(0xa3d)
#define WERR_NERR_RPLPROFILENOTEMPTY W_ERROR(0xa3e)
#define WERR_NERR_RPLCONFIGINFOCORRUPTED W_ERROR(0xa3f)
#define WERR_NERR_RPLCONFIGNOTFOUND W_ERROR(0xa40)
#define WERR_NERR_RPLADAPTERINFOCORRUPTED W_ERROR(0xa41)
#define WERR_NERR_RPLINTERNAL W_ERROR(0xa42)
#define WERR_NERR_RPLVENDORINFOCORRUPTED W_ERROR(0xa43)
#define WERR_NERR_RPLBOOTINFOCORRUPTED W_ERROR(0xa44)
#define WERR_NERR_RPLWKSTANEEDSUSERACCT W_ERROR(0xa45)
#define WERR_NERR_RPLNEEDSRPLUSERACCT W_ERROR(0xa46)
#define WERR_NERR_RPLBOOTNOTFOUND W_ERROR(0xa47)
#define WERR_NERR_RPLINCOMPATIBLEPROFILE W_ERROR(0xa48)
#define WERR_NERR_RPLADAPTERNAMEUNAVAILABLE W_ERROR(0xa49)
#define WERR_NERR_RPLCONFIGNOTEMPTY W_ERROR(0xa4a)
#define WERR_NERR_RPLBOOTINUSE W_ERROR(0xa4b)
#define WERR_NERR_RPLBACKUPDATABASE W_ERROR(0xa4c)
#define WERR_NERR_RPLADAPTERNOTFOUND W_ERROR(0xa4d)
#define WERR_NERR_RPLVENDORNOTFOUND W_ERROR(0xa4e)
#define WERR_NERR_RPLVENDORNAMEUNAVAILABLE W_ERROR(0xa4f)
#define WERR_NERR_RPLBOOTNAMEUNAVAILABLE W_ERROR(0xa50)
#define WERR_NERR_RPLCONFIGNAMEUNAVAILABLE W_ERROR(0xa51)
#define WERR_NERR_DFSINTERNALCORRUPTION W_ERROR(0xa64)
#define WERR_NERR_DFSVOLUMEDATACORRUPT W_ERROR(0xa65)
#define WERR_NERR_DFSNOSUCHVOLUME W_ERROR(0xa66)
#define WERR_NERR_DFSVOLUMEALREADYEXISTS W_ERROR(0xa67)
#define WERR_NERR_DFSALREADYSHARED W_ERROR(0xa68)
#define WERR_NERR_DFSNOSUCHSHARE W_ERROR(0xa69)
#define WERR_NERR_DFSNOTALEAFVOLUME W_ERROR(0xa6a)
#define WERR_NERR_DFSLEAFVOLUME W_ERROR(0xa6b)
#define WERR_NERR_DFSVOLUMEHASMULTIPLESERVERS W_ERROR(0xa6c)
#define WERR_NERR_DFSCANTCREATEJUNCTIONPOINT W_ERROR(0xa6d)
#define WERR_NERR_DFSSERVERNOTDFSAWARE W_ERROR(0xa6e)
#define WERR_NERR_DFSBADRENAMEPATH W_ERROR(0xa6f)
#define WERR_NERR_DFSVOLUMEISOFFLINE W_ERROR(0xa70)
#define WERR_NERR_DFSNOSUCHSERVER W_ERROR(0xa71)
#define WERR_NERR_DFSCYCLICALNAME W_ERROR(0xa72)
#define WERR_NERR_DFSNOTSUPPORTEDINSERVERDFS W_ERROR(0xa73)
#define WERR_NERR_DFSDUPLICATESERVICE W_ERROR(0xa74)
#define WERR_NERR_DFSCANTREMOVELASTSERVERSHARE W_ERROR(0xa75)
#define WERR_NERR_DFSVOLUMEISINTERDFS W_ERROR(0xa76)
#define WERR_NERR_DFSINCONSISTENT W_ERROR(0xa77)
#define WERR_NERR_DFSSERVERUPGRADED W_ERROR(0xa78)
#define WERR_NERR_DFSDATAISIDENTICAL W_ERROR(0xa79)
#define WERR_NERR_DFSCANTREMOVEDFSROOT W_ERROR(0xa7a)
#define WERR_NERR_DFSCHILDORPARENTINDFS W_ERROR(0xa7b)
#define WERR_NERR_DFSINTERNALERROR W_ERROR(0xa82)
#define WERR_NERR_SETUPALREADYJOINED W_ERROR(0xa83)
#define WERR_NERR_SETUPNOTJOINED W_ERROR(0xa84)
#define WERR_NERR_SETUPDOMAINCONTROLLER W_ERROR(0xa85)
#define WERR_NERR_DEFAULTJOINREQUIRED W_ERROR(0xa86)
#define WERR_NERR_INVALIDWORKGROUPNAME W_ERROR(0xa87)
#define WERR_NERR_NAMEUSESINCOMPATIBLECODEPAGE W_ERROR(0xa88)
#define WERR_NERR_COMPUTERACCOUNTNOTFOUND W_ERROR(0xa89)
#define WERR_NERR_PERSONALSKU W_ERROR(0xa8a)
#define WERR_NERR_PASSWORDMUSTCHANGE W_ERROR(0xa8d)
#define WERR_NERR_ACCOUNTLOCKEDOUT W_ERROR(0xa8e)
#define WERR_NERR_PASSWORDTOOLONG W_ERROR(0xa8f)
#define WERR_NERR_PASSWORDNOTCOMPLEXENOUGH W_ERROR(0xa90)
#define WERR_NERR_PASSWORDFILTERERROR W_ERROR(0xa91)
#define WERR_UNKNOWN_PRINT_MONITOR W_ERROR(0xbb8)
#define WERR_PRINTER_DRIVER_IN_USE W_ERROR(0xbb9)
#define WERR_SPOOL_FILE_NOT_FOUND W_ERROR(0xbba)
#define WERR_SPL_NO_STARTDOC W_ERROR(0xbbb)
#define WERR_SPL_NO_ADDJOB W_ERROR(0xbbc)
#define WERR_PRINT_PROCESSOR_ALREADY_INSTALLED W_ERROR(0xbbd)
#define WERR_PRINT_MONITOR_ALREADY_INSTALLED W_ERROR(0xbbe)
#define WERR_INVALID_PRINT_MONITOR W_ERROR(0xbbf)
#define WERR_PRINT_MONITOR_IN_USE W_ERROR(0xbc0)
#define WERR_PRINTER_HAS_JOBS_QUEUED W_ERROR(0xbc1)
#define WERR_SUCCESS_REBOOT_REQUIRED W_ERROR(0xbc2)
#define WERR_SUCCESS_RESTART_REQUIRED W_ERROR(0xbc3)
#define WERR_PRINTER_NOT_FOUND W_ERROR(0xbc4)
#define WERR_PRINTER_DRIVER_WARNED W_ERROR(0xbc5)
#define WERR_PRINTER_DRIVER_BLOCKED W_ERROR(0xbc6)
#define WERR_PRINTER_DRIVER_PACKAGE_IN_USE W_ERROR(0xbc7)
#define WERR_CORE_DRIVER_PACKAGE_NOT_FOUND W_ERROR(0xbc8)
#define WERR_FAIL_REBOOT_REQUIRED W_ERROR(0xbc9)
#define WERR_FAIL_REBOOT_INITIATED W_ERROR(0xbca)
#define WERR_PRINTER_DRIVER_DOWNLOAD_NEEDED W_ERROR(0xbcb)
#define WERR_PRINTER_NOT_SHAREABLE W_ERROR(0xbce)
#define WERR_IO_REISSUE_AS_CACHED W_ERROR(0xf6e)
#define WERR_WINS_INTERNAL W_ERROR(0xfa0)
#define WERR_CAN_NOT_DEL_LOCAL_WINS W_ERROR(0xfa1)
#define WERR_STATIC_INIT W_ERROR(0xfa2)
#define WERR_INC_BACKUP W_ERROR(0xfa3)
#define WERR_FULL_BACKUP W_ERROR(0xfa4)
#define WERR_REC_NON_EXISTENT W_ERROR(0xfa5)
#define WERR_RPL_NOT_ALLOWED W_ERROR(0xfa6)
#define WERR_PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED W_ERROR(0xfd2)
#define WERR_PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO W_ERROR(0xfd3)
#define WERR_PEERDIST_ERROR_MISSING_DATA W_ERROR(0xfd4)
#define WERR_PEERDIST_ERROR_NO_MORE W_ERROR(0xfd5)
#define WERR_PEERDIST_ERROR_NOT_INITIALIZED W_ERROR(0xfd6)
#define WERR_PEERDIST_ERROR_ALREADY_INITIALIZED W_ERROR(0xfd7)
#define WERR_PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS W_ERROR(0xfd8)
#define WERR_PEERDIST_ERROR_INVALIDATED W_ERROR(0xfd9)
#define WERR_PEERDIST_ERROR_ALREADY_EXISTS W_ERROR(0xfda)
#define WERR_PEERDIST_ERROR_OPERATION_NOTFOUND W_ERROR(0xfdb)
#define WERR_PEERDIST_ERROR_ALREADY_COMPLETED W_ERROR(0xfdc)
#define WERR_PEERDIST_ERROR_OUT_OF_BOUNDS W_ERROR(0xfdd)
#define WERR_PEERDIST_ERROR_VERSION_UNSUPPORTED W_ERROR(0xfde)
#define WERR_PEERDIST_ERROR_INVALID_CONFIGURATION W_ERROR(0xfdf)
#define WERR_PEERDIST_ERROR_NOT_LICENSED W_ERROR(0xfe0)
#define WERR_PEERDIST_ERROR_SERVICE_UNAVAILABLE W_ERROR(0xfe1)
#define WERR_DHCP_ADDRESS_CONFLICT W_ERROR(0x1004)
#define WERR_WMI_GUID_NOT_FOUND W_ERROR(0x1068)
#define WERR_WMI_INSTANCE_NOT_FOUND W_ERROR(0x1069)
#define WERR_WMI_ITEMID_NOT_FOUND W_ERROR(0x106a)
#define WERR_WMI_TRY_AGAIN W_ERROR(0x106b)
#define WERR_WMI_DP_NOT_FOUND W_ERROR(0x106c)
#define WERR_WMI_UNRESOLVED_INSTANCE_REF W_ERROR(0x106d)
#define WERR_WMI_ALREADY_ENABLED W_ERROR(0x106e)
#define WERR_WMI_GUID_DISCONNECTED W_ERROR(0x106f)
#define WERR_WMI_SERVER_UNAVAILABLE W_ERROR(0x1070)
#define WERR_WMI_DP_FAILED W_ERROR(0x1071)
#define WERR_WMI_INVALID_MOF W_ERROR(0x1072)
#define WERR_WMI_INVALID_REGINFO W_ERROR(0x1073)
#define WERR_WMI_ALREADY_DISABLED W_ERROR(0x1074)
#define WERR_WMI_READ_ONLY W_ERROR(0x1075)
#define WERR_WMI_SET_FAILURE W_ERROR(0x1076)
#define WERR_INVALID_MEDIA W_ERROR(0x10cc)
#define WERR_INVALID_LIBRARY W_ERROR(0x10cd)
#define WERR_INVALID_MEDIA_POOL W_ERROR(0x10ce)
#define WERR_DRIVE_MEDIA_MISMATCH W_ERROR(0x10cf)
#define WERR_MEDIA_OFFLINE W_ERROR(0x10d0)
#define WERR_LIBRARY_OFFLINE W_ERROR(0x10d1)
#define WERR_EMPTY W_ERROR(0x10d2)
#define WERR_NOT_EMPTY W_ERROR(0x10d3)
#define WERR_MEDIA_UNAVAILABLE W_ERROR(0x10d4)
#define WERR_RESOURCE_DISABLED W_ERROR(0x10d5)
#define WERR_INVALID_CLEANER W_ERROR(0x10d6)
#define WERR_UNABLE_TO_CLEAN W_ERROR(0x10d7)
#define WERR_OBJECT_NOT_FOUND W_ERROR(0x10d8)
#define WERR_DATABASE_FAILURE W_ERROR(0x10d9)
#define WERR_DATABASE_FULL W_ERROR(0x10da)
#define WERR_MEDIA_INCOMPATIBLE W_ERROR(0x10db)
#define WERR_RESOURCE_NOT_PRESENT W_ERROR(0x10dc)
#define WERR_INVALID_OPERATION W_ERROR(0x10dd)
#define WERR_MEDIA_NOT_AVAILABLE W_ERROR(0x10de)
#define WERR_DEVICE_NOT_AVAILABLE W_ERROR(0x10df)
#define WERR_REQUEST_REFUSED W_ERROR(0x10e0)
#define WERR_INVALID_DRIVE_OBJECT W_ERROR(0x10e1)
#define WERR_LIBRARY_FULL W_ERROR(0x10e2)
#define WERR_MEDIUM_NOT_ACCESSIBLE W_ERROR(0x10e3)
#define WERR_UNABLE_TO_LOAD_MEDIUM W_ERROR(0x10e4)
#define WERR_UNABLE_TO_INVENTORY_DRIVE W_ERROR(0x10e5)
#define WERR_UNABLE_TO_INVENTORY_SLOT W_ERROR(0x10e6)
#define WERR_UNABLE_TO_INVENTORY_TRANSPORT W_ERROR(0x10e7)
#define WERR_TRANSPORT_FULL W_ERROR(0x10e8)
#define WERR_CONTROLLING_IEPORT W_ERROR(0x10e9)
#define WERR_UNABLE_TO_EJECT_MOUNTED_MEDIA W_ERROR(0x10ea)
#define WERR_CLEANER_SLOT_SET W_ERROR(0x10eb)
#define WERR_CLEANER_SLOT_NOT_SET W_ERROR(0x10ec)
#define WERR_CLEANER_CARTRIDGE_SPENT W_ERROR(0x10ed)
#define WERR_UNEXPECTED_OMID W_ERROR(0x10ee)
#define WERR_CANT_DELETE_LAST_ITEM W_ERROR(0x10ef)
#define WERR_MESSAGE_EXCEEDS_MAX_SIZE W_ERROR(0x10f0)
#define WERR_VOLUME_CONTAINS_SYS_FILES W_ERROR(0x10f1)
#define WERR_INDIGENOUS_TYPE W_ERROR(0x10f2)
#define WERR_NO_SUPPORTING_DRIVES W_ERROR(0x10f3)
#define WERR_CLEANER_CARTRIDGE_INSTALLED W_ERROR(0x10f4)
#define WERR_IEPORT_FULL W_ERROR(0x10f5)
#define WERR_FILE_OFFLINE W_ERROR(0x10fe)
#define WERR_REMOTE_STORAGE_NOT_ACTIVE W_ERROR(0x10ff)
#define WERR_REMOTE_STORAGE_MEDIA_ERROR W_ERROR(0x1100)
#define WERR_NOT_A_REPARSE_POINT W_ERROR(0x1126)
#define WERR_REPARSE_ATTRIBUTE_CONFLICT W_ERROR(0x1127)
#define WERR_INVALID_REPARSE_DATA W_ERROR(0x1128)
#define WERR_REPARSE_TAG_INVALID W_ERROR(0x1129)
#define WERR_REPARSE_TAG_MISMATCH W_ERROR(0x112a)
#define WERR_VOLUME_NOT_SIS_ENABLED W_ERROR(0x1194)
#define WERR_DEPENDENT_RESOURCE_EXISTS W_ERROR(0x1389)
#define WERR_DEPENDENCY_NOT_FOUND W_ERROR(0x138a)
#define WERR_DEPENDENCY_ALREADY_EXISTS W_ERROR(0x138b)
#define WERR_RESOURCE_NOT_ONLINE W_ERROR(0x138c)
#define WERR_HOST_NODE_NOT_AVAILABLE W_ERROR(0x138d)
#define WERR_RESOURCE_NOT_AVAILABLE W_ERROR(0x138e)
#define WERR_RESOURCE_NOT_FOUND W_ERROR(0x138f)
#define WERR_SHUTDOWN_CLUSTER W_ERROR(0x1390)
#define WERR_CANT_EVICT_ACTIVE_NODE W_ERROR(0x1391)
#define WERR_OBJECT_ALREADY_EXISTS W_ERROR(0x1392)
#define WERR_OBJECT_IN_LIST W_ERROR(0x1393)
#define WERR_GROUP_NOT_AVAILABLE W_ERROR(0x1394)
#define WERR_GROUP_NOT_FOUND W_ERROR(0x1395)
#define WERR_GROUP_NOT_ONLINE W_ERROR(0x1396)
#define WERR_HOST_NODE_NOT_RESOURCE_OWNER W_ERROR(0x1397)
#define WERR_HOST_NODE_NOT_GROUP_OWNER W_ERROR(0x1398)
#define WERR_RESMON_CREATE_FAILED W_ERROR(0x1399)
#define WERR_RESMON_ONLINE_FAILED W_ERROR(0x139a)
#define WERR_RESOURCE_ONLINE W_ERROR(0x139b)
#define WERR_QUORUM_RESOURCE W_ERROR(0x139c)
#define WERR_NOT_QUORUM_CAPABLE W_ERROR(0x139d)
#define WERR_CLUSTER_SHUTTING_DOWN W_ERROR(0x139e)
#define WERR_INVALID_STATE W_ERROR(0x139f)
#define WERR_RESOURCE_PROPERTIES_STORED W_ERROR(0x13a0)
#define WERR_NOT_QUORUM_CLASS W_ERROR(0x13a1)
#define WERR_CORE_RESOURCE W_ERROR(0x13a2)
#define WERR_QUORUM_RESOURCE_ONLINE_FAILED W_ERROR(0x13a3)
#define WERR_QUORUMLOG_OPEN_FAILED W_ERROR(0x13a4)
#define WERR_CLUSTERLOG_CORRUPT W_ERROR(0x13a5)
#define WERR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE W_ERROR(0x13a6)
#define WERR_CLUSTERLOG_EXCEEDS_MAXSIZE W_ERROR(0x13a7)
#define WERR_CLUSTERLOG_CHKPOINT_NOT_FOUND W_ERROR(0x13a8)
#define WERR_CLUSTERLOG_NOT_ENOUGH_SPACE W_ERROR(0x13a9)
#define WERR_QUORUM_OWNER_ALIVE W_ERROR(0x13aa)
#define WERR_NETWORK_NOT_AVAILABLE W_ERROR(0x13ab)
#define WERR_NODE_NOT_AVAILABLE W_ERROR(0x13ac)
#define WERR_ALL_NODES_NOT_AVAILABLE W_ERROR(0x13ad)
#define WERR_RESOURCE_FAILED W_ERROR(0x13ae)
#define WERR_CLUSTER_INVALID_NODE W_ERROR(0x13af)
#define WERR_CLUSTER_NODE_EXISTS W_ERROR(0x13b0)
#define WERR_CLUSTER_JOIN_IN_PROGRESS W_ERROR(0x13b1)
#define WERR_CLUSTER_NODE_NOT_FOUND W_ERROR(0x13b2)
#define WERR_CLUSTER_LOCAL_NODE_NOT_FOUND W_ERROR(0x13b3)
#define WERR_CLUSTER_NETWORK_EXISTS W_ERROR(0x13b4)
#define WERR_CLUSTER_NETWORK_NOT_FOUND W_ERROR(0x13b5)
#define WERR_CLUSTER_NETINTERFACE_EXISTS W_ERROR(0x13b6)
#define WERR_CLUSTER_NETINTERFACE_NOT_FOUND W_ERROR(0x13b7)
#define WERR_CLUSTER_INVALID_REQUEST W_ERROR(0x13b8)
#define WERR_CLUSTER_INVALID_NETWORK_PROVIDER W_ERROR(0x13b9)
#define WERR_CLUSTER_NODE_DOWN W_ERROR(0x13ba)
#define WERR_CLUSTER_NODE_UNREACHABLE W_ERROR(0x13bb)
#define WERR_CLUSTER_NODE_NOT_MEMBER W_ERROR(0x13bc)
#define WERR_CLUSTER_JOIN_NOT_IN_PROGRESS W_ERROR(0x13bd)
#define WERR_CLUSTER_INVALID_NETWORK W_ERROR(0x13be)
#define WERR_CLUSTER_NODE_UP W_ERROR(0x13c0)
#define WERR_CLUSTER_IPADDR_IN_USE W_ERROR(0x13c1)
#define WERR_CLUSTER_NODE_NOT_PAUSED W_ERROR(0x13c2)
#define WERR_CLUSTER_NO_SECURITY_CONTEXT W_ERROR(0x13c3)
#define WERR_CLUSTER_NETWORK_NOT_INTERNAL W_ERROR(0x13c4)
#define WERR_CLUSTER_NODE_ALREADY_UP W_ERROR(0x13c5)
#define WERR_CLUSTER_NODE_ALREADY_DOWN W_ERROR(0x13c6)
#define WERR_CLUSTER_NETWORK_ALREADY_ONLINE W_ERROR(0x13c7)
#define WERR_CLUSTER_NETWORK_ALREADY_OFFLINE W_ERROR(0x13c8)
#define WERR_CLUSTER_NODE_ALREADY_MEMBER W_ERROR(0x13c9)
#define WERR_CLUSTER_LAST_INTERNAL_NETWORK W_ERROR(0x13ca)
#define WERR_CLUSTER_NETWORK_HAS_DEPENDENTS W_ERROR(0x13cb)
#define WERR_INVALID_OPERATION_ON_QUORUM W_ERROR(0x13cc)
#define WERR_DEPENDENCY_NOT_ALLOWED W_ERROR(0x13cd)
#define WERR_CLUSTER_NODE_PAUSED W_ERROR(0x13ce)
#define WERR_NODE_CANT_HOST_RESOURCE W_ERROR(0x13cf)
#define WERR_CLUSTER_NODE_NOT_READY W_ERROR(0x13d0)
#define WERR_CLUSTER_NODE_SHUTTING_DOWN W_ERROR(0x13d1)
#define WERR_CLUSTER_JOIN_ABORTED W_ERROR(0x13d2)
#define WERR_CLUSTER_INCOMPATIBLE_VERSIONS W_ERROR(0x13d3)
#define WERR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED W_ERROR(0x13d4)
#define WERR_CLUSTER_SYSTEM_CONFIG_CHANGED W_ERROR(0x13d5)
#define WERR_CLUSTER_RESOURCE_TYPE_NOT_FOUND W_ERROR(0x13d6)
#define WERR_CLUSTER_RESTYPE_NOT_SUPPORTED W_ERROR(0x13d7)
#define WERR_CLUSTER_RESNAME_NOT_FOUND W_ERROR(0x13d8)
#define WERR_CLUSTER_NO_RPC_PACKAGES_REGISTERED W_ERROR(0x13d9)
#define WERR_CLUSTER_OWNER_NOT_IN_PREFLIST W_ERROR(0x13da)
#define WERR_CLUSTER_DATABASE_SEQMISMATCH W_ERROR(0x13db)
#define WERR_RESMON_INVALID_STATE W_ERROR(0x13dc)
#define WERR_CLUSTER_GUM_NOT_LOCKER W_ERROR(0x13dd)
#define WERR_QUORUM_DISK_NOT_FOUND W_ERROR(0x13de)
#define WERR_DATABASE_BACKUP_CORRUPT W_ERROR(0x13df)
#define WERR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT W_ERROR(0x13e0)
#define WERR_RESOURCE_PROPERTY_UNCHANGEABLE W_ERROR(0x13e1)
#define WERR_CLUSTER_MEMBERSHIP_INVALID_STATE W_ERROR(0x1702)
#define WERR_CLUSTER_QUORUMLOG_NOT_FOUND W_ERROR(0x1703)
#define WERR_CLUSTER_MEMBERSHIP_HALT W_ERROR(0x1704)
#define WERR_CLUSTER_INSTANCE_ID_MISMATCH W_ERROR(0x1705)
#define WERR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP W_ERROR(0x1706)
#define WERR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH W_ERROR(0x1707)
#define WERR_CLUSTER_EVICT_WITHOUT_CLEANUP W_ERROR(0x1708)
#define WERR_CLUSTER_PARAMETER_MISMATCH W_ERROR(0x1709)
#define WERR_NODE_CANNOT_BE_CLUSTERED W_ERROR(0x170a)
#define WERR_CLUSTER_WRONG_OS_VERSION W_ERROR(0x170b)
#define WERR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME W_ERROR(0x170c)
#define WERR_CLUSCFG_ALREADY_COMMITTED W_ERROR(0x170d)
#define WERR_CLUSCFG_ROLLBACK_FAILED W_ERROR(0x170e)
#define WERR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT W_ERROR(0x170f)
#define WERR_CLUSTER_OLD_VERSION W_ERROR(0x1710)
#define WERR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME W_ERROR(0x1711)
#define WERR_CLUSTER_NO_NET_ADAPTERS W_ERROR(0x1712)
#define WERR_CLUSTER_POISONED W_ERROR(0x1713)
#define WERR_CLUSTER_GROUP_MOVING W_ERROR(0x1714)
#define WERR_CLUSTER_RESOURCE_TYPE_BUSY W_ERROR(0x1715)
#define WERR_RESOURCE_CALL_TIMED_OUT W_ERROR(0x1716)
#define WERR_INVALID_CLUSTER_IPV6_ADDRESS W_ERROR(0x1717)
#define WERR_CLUSTER_INTERNAL_INVALID_FUNCTION W_ERROR(0x1718)
#define WERR_CLUSTER_PARAMETER_OUT_OF_BOUNDS W_ERROR(0x1719)
#define WERR_CLUSTER_PARTIAL_SEND W_ERROR(0x171a)
#define WERR_CLUSTER_REGISTRY_INVALID_FUNCTION W_ERROR(0x171b)
#define WERR_CLUSTER_INVALID_STRING_TERMINATION W_ERROR(0x171c)
#define WERR_CLUSTER_INVALID_STRING_FORMAT W_ERROR(0x171d)
#define WERR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS W_ERROR(0x171e)
#define WERR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS W_ERROR(0x171f)
#define WERR_CLUSTER_NULL_DATA W_ERROR(0x1720)
#define WERR_CLUSTER_PARTIAL_READ W_ERROR(0x1721)
#define WERR_CLUSTER_PARTIAL_WRITE W_ERROR(0x1722)
#define WERR_CLUSTER_CANT_DESERIALIZE_DATA W_ERROR(0x1723)
#define WERR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT W_ERROR(0x1724)
#define WERR_CLUSTER_NO_QUORUM W_ERROR(0x1725)
#define WERR_CLUSTER_INVALID_IPV6_NETWORK W_ERROR(0x1726)
#define WERR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK W_ERROR(0x1727)
#define WERR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP W_ERROR(0x1728)
#define WERR_ENCRYPTION_FAILED W_ERROR(0x1770)
#define WERR_DECRYPTION_FAILED W_ERROR(0x1771)
#define WERR_FILE_ENCRYPTED W_ERROR(0x1772)
#define WERR_NO_RECOVERY_POLICY W_ERROR(0x1773)
#define WERR_NO_EFS W_ERROR(0x1774)
#define WERR_WRONG_EFS W_ERROR(0x1775)
#define WERR_NO_USER_KEYS W_ERROR(0x1776)
#define WERR_FILE_NOT_ENCRYPTED W_ERROR(0x1777)
#define WERR_NOT_EXPORT_FORMAT W_ERROR(0x1778)
#define WERR_FILE_READ_ONLY W_ERROR(0x1779)
#define WERR_DIR_EFS_DISALLOWED W_ERROR(0x177a)
#define WERR_EFS_SERVER_NOT_TRUSTED W_ERROR(0x177b)
#define WERR_BAD_RECOVERY_POLICY W_ERROR(0x177c)
#define WERR_EFS_ALG_BLOB_TOO_BIG W_ERROR(0x177d)
#define WERR_VOLUME_NOT_SUPPORT_EFS W_ERROR(0x177e)
#define WERR_EFS_DISABLED W_ERROR(0x177f)
#define WERR_EFS_VERSION_NOT_SUPPORT W_ERROR(0x1780)
#define WERR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE W_ERROR(0x1781)
#define WERR_CS_ENCRYPTION_UNSUPPORTED_SERVER W_ERROR(0x1782)
#define WERR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE W_ERROR(0x1783)
#define WERR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE W_ERROR(0x1784)
#define WERR_CS_ENCRYPTION_FILE_NOT_CSE W_ERROR(0x1785)
#define WERR_NO_BROWSER_SERVERS_FOUND W_ERROR(0x17e6)
#define WERR_SCHED_E_SERVICE_NOT_LOCALSYSTEM W_ERROR(0x1838)
#define WERR_LOG_SECTOR_INVALID W_ERROR(0x19c8)
#define WERR_LOG_SECTOR_PARITY_INVALID W_ERROR(0x19c9)
#define WERR_LOG_SECTOR_REMAPPED W_ERROR(0x19ca)
#define WERR_LOG_BLOCK_INCOMPLETE W_ERROR(0x19cb)
#define WERR_LOG_INVALID_RANGE W_ERROR(0x19cc)
#define WERR_LOG_BLOCKS_EXHAUSTED W_ERROR(0x19cd)
#define WERR_LOG_READ_CONTEXT_INVALID W_ERROR(0x19ce)
#define WERR_LOG_RESTART_INVALID W_ERROR(0x19cf)
#define WERR_LOG_BLOCK_VERSION W_ERROR(0x19d0)
#define WERR_LOG_BLOCK_INVALID W_ERROR(0x19d1)
#define WERR_LOG_READ_MODE_INVALID W_ERROR(0x19d2)
#define WERR_LOG_NO_RESTART W_ERROR(0x19d3)
#define WERR_LOG_METADATA_CORRUPT W_ERROR(0x19d4)
#define WERR_LOG_METADATA_INVALID W_ERROR(0x19d5)
#define WERR_LOG_METADATA_INCONSISTENT W_ERROR(0x19d6)
#define WERR_LOG_RESERVATION_INVALID W_ERROR(0x19d7)
#define WERR_LOG_CANT_DELETE W_ERROR(0x19d8)
#define WERR_LOG_CONTAINER_LIMIT_EXCEEDED W_ERROR(0x19d9)
#define WERR_LOG_START_OF_LOG W_ERROR(0x19da)
#define WERR_LOG_POLICY_ALREADY_INSTALLED W_ERROR(0x19db)
#define WERR_LOG_POLICY_NOT_INSTALLED W_ERROR(0x19dc)
#define WERR_LOG_POLICY_INVALID W_ERROR(0x19dd)
#define WERR_LOG_POLICY_CONFLICT W_ERROR(0x19de)
#define WERR_LOG_PINNED_ARCHIVE_TAIL W_ERROR(0x19df)
#define WERR_LOG_RECORD_NONEXISTENT W_ERROR(0x19e0)
#define WERR_LOG_RECORDS_RESERVED_INVALID W_ERROR(0x19e1)
#define WERR_LOG_SPACE_RESERVED_INVALID W_ERROR(0x19e2)
#define WERR_LOG_TAIL_INVALID W_ERROR(0x19e3)
#define WERR_LOG_FULL W_ERROR(0x19e4)
#define WERR_COULD_NOT_RESIZE_LOG W_ERROR(0x19e5)
#define WERR_LOG_MULTIPLEXED W_ERROR(0x19e6)
#define WERR_LOG_DEDICATED W_ERROR(0x19e7)
#define WERR_LOG_ARCHIVE_NOT_IN_PROGRESS W_ERROR(0x19e8)
#define WERR_LOG_ARCHIVE_IN_PROGRESS W_ERROR(0x19e9)
#define WERR_LOG_EPHEMERAL W_ERROR(0x19ea)
#define WERR_LOG_NOT_ENOUGH_CONTAINERS W_ERROR(0x19eb)
#define WERR_LOG_CLIENT_ALREADY_REGISTERED W_ERROR(0x19ec)
#define WERR_LOG_CLIENT_NOT_REGISTERED W_ERROR(0x19ed)
#define WERR_LOG_FULL_HANDLER_IN_PROGRESS W_ERROR(0x19ee)
#define WERR_LOG_CONTAINER_READ_FAILED W_ERROR(0x19ef)
#define WERR_LOG_CONTAINER_WRITE_FAILED W_ERROR(0x19f0)
#define WERR_LOG_CONTAINER_OPEN_FAILED W_ERROR(0x19f1)
#define WERR_LOG_CONTAINER_STATE_INVALID W_ERROR(0x19f2)
#define WERR_LOG_STATE_INVALID W_ERROR(0x19f3)
#define WERR_LOG_PINNED W_ERROR(0x19f4)
#define WERR_LOG_METADATA_FLUSH_FAILED W_ERROR(0x19f5)
#define WERR_LOG_INCONSISTENT_SECURITY W_ERROR(0x19f6)
#define WERR_LOG_APPENDED_FLUSH_FAILED W_ERROR(0x19f7)
#define WERR_LOG_PINNED_RESERVATION W_ERROR(0x19f8)
#define WERR_INVALID_TRANSACTION W_ERROR(0x1a2c)
#define WERR_TRANSACTION_NOT_ACTIVE W_ERROR(0x1a2d)
#define WERR_TRANSACTION_REQUEST_NOT_VALID W_ERROR(0x1a2e)
#define WERR_TRANSACTION_NOT_REQUESTED W_ERROR(0x1a2f)
#define WERR_TRANSACTION_ALREADY_ABORTED W_ERROR(0x1a30)
#define WERR_TRANSACTION_ALREADY_COMMITTED W_ERROR(0x1a31)
#define WERR_TM_INITIALIZATION_FAILED W_ERROR(0x1a32)
#define WERR_RESOURCEMANAGER_READ_ONLY W_ERROR(0x1a33)
#define WERR_TRANSACTION_NOT_JOINED W_ERROR(0x1a34)
#define WERR_TRANSACTION_SUPERIOR_EXISTS W_ERROR(0x1a35)
#define WERR_CRM_PROTOCOL_ALREADY_EXISTS W_ERROR(0x1a36)
#define WERR_TRANSACTION_PROPAGATION_FAILED W_ERROR(0x1a37)
#define WERR_CRM_PROTOCOL_NOT_FOUND W_ERROR(0x1a38)
#define WERR_TRANSACTION_INVALID_MARSHALL_BUFFER W_ERROR(0x1a39)
#define WERR_CURRENT_TRANSACTION_NOT_VALID W_ERROR(0x1a3a)
#define WERR_TRANSACTION_NOT_FOUND W_ERROR(0x1a3b)
#define WERR_RESOURCEMANAGER_NOT_FOUND W_ERROR(0x1a3c)
#define WERR_ENLISTMENT_NOT_FOUND W_ERROR(0x1a3d)
#define WERR_TRANSACTIONMANAGER_NOT_FOUND W_ERROR(0x1a3e)
#define WERR_TRANSACTIONMANAGER_NOT_ONLINE W_ERROR(0x1a3f)
#define WERR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION W_ERROR(0x1a40)
#define WERR_TRANSACTIONAL_CONFLICT W_ERROR(0x1a90)
#define WERR_RM_NOT_ACTIVE W_ERROR(0x1a91)
#define WERR_RM_METADATA_CORRUPT W_ERROR(0x1a92)
#define WERR_DIRECTORY_NOT_RM W_ERROR(0x1a93)
#define WERR_TRANSACTIONS_UNSUPPORTED_REMOTE W_ERROR(0x1a95)
#define WERR_LOG_RESIZE_INVALID_SIZE W_ERROR(0x1a96)
#define WERR_OBJECT_NO_LONGER_EXISTS W_ERROR(0x1a97)
#define WERR_STREAM_MINIVERSION_NOT_FOUND W_ERROR(0x1a98)
#define WERR_STREAM_MINIVERSION_NOT_VALID W_ERROR(0x1a99)
#define WERR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION W_ERROR(0x1a9a)
#define WERR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT W_ERROR(0x1a9b)
#define WERR_CANT_CREATE_MORE_STREAM_MINIVERSIONS W_ERROR(0x1a9c)
#define WERR_REMOTE_FILE_VERSION_MISMATCH W_ERROR(0x1a9e)
#define WERR_HANDLE_NO_LONGER_VALID W_ERROR(0x1a9f)
#define WERR_NO_TXF_METADATA W_ERROR(0x1aa0)
#define WERR_LOG_CORRUPTION_DETECTED W_ERROR(0x1aa1)
#define WERR_CANT_RECOVER_WITH_HANDLE_OPEN W_ERROR(0x1aa2)
#define WERR_RM_DISCONNECTED W_ERROR(0x1aa3)
#define WERR_ENLISTMENT_NOT_SUPERIOR W_ERROR(0x1aa4)
#define WERR_RECOVERY_NOT_NEEDED W_ERROR(0x1aa5)
#define WERR_RM_ALREADY_STARTED W_ERROR(0x1aa6)
#define WERR_FILE_IDENTITY_NOT_PERSISTENT W_ERROR(0x1aa7)
#define WERR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY W_ERROR(0x1aa8)
#define WERR_CANT_CROSS_RM_BOUNDARY W_ERROR(0x1aa9)
#define WERR_TXF_DIR_NOT_EMPTY W_ERROR(0x1aaa)
#define WERR_INDOUBT_TRANSACTIONS_EXIST W_ERROR(0x1aab)
#define WERR_TM_VOLATILE W_ERROR(0x1aac)
#define WERR_ROLLBACK_TIMER_EXPIRED W_ERROR(0x1aad)
#define WERR_TXF_ATTRIBUTE_CORRUPT W_ERROR(0x1aae)
#define WERR_EFS_NOT_ALLOWED_IN_TRANSACTION W_ERROR(0x1aaf)
#define WERR_TRANSACTIONAL_OPEN_NOT_ALLOWED W_ERROR(0x1ab0)
#define WERR_LOG_GROWTH_FAILED W_ERROR(0x1ab1)
#define WERR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE W_ERROR(0x1ab2)
#define WERR_TXF_METADATA_ALREADY_PRESENT W_ERROR(0x1ab3)
#define WERR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET W_ERROR(0x1ab4)
#define WERR_TRANSACTION_REQUIRED_PROMOTION W_ERROR(0x1ab5)
#define WERR_CANNOT_EXECUTE_FILE_IN_TRANSACTION W_ERROR(0x1ab6)
#define WERR_TRANSACTIONS_NOT_FROZEN W_ERROR(0x1ab7)
#define WERR_TRANSACTION_FREEZE_IN_PROGRESS W_ERROR(0x1ab8)
#define WERR_NOT_SNAPSHOT_VOLUME W_ERROR(0x1ab9)
#define WERR_NO_SAVEPOINT_WITH_OPEN_FILES W_ERROR(0x1aba)
#define WERR_DATA_LOST_REPAIR W_ERROR(0x1abb)
#define WERR_SPARSE_NOT_ALLOWED_IN_TRANSACTION W_ERROR(0x1abc)
#define WERR_TM_IDENTITY_MISMATCH W_ERROR(0x1abd)
#define WERR_FLOATED_SECTION W_ERROR(0x1abe)
#define WERR_CANNOT_ACCEPT_TRANSACTED_WORK W_ERROR(0x1abf)
#define WERR_CANNOT_ABORT_TRANSACTIONS W_ERROR(0x1ac0)
#define WERR_CTX_WINSTATION_NAME_INVALID W_ERROR(0x1b59)
#define WERR_CTX_INVALID_PD W_ERROR(0x1b5a)
#define WERR_CTX_PD_NOT_FOUND W_ERROR(0x1b5b)
#define WERR_CTX_WD_NOT_FOUND W_ERROR(0x1b5c)
#define WERR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY W_ERROR(0x1b5d)
#define WERR_CTX_SERVICE_NAME_COLLISION W_ERROR(0x1b5e)
#define WERR_CTX_CLOSE_PENDING W_ERROR(0x1b5f)
#define WERR_CTX_NO_OUTBUF W_ERROR(0x1b60)
#define WERR_CTX_MODEM_INF_NOT_FOUND W_ERROR(0x1b61)
#define WERR_CTX_INVALID_MODEMNAME W_ERROR(0x1b62)
#define WERR_CTX_MODEM_RESPONSE_ERROR W_ERROR(0x1b63)
#define WERR_CTX_MODEM_RESPONSE_TIMEOUT W_ERROR(0x1b64)
#define WERR_CTX_MODEM_RESPONSE_NO_CARRIER W_ERROR(0x1b65)
#define WERR_CTX_MODEM_RESPONSE_NO_DIALTONE W_ERROR(0x1b66)
#define WERR_CTX_MODEM_RESPONSE_BUSY W_ERROR(0x1b67)
#define WERR_CTX_MODEM_RESPONSE_VOICE W_ERROR(0x1b68)
#define WERR_CTX_TD_ERROR W_ERROR(0x1b69)
#define WERR_CTX_WINSTATION_NOT_FOUND W_ERROR(0x1b6e)
#define WERR_CTX_WINSTATION_ALREADY_EXISTS W_ERROR(0x1b6f)
#define WERR_CTX_WINSTATION_BUSY W_ERROR(0x1b70)
#define WERR_CTX_BAD_VIDEO_MODE W_ERROR(0x1b71)
#define WERR_CTX_GRAPHICS_INVALID W_ERROR(0x1b7b)
#define WERR_CTX_LOGON_DISABLED W_ERROR(0x1b7d)
#define WERR_CTX_NOT_CONSOLE W_ERROR(0x1b7e)
#define WERR_CTX_CLIENT_QUERY_TIMEOUT W_ERROR(0x1b80)
#define WERR_CTX_CONSOLE_DISCONNECT W_ERROR(0x1b81)
#define WERR_CTX_CONSOLE_CONNECT W_ERROR(0x1b82)
#define WERR_CTX_SHADOW_DENIED W_ERROR(0x1b84)
#define WERR_CTX_WINSTATION_ACCESS_DENIED W_ERROR(0x1b85)
#define WERR_CTX_INVALID_WD W_ERROR(0x1b89)
#define WERR_CTX_SHADOW_INVALID W_ERROR(0x1b8a)
#define WERR_CTX_SHADOW_DISABLED W_ERROR(0x1b8b)
#define WERR_CTX_CLIENT_LICENSE_IN_USE W_ERROR(0x1b8c)
#define WERR_CTX_CLIENT_LICENSE_NOT_SET W_ERROR(0x1b8d)
#define WERR_CTX_LICENSE_NOT_AVAILABLE W_ERROR(0x1b8e)
#define WERR_CTX_LICENSE_CLIENT_INVALID W_ERROR(0x1b8f)
#define WERR_CTX_LICENSE_EXPIRED W_ERROR(0x1b90)
#define WERR_CTX_SHADOW_NOT_RUNNING W_ERROR(0x1b91)
#define WERR_CTX_SHADOW_ENDED_BY_MODE_CHANGE W_ERROR(0x1b92)
#define WERR_ACTIVATION_COUNT_EXCEEDED W_ERROR(0x1b93)
#define WERR_CTX_WINSTATIONS_DISABLED W_ERROR(0x1b94)
#define WERR_CTX_ENCRYPTION_LEVEL_REQUIRED W_ERROR(0x1b95)
#define WERR_CTX_SESSION_IN_USE W_ERROR(0x1b96)
#define WERR_CTX_NO_FORCE_LOGOFF W_ERROR(0x1b97)
#define WERR_CTX_ACCOUNT_RESTRICTION W_ERROR(0x1b98)
#define WERR_RDP_PROTOCOL_ERROR W_ERROR(0x1b99)
#define WERR_CTX_CDM_CONNECT W_ERROR(0x1b9a)
#define WERR_CTX_CDM_DISCONNECT W_ERROR(0x1b9b)
#define WERR_CTX_SECURITY_LAYER_ERROR W_ERROR(0x1b9c)
#define WERR_TS_INCOMPATIBLE_SESSIONS W_ERROR(0x1b9d)
#define WERR_FRS_ERR_INVALID_API_SEQUENCE W_ERROR(0x1f41)
#define WERR_FRS_ERR_STARTING_SERVICE W_ERROR(0x1f42)
#define WERR_FRS_ERR_STOPPING_SERVICE W_ERROR(0x1f43)
#define WERR_FRS_ERR_INTERNAL_API W_ERROR(0x1f44)
#define WERR_FRS_ERR_INTERNAL W_ERROR(0x1f45)
#define WERR_FRS_ERR_SERVICE_COMM W_ERROR(0x1f46)
#define WERR_FRS_ERR_INSUFFICIENT_PRIV W_ERROR(0x1f47)
#define WERR_FRS_ERR_AUTHENTICATION W_ERROR(0x1f48)
#define WERR_FRS_ERR_PARENT_INSUFFICIENT_PRIV W_ERROR(0x1f49)
#define WERR_FRS_ERR_PARENT_AUTHENTICATION W_ERROR(0x1f4a)
#define WERR_FRS_ERR_CHILD_TO_PARENT_COMM W_ERROR(0x1f4b)
#define WERR_FRS_ERR_PARENT_TO_CHILD_COMM W_ERROR(0x1f4c)
#define WERR_FRS_ERR_SYSVOL_POPULATE W_ERROR(0x1f4d)
#define WERR_FRS_ERR_SYSVOL_POPULATE_TIMEOUT W_ERROR(0x1f4e)
#define WERR_FRS_ERR_SYSVOL_IS_BUSY W_ERROR(0x1f4f)
#define WERR_FRS_ERR_SYSVOL_DEMOTE W_ERROR(0x1f50)
#define WERR_FRS_ERR_INVALID_SERVICE_PARAMETER W_ERROR(0x1f51)
#define WERR_DS_NOT_INSTALLED W_ERROR(0x2008)
#define WERR_DS_MEMBERSHIP_EVALUATED_LOCALLY W_ERROR(0x2009)
#define WERR_DS_NO_ATTRIBUTE_OR_VALUE W_ERROR(0x200a)
#define WERR_DS_INVALID_ATTRIBUTE_SYNTAX W_ERROR(0x200b)
#define WERR_DS_ATTRIBUTE_TYPE_UNDEFINED W_ERROR(0x200c)
#define WERR_DS_ATTRIBUTE_OR_VALUE_EXISTS W_ERROR(0x200d)
#define WERR_DS_BUSY W_ERROR(0x200e)
#define WERR_DS_UNAVAILABLE W_ERROR(0x200f)
#define WERR_DS_NO_RIDS_ALLOCATED W_ERROR(0x2010)
#define WERR_DS_NO_MORE_RIDS W_ERROR(0x2011)
#define WERR_DS_INCORRECT_ROLE_OWNER W_ERROR(0x2012)
#define WERR_DS_RIDMGR_INIT_ERROR W_ERROR(0x2013)
#define WERR_DS_OBJ_CLASS_VIOLATION W_ERROR(0x2014)
#define WERR_DS_CANT_ON_NON_LEAF W_ERROR(0x2015)
#define WERR_DS_CANT_ON_RDN W_ERROR(0x2016)
#define WERR_DS_CANT_MOD_OBJ_CLASS W_ERROR(0x2017)
#define WERR_DS_CROSS_DOM_MOVE_ERROR W_ERROR(0x2018)
#define WERR_DS_GC_NOT_AVAILABLE W_ERROR(0x2019)
#define WERR_SHARED_POLICY W_ERROR(0x201a)
#define WERR_POLICY_OBJECT_NOT_FOUND W_ERROR(0x201b)
#define WERR_POLICY_ONLY_IN_DS W_ERROR(0x201c)
#define WERR_PROMOTION_ACTIVE W_ERROR(0x201d)
#define WERR_NO_PROMOTION_ACTIVE W_ERROR(0x201e)
#define WERR_DS_OPERATIONS_ERROR W_ERROR(0x2020)
#define WERR_DS_PROTOCOL_ERROR W_ERROR(0x2021)
#define WERR_DS_TIMELIMIT_EXCEEDED W_ERROR(0x2022)
#define WERR_DS_SIZELIMIT_EXCEEDED W_ERROR(0x2023)
#define WERR_DS_ADMIN_LIMIT_EXCEEDED W_ERROR(0x2024)
#define WERR_DS_COMPARE_FALSE W_ERROR(0x2025)
#define WERR_DS_COMPARE_TRUE W_ERROR(0x2026)
#define WERR_DS_AUTH_METHOD_NOT_SUPPORTED W_ERROR(0x2027)
#define WERR_DS_STRONG_AUTH_REQUIRED W_ERROR(0x2028)
#define WERR_DS_INAPPROPRIATE_AUTH W_ERROR(0x2029)
#define WERR_DS_AUTH_UNKNOWN W_ERROR(0x202a)
#define WERR_DS_REFERRAL W_ERROR(0x202b)
#define WERR_DS_UNAVAILABLE_CRIT_EXTENSION W_ERROR(0x202c)
#define WERR_DS_CONFIDENTIALITY_REQUIRED W_ERROR(0x202d)
#define WERR_DS_INAPPROPRIATE_MATCHING W_ERROR(0x202e)
#define WERR_DS_CONSTRAINT_VIOLATION W_ERROR(0x202f)
#define WERR_DS_NO_SUCH_OBJECT W_ERROR(0x2030)
#define WERR_DS_ALIAS_PROBLEM W_ERROR(0x2031)
#define WERR_DS_INVALID_DN_SYNTAX W_ERROR(0x2032)
#define WERR_DS_IS_LEAF W_ERROR(0x2033)
#define WERR_DS_ALIAS_DEREF_PROBLEM W_ERROR(0x2034)
#define WERR_DS_UNWILLING_TO_PERFORM W_ERROR(0x2035)
#define WERR_DS_LOOP_DETECT W_ERROR(0x2036)
#define WERR_DS_NAMING_VIOLATION W_ERROR(0x2037)
#define WERR_DS_OBJECT_RESULTS_TOO_LARGE W_ERROR(0x2038)
#define WERR_DS_AFFECTS_MULTIPLE_DSAS W_ERROR(0x2039)
#define WERR_DS_SERVER_DOWN W_ERROR(0x203a)
#define WERR_DS_LOCAL_ERROR W_ERROR(0x203b)
#define WERR_DS_ENCODING_ERROR W_ERROR(0x203c)
#define WERR_DS_DECODING_ERROR W_ERROR(0x203d)
#define WERR_DS_FILTER_UNKNOWN W_ERROR(0x203e)
#define WERR_DS_PARAM_ERROR W_ERROR(0x203f)
#define WERR_DS_NOT_SUPPORTED W_ERROR(0x2040)
#define WERR_DS_NO_RESULTS_RETURNED W_ERROR(0x2041)
#define WERR_DS_CONTROL_NOT_FOUND W_ERROR(0x2042)
#define WERR_DS_CLIENT_LOOP W_ERROR(0x2043)
#define WERR_DS_REFERRAL_LIMIT_EXCEEDED W_ERROR(0x2044)
#define WERR_DS_SORT_CONTROL_MISSING W_ERROR(0x2045)
#define WERR_DS_OFFSET_RANGE_ERROR W_ERROR(0x2046)
#define WERR_DS_ROOT_MUST_BE_NC W_ERROR(0x206d)
#define WERR_DS_ADD_REPLICA_INHIBITED W_ERROR(0x206e)
#define WERR_DS_ATT_NOT_DEF_IN_SCHEMA W_ERROR(0x206f)
#define WERR_DS_MAX_OBJ_SIZE_EXCEEDED W_ERROR(0x2070)
#define WERR_DS_OBJ_STRING_NAME_EXISTS W_ERROR(0x2071)
#define WERR_DS_NO_RDN_DEFINED_IN_SCHEMA W_ERROR(0x2072)
#define WERR_DS_RDN_DOESNT_MATCH_SCHEMA W_ERROR(0x2073)
#define WERR_DS_NO_REQUESTED_ATTS_FOUND W_ERROR(0x2074)
#define WERR_DS_USER_BUFFER_TO_SMALL W_ERROR(0x2075)
#define WERR_DS_ATT_IS_NOT_ON_OBJ W_ERROR(0x2076)
#define WERR_DS_ILLEGAL_MOD_OPERATION W_ERROR(0x2077)
#define WERR_DS_OBJ_TOO_LARGE W_ERROR(0x2078)
#define WERR_DS_BAD_INSTANCE_TYPE W_ERROR(0x2079)
#define WERR_DS_MASTERDSA_REQUIRED W_ERROR(0x207a)
#define WERR_DS_OBJECT_CLASS_REQUIRED W_ERROR(0x207b)
#define WERR_DS_MISSING_REQUIRED_ATT W_ERROR(0x207c)
#define WERR_DS_ATT_NOT_DEF_FOR_CLASS W_ERROR(0x207d)
#define WERR_DS_ATT_ALREADY_EXISTS W_ERROR(0x207e)
#define WERR_DS_CANT_ADD_ATT_VALUES W_ERROR(0x2080)
#define WERR_DS_SINGLE_VALUE_CONSTRAINT W_ERROR(0x2081)
#define WERR_DS_RANGE_CONSTRAINT W_ERROR(0x2082)
#define WERR_DS_ATT_VAL_ALREADY_EXISTS W_ERROR(0x2083)
#define WERR_DS_CANT_REM_MISSING_ATT W_ERROR(0x2084)
#define WERR_DS_CANT_REM_MISSING_ATT_VAL W_ERROR(0x2085)
#define WERR_DS_ROOT_CANT_BE_SUBREF W_ERROR(0x2086)
#define WERR_DS_NO_CHAINING W_ERROR(0x2087)
#define WERR_DS_NO_CHAINED_EVAL W_ERROR(0x2088)
#define WERR_DS_NO_PARENT_OBJECT W_ERROR(0x2089)
#define WERR_DS_PARENT_IS_AN_ALIAS W_ERROR(0x208a)
#define WERR_DS_CANT_MIX_MASTER_AND_REPS W_ERROR(0x208b)
#define WERR_DS_CHILDREN_EXIST W_ERROR(0x208c)
#define WERR_DS_OBJ_NOT_FOUND W_ERROR(0x208d)
#define WERR_DS_ALIASED_OBJ_MISSING W_ERROR(0x208e)
#define WERR_DS_BAD_NAME_SYNTAX W_ERROR(0x208f)
#define WERR_DS_ALIAS_POINTS_TO_ALIAS W_ERROR(0x2090)
#define WERR_DS_CANT_DEREF_ALIAS W_ERROR(0x2091)
#define WERR_DS_OUT_OF_SCOPE W_ERROR(0x2092)
#define WERR_DS_OBJECT_BEING_REMOVED W_ERROR(0x2093)
#define WERR_DS_CANT_DELETE_DSA_OBJ W_ERROR(0x2094)
#define WERR_DS_GENERIC_ERROR W_ERROR(0x2095)
#define WERR_DS_DSA_MUST_BE_INT_MASTER W_ERROR(0x2096)
#define WERR_DS_CLASS_NOT_DSA W_ERROR(0x2097)
#define WERR_DS_INSUFF_ACCESS_RIGHTS W_ERROR(0x2098)
#define WERR_DS_ILLEGAL_SUPERIOR W_ERROR(0x2099)
#define WERR_DS_ATTRIBUTE_OWNED_BY_SAM W_ERROR(0x209a)
#define WERR_DS_NAME_TOO_MANY_PARTS W_ERROR(0x209b)
#define WERR_DS_NAME_TOO_LONG W_ERROR(0x209c)
#define WERR_DS_NAME_VALUE_TOO_LONG W_ERROR(0x209d)
#define WERR_DS_NAME_UNPARSEABLE W_ERROR(0x209e)
#define WERR_DS_NAME_TYPE_UNKNOWN W_ERROR(0x209f)
#define WERR_DS_NOT_AN_OBJECT W_ERROR(0x20a0)
#define WERR_DS_SEC_DESC_TOO_SHORT W_ERROR(0x20a1)
#define WERR_DS_SEC_DESC_INVALID W_ERROR(0x20a2)
#define WERR_DS_NO_DELETED_NAME W_ERROR(0x20a3)
#define WERR_DS_SUBREF_MUST_HAVE_PARENT W_ERROR(0x20a4)
#define WERR_DS_NCNAME_MUST_BE_NC W_ERROR(0x20a5)
#define WERR_DS_CANT_ADD_SYSTEM_ONLY W_ERROR(0x20a6)
#define WERR_DS_CLASS_MUST_BE_CONCRETE W_ERROR(0x20a7)
#define WERR_DS_INVALID_DMD W_ERROR(0x20a8)
#define WERR_DS_OBJ_GUID_EXISTS W_ERROR(0x20a9)
#define WERR_DS_NOT_ON_BACKLINK W_ERROR(0x20aa)
#define WERR_DS_NO_CROSSREF_FOR_NC W_ERROR(0x20ab)
#define WERR_DS_SHUTTING_DOWN W_ERROR(0x20ac)
#define WERR_DS_UNKNOWN_OPERATION W_ERROR(0x20ad)
#define WERR_DS_INVALID_ROLE_OWNER W_ERROR(0x20ae)
#define WERR_DS_COULDNT_CONTACT_FSMO W_ERROR(0x20af)
#define WERR_DS_CROSS_NC_DN_RENAME W_ERROR(0x20b0)
#define WERR_DS_CANT_MOD_SYSTEM_ONLY W_ERROR(0x20b1)
#define WERR_DS_REPLICATOR_ONLY W_ERROR(0x20b2)
#define WERR_DS_OBJ_CLASS_NOT_DEFINED W_ERROR(0x20b3)
#define WERR_DS_OBJ_CLASS_NOT_SUBCLASS W_ERROR(0x20b4)
#define WERR_DS_NAME_REFERENCE_INVALID W_ERROR(0x20b5)
#define WERR_DS_CROSS_REF_EXISTS W_ERROR(0x20b6)
#define WERR_DS_CANT_DEL_MASTER_CROSSREF W_ERROR(0x20b7)
#define WERR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD W_ERROR(0x20b8)
#define WERR_DS_NOTIFY_FILTER_TOO_COMPLEX W_ERROR(0x20b9)
#define WERR_DS_DUP_RDN W_ERROR(0x20ba)
#define WERR_DS_DUP_OID W_ERROR(0x20bb)
#define WERR_DS_DUP_MAPI_ID W_ERROR(0x20bc)
#define WERR_DS_DUP_SCHEMA_ID_GUID W_ERROR(0x20bd)
#define WERR_DS_DUP_LDAP_DISPLAY_NAME W_ERROR(0x20be)
#define WERR_DS_SEMANTIC_ATT_TEST W_ERROR(0x20bf)
#define WERR_DS_SYNTAX_MISMATCH W_ERROR(0x20c0)
#define WERR_DS_EXISTS_IN_MUST_HAVE W_ERROR(0x20c1)
#define WERR_DS_EXISTS_IN_MAY_HAVE W_ERROR(0x20c2)
#define WERR_DS_NONEXISTENT_MAY_HAVE W_ERROR(0x20c3)
#define WERR_DS_NONEXISTENT_MUST_HAVE W_ERROR(0x20c4)
#define WERR_DS_AUX_CLS_TEST_FAIL W_ERROR(0x20c5)
#define WERR_DS_NONEXISTENT_POSS_SUP W_ERROR(0x20c6)
#define WERR_DS_SUB_CLS_TEST_FAIL W_ERROR(0x20c7)
#define WERR_DS_BAD_RDN_ATT_ID_SYNTAX W_ERROR(0x20c8)
#define WERR_DS_EXISTS_IN_AUX_CLS W_ERROR(0x20c9)
#define WERR_DS_EXISTS_IN_SUB_CLS W_ERROR(0x20ca)
#define WERR_DS_EXISTS_IN_POSS_SUP W_ERROR(0x20cb)
#define WERR_DS_RECALCSCHEMA_FAILED W_ERROR(0x20cc)
#define WERR_DS_TREE_DELETE_NOT_FINISHED W_ERROR(0x20cd)
#define WERR_DS_CANT_DELETE W_ERROR(0x20ce)
#define WERR_DS_ATT_SCHEMA_REQ_ID W_ERROR(0x20cf)
#define WERR_DS_BAD_ATT_SCHEMA_SYNTAX W_ERROR(0x20d0)
#define WERR_DS_CANT_CACHE_ATT W_ERROR(0x20d1)
#define WERR_DS_CANT_CACHE_CLASS W_ERROR(0x20d2)
#define WERR_DS_CANT_REMOVE_ATT_CACHE W_ERROR(0x20d3)
#define WERR_DS_CANT_REMOVE_CLASS_CACHE W_ERROR(0x20d4)
#define WERR_DS_CANT_RETRIEVE_DN W_ERROR(0x20d5)
#define WERR_DS_MISSING_SUPREF W_ERROR(0x20d6)
#define WERR_DS_CANT_RETRIEVE_INSTANCE W_ERROR(0x20d7)
#define WERR_DS_CODE_INCONSISTENCY W_ERROR(0x20d8)
#define WERR_DS_DATABASE_ERROR W_ERROR(0x20d9)
#define WERR_DS_GOVERNSID_MISSING W_ERROR(0x20da)
#define WERR_DS_MISSING_EXPECTED_ATT W_ERROR(0x20db)
#define WERR_DS_NCNAME_MISSING_CR_REF W_ERROR(0x20dc)
#define WERR_DS_SECURITY_CHECKING_ERROR W_ERROR(0x20dd)
#define WERR_DS_SCHEMA_NOT_LOADED W_ERROR(0x20de)
#define WERR_DS_SCHEMA_ALLOC_FAILED W_ERROR(0x20df)
#define WERR_DS_ATT_SCHEMA_REQ_SYNTAX W_ERROR(0x20e0)
#define WERR_DS_GCVERIFY_ERROR W_ERROR(0x20e1)
#define WERR_DS_DRA_SCHEMA_MISMATCH W_ERROR(0x20e2)
#define WERR_DS_CANT_FIND_DSA_OBJ W_ERROR(0x20e3)
#define WERR_DS_CANT_FIND_EXPECTED_NC W_ERROR(0x20e4)
#define WERR_DS_CANT_FIND_NC_IN_CACHE W_ERROR(0x20e5)
#define WERR_DS_CANT_RETRIEVE_CHILD W_ERROR(0x20e6)
#define WERR_DS_SECURITY_ILLEGAL_MODIFY W_ERROR(0x20e7)
#define WERR_DS_CANT_REPLACE_HIDDEN_REC W_ERROR(0x20e8)
#define WERR_DS_BAD_HIERARCHY_FILE W_ERROR(0x20e9)
#define WERR_DS_BUILD_HIERARCHY_TABLE_FAILED W_ERROR(0x20ea)
#define WERR_DS_CONFIG_PARAM_MISSING W_ERROR(0x20eb)
#define WERR_DS_COUNTING_AB_INDICES_FAILED W_ERROR(0x20ec)
#define WERR_DS_HIERARCHY_TABLE_MALLOC_FAILED W_ERROR(0x20ed)
#define WERR_DS_INTERNAL_FAILURE W_ERROR(0x20ee)
#define WERR_DS_UNKNOWN_ERROR W_ERROR(0x20ef)
#define WERR_DS_ROOT_REQUIRES_CLASS_TOP W_ERROR(0x20f0)
#define WERR_DS_REFUSING_FSMO_ROLES W_ERROR(0x20f1)
#define WERR_DS_MISSING_FSMO_SETTINGS W_ERROR(0x20f2)
#define WERR_DS_UNABLE_TO_SURRENDER_ROLES W_ERROR(0x20f3)
#define WERR_DS_DRA_GENERIC W_ERROR(0x20f4)
#define WERR_DS_DRA_INVALID_PARAMETER W_ERROR(0x20f5)
#define WERR_DS_DRA_BUSY W_ERROR(0x20f6)
#define WERR_DS_DRA_BAD_DN W_ERROR(0x20f7)
#define WERR_DS_DRA_BAD_NC W_ERROR(0x20f8)
#define WERR_DS_DRA_DN_EXISTS W_ERROR(0x20f9)
#define WERR_DS_DRA_INTERNAL_ERROR W_ERROR(0x20fa)
#define WERR_DS_DRA_INCONSISTENT_DIT W_ERROR(0x20fb)
#define WERR_DS_DRA_CONNECTION_FAILED W_ERROR(0x20fc)
#define WERR_DS_DRA_BAD_INSTANCE_TYPE W_ERROR(0x20fd)
#define WERR_DS_DRA_OUT_OF_MEM W_ERROR(0x20fe)
#define WERR_DS_DRA_MAIL_PROBLEM W_ERROR(0x20ff)
#define WERR_DS_DRA_REF_ALREADY_EXISTS W_ERROR(0x2100)
#define WERR_DS_DRA_REF_NOT_FOUND W_ERROR(0x2101)
#define WERR_DS_DRA_OBJ_IS_REP_SOURCE W_ERROR(0x2102)
#define WERR_DS_DRA_DB_ERROR W_ERROR(0x2103)
#define WERR_DS_DRA_NO_REPLICA W_ERROR(0x2104)
#define WERR_DS_DRA_ACCESS_DENIED W_ERROR(0x2105)
#define WERR_DS_DRA_NOT_SUPPORTED W_ERROR(0x2106)
#define WERR_DS_DRA_RPC_CANCELLED W_ERROR(0x2107)
#define WERR_DS_DRA_SOURCE_DISABLED W_ERROR(0x2108)
#define WERR_DS_DRA_SINK_DISABLED W_ERROR(0x2109)
#define WERR_DS_DRA_NAME_COLLISION W_ERROR(0x210a)
#define WERR_DS_DRA_SOURCE_REINSTALLED W_ERROR(0x210b)
#define WERR_DS_DRA_MISSING_PARENT W_ERROR(0x210c)
#define WERR_DS_DRA_PREEMPTED W_ERROR(0x210d)
#define WERR_DS_DRA_ABANDON_SYNC W_ERROR(0x210e)
#define WERR_DS_DRA_SHUTDOWN W_ERROR(0x210f)
#define WERR_DS_DRA_INCOMPATIBLE_PARTIAL_SET W_ERROR(0x2110)
#define WERR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA W_ERROR(0x2111)
#define WERR_DS_DRA_EXTN_CONNECTION_FAILED W_ERROR(0x2112)
#define WERR_DS_INSTALL_SCHEMA_MISMATCH W_ERROR(0x2113)
#define WERR_DS_DUP_LINK_ID W_ERROR(0x2114)
#define WERR_DS_NAME_ERROR_RESOLVING W_ERROR(0x2115)
#define WERR_DS_NAME_ERROR_NOT_FOUND W_ERROR(0x2116)
#define WERR_DS_NAME_ERROR_NOT_UNIQUE W_ERROR(0x2117)
#define WERR_DS_NAME_ERROR_NO_MAPPING W_ERROR(0x2118)
#define WERR_DS_NAME_ERROR_DOMAIN_ONLY W_ERROR(0x2119)
#define WERR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING W_ERROR(0x211a)
#define WERR_DS_CONSTRUCTED_ATT_MOD W_ERROR(0x211b)
#define WERR_DS_WRONG_OM_OBJ_CLASS W_ERROR(0x211c)
#define WERR_DS_DRA_REPL_PENDING W_ERROR(0x211d)
#define WERR_DS_DS_REQUIRED W_ERROR(0x211e)
#define WERR_DS_INVALID_LDAP_DISPLAY_NAME W_ERROR(0x211f)
#define WERR_DS_NON_BASE_SEARCH W_ERROR(0x2120)
#define WERR_DS_CANT_RETRIEVE_ATTS W_ERROR(0x2121)
#define WERR_DS_BACKLINK_WITHOUT_LINK W_ERROR(0x2122)
#define WERR_DS_EPOCH_MISMATCH W_ERROR(0x2123)
#define WERR_DS_SRC_NAME_MISMATCH W_ERROR(0x2124)
#define WERR_DS_SRC_AND_DST_NC_IDENTICAL W_ERROR(0x2125)
#define WERR_DS_DST_NC_MISMATCH W_ERROR(0x2126)
#define WERR_DS_NOT_AUTHORITIVE_FOR_DST_NC W_ERROR(0x2127)
#define WERR_DS_SRC_GUID_MISMATCH W_ERROR(0x2128)
#define WERR_DS_CANT_MOVE_DELETED_OBJECT W_ERROR(0x2129)
#define WERR_DS_PDC_OPERATION_IN_PROGRESS W_ERROR(0x212a)
#define WERR_DS_CROSS_DOMAIN_CLEANUP_REQD W_ERROR(0x212b)
#define WERR_DS_ILLEGAL_XDOM_MOVE_OPERATION W_ERROR(0x212c)
#define WERR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS W_ERROR(0x212d)
#define WERR_DS_NC_MUST_HAVE_NC_PARENT W_ERROR(0x212e)
#define WERR_DS_CR_IMPOSSIBLE_TO_VALIDATE W_ERROR(0x212f)
#define WERR_DS_DST_DOMAIN_NOT_NATIVE W_ERROR(0x2130)
#define WERR_DS_MISSING_INFRASTRUCTURE_CONTAINER W_ERROR(0x2131)
#define WERR_DS_CANT_MOVE_ACCOUNT_GROUP W_ERROR(0x2132)
#define WERR_DS_CANT_MOVE_RESOURCE_GROUP W_ERROR(0x2133)
#define WERR_DS_INVALID_SEARCH_FLAG W_ERROR(0x2134)
#define WERR_DS_NO_TREE_DELETE_ABOVE_NC W_ERROR(0x2135)
#define WERR_DS_COULDNT_LOCK_TREE_FOR_DELETE W_ERROR(0x2136)
#define WERR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE W_ERROR(0x2137)
#define WERR_DS_SAM_INIT_FAILURE W_ERROR(0x2138)
#define WERR_DS_SENSITIVE_GROUP_VIOLATION W_ERROR(0x2139)
#define WERR_DS_CANT_MOD_PRIMARYGROUPID W_ERROR(0x213a)
#define WERR_DS_ILLEGAL_BASE_SCHEMA_MOD W_ERROR(0x213b)
#define WERR_DS_NONSAFE_SCHEMA_CHANGE W_ERROR(0x213c)
#define WERR_DS_SCHEMA_UPDATE_DISALLOWED W_ERROR(0x213d)
#define WERR_DS_CANT_CREATE_UNDER_SCHEMA W_ERROR(0x213e)
#define WERR_DS_INSTALL_NO_SRC_SCH_VERSION W_ERROR(0x213f)
#define WERR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE W_ERROR(0x2140)
#define WERR_DS_INVALID_GROUP_TYPE W_ERROR(0x2141)
#define WERR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN W_ERROR(0x2142)
#define WERR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN W_ERROR(0x2143)
#define WERR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER W_ERROR(0x2144)
#define WERR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER W_ERROR(0x2145)
#define WERR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER W_ERROR(0x2146)
#define WERR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER W_ERROR(0x2147)
#define WERR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER W_ERROR(0x2148)
#define WERR_DS_HAVE_PRIMARY_MEMBERS W_ERROR(0x2149)
#define WERR_DS_STRING_SD_CONVERSION_FAILED W_ERROR(0x214a)
#define WERR_DS_NAMING_MASTER_GC W_ERROR(0x214b)
#define WERR_DS_DNS_LOOKUP_FAILURE W_ERROR(0x214c)
#define WERR_DS_COULDNT_UPDATE_SPNS W_ERROR(0x214d)
#define WERR_DS_CANT_RETRIEVE_SD W_ERROR(0x214e)
#define WERR_DS_KEY_NOT_UNIQUE W_ERROR(0x214f)
#define WERR_DS_WRONG_LINKED_ATT_SYNTAX W_ERROR(0x2150)
#define WERR_DS_SAM_NEED_BOOTKEY_PASSWORD W_ERROR(0x2151)
#define WERR_DS_SAM_NEED_BOOTKEY_FLOPPY W_ERROR(0x2152)
#define WERR_DS_CANT_START W_ERROR(0x2153)
#define WERR_DS_INIT_FAILURE W_ERROR(0x2154)
#define WERR_DS_NO_PKT_PRIVACY_ON_CONNECTION W_ERROR(0x2155)
#define WERR_DS_SOURCE_DOMAIN_IN_FOREST W_ERROR(0x2156)
#define WERR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST W_ERROR(0x2157)
#define WERR_DS_DESTINATION_AUDITING_NOT_ENABLED W_ERROR(0x2158)
#define WERR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN W_ERROR(0x2159)
#define WERR_DS_SRC_OBJ_NOT_GROUP_OR_USER W_ERROR(0x215a)
#define WERR_DS_SRC_SID_EXISTS_IN_FOREST W_ERROR(0x215b)
#define WERR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH W_ERROR(0x215c)
#define WERR_SAM_INIT_FAILURE W_ERROR(0x215d)
#define WERR_DS_DRA_SCHEMA_INFO_SHIP W_ERROR(0x215e)
#define WERR_DS_DRA_SCHEMA_CONFLICT W_ERROR(0x215f)
#define WERR_DS_DRA_EARLIER_SCHEMA_CONFLICT W_ERROR(0x2160)
#define WERR_DS_DRA_OBJ_NC_MISMATCH W_ERROR(0x2161)
#define WERR_DS_NC_STILL_HAS_DSAS W_ERROR(0x2162)
#define WERR_DS_GC_REQUIRED W_ERROR(0x2163)
#define WERR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY W_ERROR(0x2164)
#define WERR_DS_NO_FPO_IN_UNIVERSAL_GROUPS W_ERROR(0x2165)
#define WERR_DS_CANT_ADD_TO_GC W_ERROR(0x2166)
#define WERR_DS_NO_CHECKPOINT_WITH_PDC W_ERROR(0x2167)
#define WERR_DS_SOURCE_AUDITING_NOT_ENABLED W_ERROR(0x2168)
#define WERR_DS_CANT_CREATE_IN_NONDOMAIN_NC W_ERROR(0x2169)
#define WERR_DS_INVALID_NAME_FOR_SPN W_ERROR(0x216a)
#define WERR_DS_FILTER_USES_CONTRUCTED_ATTRS W_ERROR(0x216b)
#define WERR_DS_UNICODEPWD_NOT_IN_QUOTES W_ERROR(0x216c)
#define WERR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED W_ERROR(0x216d)
#define WERR_DS_MUST_BE_RUN_ON_DST_DC W_ERROR(0x216e)
#define WERR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER W_ERROR(0x216f)
#define WERR_DS_CANT_TREE_DELETE_CRITICAL_OBJ W_ERROR(0x2170)
#define WERR_DS_INIT_FAILURE_CONSOLE W_ERROR(0x2171)
#define WERR_DS_SAM_INIT_FAILURE_CONSOLE W_ERROR(0x2172)
#define WERR_DS_FOREST_VERSION_TOO_HIGH W_ERROR(0x2173)
#define WERR_DS_DOMAIN_VERSION_TOO_HIGH W_ERROR(0x2174)
#define WERR_DS_FOREST_VERSION_TOO_LOW W_ERROR(0x2175)
#define WERR_DS_DOMAIN_VERSION_TOO_LOW W_ERROR(0x2176)
#define WERR_DS_INCOMPATIBLE_VERSION W_ERROR(0x2177)
#define WERR_DS_LOW_DSA_VERSION W_ERROR(0x2178)
#define WERR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN W_ERROR(0x2179)
#define WERR_DS_NOT_SUPPORTED_SORT_ORDER W_ERROR(0x217a)
#define WERR_DS_NAME_NOT_UNIQUE W_ERROR(0x217b)
#define WERR_DS_MACHINE_ACCOUNT_CREATED_PRENT4 W_ERROR(0x217c)
#define WERR_DS_OUT_OF_VERSION_STORE W_ERROR(0x217d)
#define WERR_DS_INCOMPATIBLE_CONTROLS_USED W_ERROR(0x217e)
#define WERR_DS_NO_REF_DOMAIN W_ERROR(0x217f)
#define WERR_DS_RESERVED_LINK_ID W_ERROR(0x2180)
#define WERR_DS_LINK_ID_NOT_AVAILABLE W_ERROR(0x2181)
#define WERR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER W_ERROR(0x2182)
#define WERR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE W_ERROR(0x2183)
#define WERR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC W_ERROR(0x2184)
#define WERR_DS_MODIFYDN_DISALLOWED_BY_FLAG W_ERROR(0x2185)
#define WERR_DS_MODIFYDN_WRONG_GRANDPARENT W_ERROR(0x2186)
#define WERR_DS_NAME_ERROR_TRUST_REFERRAL W_ERROR(0x2187)
#define WERR_NOT_SUPPORTED_ON_STANDARD_SERVER W_ERROR(0x2188)
#define WERR_DS_CANT_ACCESS_REMOTE_PART_OF_AD W_ERROR(0x2189)
#define WERR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2 W_ERROR(0x218a)
#define WERR_DS_THREAD_LIMIT_EXCEEDED W_ERROR(0x218b)
#define WERR_DS_NOT_CLOSEST W_ERROR(0x218c)
#define WERR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF W_ERROR(0x218d)
#define WERR_DS_SINGLE_USER_MODE_FAILED W_ERROR(0x218e)
#define WERR_DS_NTDSCRIPT_SYNTAX_ERROR W_ERROR(0x218f)
#define WERR_DS_NTDSCRIPT_PROCESS_ERROR W_ERROR(0x2190)
#define WERR_DS_DIFFERENT_REPL_EPOCHS W_ERROR(0x2191)
#define WERR_DS_DRS_EXTENSIONS_CHANGED W_ERROR(0x2192)
#define WERR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR W_ERROR(0x2193)
#define WERR_DS_NO_MSDS_INTID W_ERROR(0x2194)
#define WERR_DS_DUP_MSDS_INTID W_ERROR(0x2195)
#define WERR_DS_EXISTS_IN_RDNATTID W_ERROR(0x2196)
#define WERR_DS_AUTHORIZATION_FAILED W_ERROR(0x2197)
#define WERR_DS_INVALID_SCRIPT W_ERROR(0x2198)
#define WERR_DS_REMOTE_CROSSREF_OP_FAILED W_ERROR(0x2199)
#define WERR_DS_CROSS_REF_BUSY W_ERROR(0x219a)
#define WERR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN W_ERROR(0x219b)
#define WERR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC W_ERROR(0x219c)
#define WERR_DS_DUPLICATE_ID_FOUND W_ERROR(0x219d)
#define WERR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT W_ERROR(0x219e)
#define WERR_DS_GROUP_CONVERSION_ERROR W_ERROR(0x219f)
#define WERR_DS_CANT_MOVE_APP_BASIC_GROUP W_ERROR(0x21a0)
#define WERR_DS_CANT_MOVE_APP_QUERY_GROUP W_ERROR(0x21a1)
#define WERR_DS_ROLE_NOT_VERIFIED W_ERROR(0x21a2)
#define WERR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL W_ERROR(0x21a3)
#define WERR_DS_DOMAIN_RENAME_IN_PROGRESS W_ERROR(0x21a4)
#define WERR_DS_EXISTING_AD_CHILD_NC W_ERROR(0x21a5)
#define WERR_DS_REPL_LIFETIME_EXCEEDED W_ERROR(0x21a6)
#define WERR_DS_DISALLOWED_IN_SYSTEM_CONTAINER W_ERROR(0x21a7)
#define WERR_DS_LDAP_SEND_QUEUE_FULL W_ERROR(0x21a8)
#define WERR_DS_DRA_OUT_SCHEDULE_WINDOW W_ERROR(0x21a9)
#define WERR_DS_POLICY_NOT_KNOWN W_ERROR(0x21aa)
#define WERR_NO_SITE_SETTINGS_OBJECT W_ERROR(0x21ab)
#define WERR_NO_SECRETS W_ERROR(0x21ac)
#define WERR_NO_WRITABLE_DC_FOUND W_ERROR(0x21ad)
#define WERR_DS_NO_SERVER_OBJECT W_ERROR(0x21ae)
#define WERR_DS_NO_NTDSA_OBJECT W_ERROR(0x21af)
#define WERR_DS_NON_ASQ_SEARCH W_ERROR(0x21b0)
#define WERR_DS_AUDIT_FAILURE W_ERROR(0x21b1)
#define WERR_DS_INVALID_SEARCH_FLAG_SUBTREE W_ERROR(0x21b2)
#define WERR_DS_INVALID_SEARCH_FLAG_TUPLE W_ERROR(0x21b3)
#define WERR_DS_DRA_RECYCLED_TARGET W_ERROR(0x21bf)
#define WERR_DS_HIGH_DSA_VERSION W_ERROR(0x21c2)
#define WERR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST W_ERROR(0x21c7)
#define WERR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST W_ERROR(0x21c8)
#define WERR_DNS_ERROR_RCODE_FORMAT_ERROR W_ERROR(0x2329)
#define WERR_DNS_ERROR_RCODE_SERVER_FAILURE W_ERROR(0x232a)
#define WERR_DNS_ERROR_RCODE_NAME_ERROR W_ERROR(0x232b)
#define WERR_DNS_ERROR_RCODE_NOT_IMPLEMENTED W_ERROR(0x232c)
#define WERR_DNS_ERROR_RCODE_REFUSED W_ERROR(0x232d)
#define WERR_DNS_ERROR_RCODE_YXDOMAIN W_ERROR(0x232e)
#define WERR_DNS_ERROR_RCODE_YXRRSET W_ERROR(0x232f)
#define WERR_DNS_ERROR_RCODE_NXRRSET W_ERROR(0x2330)
#define WERR_DNS_ERROR_RCODE_NOTAUTH W_ERROR(0x2331)
#define WERR_DNS_ERROR_RCODE_NOTZONE W_ERROR(0x2332)
#define WERR_DNS_ERROR_RCODE_BADSIG W_ERROR(0x2338)
#define WERR_DNS_ERROR_RCODE_BADKEY W_ERROR(0x2339)
#define WERR_DNS_ERROR_RCODE_BADTIME W_ERROR(0x233a)
#define WERR_DNS_INFO_NO_RECORDS W_ERROR(0x251d)
#define WERR_DNS_ERROR_BAD_PACKET W_ERROR(0x251e)
#define WERR_DNS_ERROR_NO_PACKET W_ERROR(0x251f)
#define WERR_DNS_ERROR_RCODE W_ERROR(0x2520)
#define WERR_DNS_ERROR_UNSECURE_PACKET W_ERROR(0x2521)
#define WERR_DNS_ERROR_INVALID_TYPE W_ERROR(0x254f)
#define WERR_DNS_ERROR_INVALID_IP_ADDRESS W_ERROR(0x2550)
#define WERR_DNS_ERROR_INVALID_PROPERTY W_ERROR(0x2551)
#define WERR_DNS_ERROR_TRY_AGAIN_LATER W_ERROR(0x2552)
#define WERR_DNS_ERROR_NOT_UNIQUE W_ERROR(0x2553)
#define WERR_DNS_ERROR_NON_RFC_NAME W_ERROR(0x2554)
#define WERR_DNS_STATUS_FQDN W_ERROR(0x2555)
#define WERR_DNS_STATUS_DOTTED_NAME W_ERROR(0x2556)
#define WERR_DNS_STATUS_SINGLE_PART_NAME W_ERROR(0x2557)
#define WERR_DNS_ERROR_INVALID_NAME_CHAR W_ERROR(0x2558)
#define WERR_DNS_ERROR_NUMERIC_NAME W_ERROR(0x2559)
#define WERR_DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER W_ERROR(0x255a)
#define WERR_DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION W_ERROR(0x255b)
#define WERR_DNS_ERROR_CANNOT_FIND_ROOT_HINTS W_ERROR(0x255c)
#define WERR_DNS_ERROR_INCONSISTENT_ROOT_HINTS W_ERROR(0x255d)
#define WERR_DNS_ERROR_DWORD_VALUE_TOO_SMALL W_ERROR(0x255e)
#define WERR_DNS_ERROR_DWORD_VALUE_TOO_LARGE W_ERROR(0x255f)
#define WERR_DNS_ERROR_BACKGROUND_LOADING W_ERROR(0x2560)
#define WERR_DNS_ERROR_NOT_ALLOWED_ON_RODC W_ERROR(0x2561)
#define WERR_DNS_ERROR_ZONE_DOES_NOT_EXIST W_ERROR(0x2581)
#define WERR_DNS_ERROR_NO_ZONE_INFO W_ERROR(0x2582)
#define WERR_DNS_ERROR_INVALID_ZONE_OPERATION W_ERROR(0x2583)
#define WERR_DNS_ERROR_ZONE_CONFIGURATION_ERROR W_ERROR(0x2584)
#define WERR_DNS_ERROR_ZONE_HAS_NO_SOA_RECORD W_ERROR(0x2585)
#define WERR_DNS_ERROR_ZONE_HAS_NO_NS_RECORDS W_ERROR(0x2586)
#define WERR_DNS_ERROR_ZONE_LOCKED W_ERROR(0x2587)
#define WERR_DNS_ERROR_ZONE_CREATION_FAILED W_ERROR(0x2588)
#define WERR_DNS_ERROR_ZONE_ALREADY_EXISTS W_ERROR(0x2589)
#define WERR_DNS_ERROR_AUTOZONE_ALREADY_EXISTS W_ERROR(0x258a)
#define WERR_DNS_ERROR_INVALID_ZONE_TYPE W_ERROR(0x258b)
#define WERR_DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP W_ERROR(0x258c)
#define WERR_DNS_ERROR_ZONE_NOT_SECONDARY W_ERROR(0x258d)
#define WERR_DNS_ERROR_NEED_SECONDARY_ADDRESSES W_ERROR(0x258e)
#define WERR_DNS_ERROR_WINS_INIT_FAILED W_ERROR(0x258f)
#define WERR_DNS_ERROR_NEED_WINS_SERVERS W_ERROR(0x2590)
#define WERR_DNS_ERROR_NBSTAT_INIT_FAILED W_ERROR(0x2591)
#define WERR_DNS_ERROR_SOA_DELETE_INVALID W_ERROR(0x2592)
#define WERR_DNS_ERROR_FORWARDER_ALREADY_EXISTS W_ERROR(0x2593)
#define WERR_DNS_ERROR_ZONE_REQUIRES_MASTER_IP W_ERROR(0x2594)
#define WERR_DNS_ERROR_ZONE_IS_SHUTDOWN W_ERROR(0x2595)
#define WERR_DNS_ERROR_PRIMARY_REQUIRES_DATAFILE W_ERROR(0x25b3)
#define WERR_DNS_ERROR_INVALID_DATAFILE_NAME W_ERROR(0x25b4)
#define WERR_DNS_ERROR_DATAFILE_OPEN_FAILURE W_ERROR(0x25b5)
#define WERR_DNS_ERROR_FILE_WRITEBACK_FAILED W_ERROR(0x25b6)
#define WERR_DNS_ERROR_DATAFILE_PARSING W_ERROR(0x25b7)
#define WERR_DNS_ERROR_RECORD_DOES_NOT_EXIST W_ERROR(0x25e5)
#define WERR_DNS_ERROR_RECORD_FORMAT W_ERROR(0x25e6)
#define WERR_DNS_ERROR_NODE_CREATION_FAILED W_ERROR(0x25e7)
#define WERR_DNS_ERROR_UNKNOWN_RECORD_TYPE W_ERROR(0x25e8)
#define WERR_DNS_ERROR_RECORD_TIMED_OUT W_ERROR(0x25e9)
#define WERR_DNS_ERROR_NAME_NOT_IN_ZONE W_ERROR(0x25ea)
#define WERR_DNS_ERROR_CNAME_LOOP W_ERROR(0x25eb)
#define WERR_DNS_ERROR_NODE_IS_CNAME W_ERROR(0x25ec)
#define WERR_DNS_ERROR_CNAME_COLLISION W_ERROR(0x25ed)
#define WERR_DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT W_ERROR(0x25ee)
#define WERR_DNS_ERROR_RECORD_ALREADY_EXISTS W_ERROR(0x25ef)
#define WERR_DNS_ERROR_SECONDARY_DATA W_ERROR(0x25f0)
#define WERR_DNS_ERROR_NO_CREATE_CACHE_DATA W_ERROR(0x25f1)
#define WERR_DNS_ERROR_NAME_DOES_NOT_EXIST W_ERROR(0x25f2)
#define WERR_DNS_WARNING_PTR_CREATE_FAILED W_ERROR(0x25f3)
#define WERR_DNS_WARNING_DOMAIN_UNDELETED W_ERROR(0x25f4)
#define WERR_DNS_ERROR_DS_UNAVAILABLE W_ERROR(0x25f5)
#define WERR_DNS_ERROR_DS_ZONE_ALREADY_EXISTS W_ERROR(0x25f6)
#define WERR_DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE W_ERROR(0x25f7)
#define WERR_DNS_INFO_AXFR_COMPLETE W_ERROR(0x2617)
#define WERR_DNS_ERROR_AXFR W_ERROR(0x2618)
#define WERR_DNS_INFO_ADDED_LOCAL_WINS W_ERROR(0x2619)
#define WERR_DNS_STATUS_CONTINUE_NEEDED W_ERROR(0x2649)
#define WERR_DNS_ERROR_NO_TCPIP W_ERROR(0x267b)
#define WERR_DNS_ERROR_NO_DNS_SERVERS W_ERROR(0x267c)
#define WERR_DNS_ERROR_DP_DOES_NOT_EXIST W_ERROR(0x26ad)
#define WERR_DNS_ERROR_DP_ALREADY_EXISTS W_ERROR(0x26ae)
#define WERR_DNS_ERROR_DP_NOT_ENLISTED W_ERROR(0x26af)
#define WERR_DNS_ERROR_DP_ALREADY_ENLISTED W_ERROR(0x26b0)
#define WERR_DNS_ERROR_DP_NOT_AVAILABLE W_ERROR(0x26b1)
#define WERR_DNS_ERROR_DP_FSMO_ERROR W_ERROR(0x26b2)
#define WERR_WSAEINTR W_ERROR(0x2714)
#define WERR_WSAEBADF W_ERROR(0x2719)
#define WERR_WSAEACCES W_ERROR(0x271d)
#define WERR_WSAEFAULT W_ERROR(0x271e)
#define WERR_WSAEINVAL W_ERROR(0x2726)
#define WERR_WSAEMFILE W_ERROR(0x2728)
#define WERR_WSAEWOULDBLOCK W_ERROR(0x2733)
#define WERR_WSAEINPROGRESS W_ERROR(0x2734)
#define WERR_WSAEALREADY W_ERROR(0x2735)
#define WERR_WSAENOTSOCK W_ERROR(0x2736)
#define WERR_WSAEDESTADDRREQ W_ERROR(0x2737)
#define WERR_WSAEMSGSIZE W_ERROR(0x2738)
#define WERR_WSAEPROTOTYPE W_ERROR(0x2739)
#define WERR_WSAENOPROTOOPT W_ERROR(0x273a)
#define WERR_WSAEPROTONOSUPPORT W_ERROR(0x273b)
#define WERR_WSAESOCKTNOSUPPORT W_ERROR(0x273c)
#define WERR_WSAEOPNOTSUPP W_ERROR(0x273d)
#define WERR_WSAEPFNOSUPPORT W_ERROR(0x273e)
#define WERR_WSAEAFNOSUPPORT W_ERROR(0x273f)
#define WERR_WSAEADDRINUSE W_ERROR(0x2740)
#define WERR_WSAEADDRNOTAVAIL W_ERROR(0x2741)
#define WERR_WSAENETDOWN W_ERROR(0x2742)
#define WERR_WSAENETUNREACH W_ERROR(0x2743)
#define WERR_WSAENETRESET W_ERROR(0x2744)
#define WERR_WSAECONNABORTED W_ERROR(0x2745)
#define WERR_WSAECONNRESET W_ERROR(0x2746)
#define WERR_WSAENOBUFS W_ERROR(0x2747)
#define WERR_WSAEISCONN W_ERROR(0x2748)
#define WERR_WSAENOTCONN W_ERROR(0x2749)
#define WERR_WSAESHUTDOWN W_ERROR(0x274a)
#define WERR_WSAETOOMANYREFS W_ERROR(0x274b)
#define WERR_WSAETIMEDOUT W_ERROR(0x274c)
#define WERR_WSAECONNREFUSED W_ERROR(0x274d)
#define WERR_WSAELOOP W_ERROR(0x274e)
#define WERR_WSAENAMETOOLONG W_ERROR(0x274f)
#define WERR_WSAEHOSTDOWN W_ERROR(0x2750)
#define WERR_WSAEHOSTUNREACH W_ERROR(0x2751)
#define WERR_WSAENOTEMPTY W_ERROR(0x2752)
#define WERR_WSAEPROCLIM W_ERROR(0x2753)
#define WERR_WSAEUSERS W_ERROR(0x2754)
#define WERR_WSAEDQUOT W_ERROR(0x2755)
#define WERR_WSAESTALE W_ERROR(0x2756)
#define WERR_WSAEREMOTE W_ERROR(0x2757)
#define WERR_WSASYSNOTREADY W_ERROR(0x276b)
#define WERR_WSAVERNOTSUPPORTED W_ERROR(0x276c)
#define WERR_WSANOTINITIALISED W_ERROR(0x276d)
#define WERR_WSAEDISCON W_ERROR(0x2775)
#define WERR_WSAENOMORE W_ERROR(0x2776)
#define WERR_WSAECANCELLED W_ERROR(0x2777)
#define WERR_WSAEINVALIDPROCTABLE W_ERROR(0x2778)
#define WERR_WSAEINVALIDPROVIDER W_ERROR(0x2779)
#define WERR_WSAEPROVIDERFAILEDINIT W_ERROR(0x277a)
#define WERR_WSASYSCALLFAILURE W_ERROR(0x277b)
#define WERR_WSASERVICE_NOT_FOUND W_ERROR(0x277c)
#define WERR_WSATYPE_NOT_FOUND W_ERROR(0x277d)
#define WERR_WSA_E_NO_MORE W_ERROR(0x277e)
#define WERR_WSA_E_CANCELLED W_ERROR(0x277f)
#define WERR_WSAEREFUSED W_ERROR(0x2780)
#define WERR_WSAHOST_NOT_FOUND W_ERROR(0x2af9)
#define WERR_WSATRY_AGAIN W_ERROR(0x2afa)
#define WERR_WSANO_RECOVERY W_ERROR(0x2afb)
#define WERR_WSANO_DATA W_ERROR(0x2afc)
#define WERR_WSA_QOS_RECEIVERS W_ERROR(0x2afd)
#define WERR_WSA_QOS_SENDERS W_ERROR(0x2afe)
#define WERR_WSA_QOS_NO_SENDERS W_ERROR(0x2aff)
#define WERR_WSA_QOS_NO_RECEIVERS W_ERROR(0x2b00)
#define WERR_WSA_QOS_REQUEST_CONFIRMED W_ERROR(0x2b01)
#define WERR_WSA_QOS_ADMISSION_FAILURE W_ERROR(0x2b02)
#define WERR_WSA_QOS_POLICY_FAILURE W_ERROR(0x2b03)
#define WERR_WSA_QOS_BAD_STYLE W_ERROR(0x2b04)
#define WERR_WSA_QOS_BAD_OBJECT W_ERROR(0x2b05)
#define WERR_WSA_QOS_TRAFFIC_CTRL_ERROR W_ERROR(0x2b06)
#define WERR_WSA_QOS_GENERIC_ERROR W_ERROR(0x2b07)
#define WERR_WSA_QOS_ESERVICETYPE W_ERROR(0x2b08)
#define WERR_WSA_QOS_EFLOWSPEC W_ERROR(0x2b09)
#define WERR_WSA_QOS_EPROVSPECBUF W_ERROR(0x2b0a)
#define WERR_WSA_QOS_EFILTERSTYLE W_ERROR(0x2b0b)
#define WERR_WSA_QOS_EFILTERTYPE W_ERROR(0x2b0c)
#define WERR_WSA_QOS_EFILTERCOUNT W_ERROR(0x2b0d)
#define WERR_WSA_QOS_EOBJLENGTH W_ERROR(0x2b0e)
#define WERR_WSA_QOS_EFLOWCOUNT W_ERROR(0x2b0f)
#define WERR_WSA_QOS_EUNKOWNPSOBJ W_ERROR(0x2b10)
#define WERR_WSA_QOS_EPOLICYOBJ W_ERROR(0x2b11)
#define WERR_WSA_QOS_EFLOWDESC W_ERROR(0x2b12)
#define WERR_WSA_QOS_EPSFLOWSPEC W_ERROR(0x2b13)
#define WERR_WSA_QOS_EPSFILTERSPEC W_ERROR(0x2b14)
#define WERR_WSA_QOS_ESDMODEOBJ W_ERROR(0x2b15)
#define WERR_WSA_QOS_ESHAPERATEOBJ W_ERROR(0x2b16)
#define WERR_WSA_QOS_RESERVED_PETYPE W_ERROR(0x2b17)
#define WERR_IPSEC_QM_POLICY_EXISTS W_ERROR(0x32c8)
#define WERR_IPSEC_QM_POLICY_NOT_FOUND W_ERROR(0x32c9)
#define WERR_IPSEC_QM_POLICY_IN_USE W_ERROR(0x32ca)
#define WERR_IPSEC_MM_POLICY_EXISTS W_ERROR(0x32cb)
#define WERR_IPSEC_MM_POLICY_NOT_FOUND W_ERROR(0x32cc)
#define WERR_IPSEC_MM_POLICY_IN_USE W_ERROR(0x32cd)
#define WERR_IPSEC_MM_FILTER_EXISTS W_ERROR(0x32ce)
#define WERR_IPSEC_MM_FILTER_NOT_FOUND W_ERROR(0x32cf)
#define WERR_IPSEC_TRANSPORT_FILTER_EXISTS W_ERROR(0x32d0)
#define WERR_IPSEC_TRANSPORT_FILTER_NOT_FOUND W_ERROR(0x32d1)
#define WERR_IPSEC_MM_AUTH_EXISTS W_ERROR(0x32d2)
#define WERR_IPSEC_MM_AUTH_NOT_FOUND W_ERROR(0x32d3)
#define WERR_IPSEC_MM_AUTH_IN_USE W_ERROR(0x32d4)
#define WERR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND W_ERROR(0x32d5)
#define WERR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND W_ERROR(0x32d6)
#define WERR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND W_ERROR(0x32d7)
#define WERR_IPSEC_TUNNEL_FILTER_EXISTS W_ERROR(0x32d8)
#define WERR_IPSEC_TUNNEL_FILTER_NOT_FOUND W_ERROR(0x32d9)
#define WERR_IPSEC_MM_FILTER_PENDING_DELETION W_ERROR(0x32da)
#define WERR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION W_ERROR(0x32db)
#define WERR_IPSEC_TUNNEL_FILTER_PENDING_DELETION W_ERROR(0x32dc)
#define WERR_IPSEC_MM_POLICY_PENDING_ELETION W_ERROR(0x32dd)
#define WERR_IPSEC_MM_AUTH_PENDING_DELETION W_ERROR(0x32de)
#define WERR_IPSEC_QM_POLICY_PENDING_DELETION W_ERROR(0x32df)
#define WERR_WARNING_IPSEC_MM_POLICY_PRUNED W_ERROR(0x32e0)
#define WERR_WARNING_IPSEC_QM_POLICY_PRUNED W_ERROR(0x32e1)
#define WERR_IPSEC_IKE_NEG_STATUS_BEGIN W_ERROR(0x35e8)
#define WERR_IPSEC_IKE_AUTH_FAIL W_ERROR(0x35e9)
#define WERR_IPSEC_IKE_ATTRIB_FAIL W_ERROR(0x35ea)
#define WERR_IPSEC_IKE_NEGOTIATION_PENDING W_ERROR(0x35eb)
#define WERR_IPSEC_IKE_GENERAL_PROCESSING_ERROR W_ERROR(0x35ec)
#define WERR_IPSEC_IKE_TIMED_OUT W_ERROR(0x35ed)
#define WERR_IPSEC_IKE_NO_CERT W_ERROR(0x35ee)
#define WERR_IPSEC_IKE_SA_DELETED W_ERROR(0x35ef)
#define WERR_IPSEC_IKE_SA_REAPED W_ERROR(0x35f0)
#define WERR_IPSEC_IKE_MM_ACQUIRE_DROP W_ERROR(0x35f1)
#define WERR_IPSEC_IKE_QM_ACQUIRE_DROP W_ERROR(0x35f2)
#define WERR_IPSEC_IKE_QUEUE_DROP_MM W_ERROR(0x35f3)
#define WERR_IPSEC_IKE_QUEUE_DROP_NO_MM W_ERROR(0x35f4)
#define WERR_IPSEC_IKE_DROP_NO_RESPONSE W_ERROR(0x35f5)
#define WERR_IPSEC_IKE_MM_DELAY_DROP W_ERROR(0x35f6)
#define WERR_IPSEC_IKE_QM_DELAY_DROP W_ERROR(0x35f7)
#define WERR_IPSEC_IKE_ERROR W_ERROR(0x35f8)
#define WERR_IPSEC_IKE_CRL_FAILED W_ERROR(0x35f9)
#define WERR_IPSEC_IKE_INVALID_KEY_USAGE W_ERROR(0x35fa)
#define WERR_IPSEC_IKE_INVALID_CERT_TYPE W_ERROR(0x35fb)
#define WERR_IPSEC_IKE_NO_PRIVATE_KEY W_ERROR(0x35fc)
#define WERR_IPSEC_IKE_DH_FAIL W_ERROR(0x35fe)
#define WERR_IPSEC_IKE_INVALID_HEADER W_ERROR(0x3600)
#define WERR_IPSEC_IKE_NO_POLICY W_ERROR(0x3601)
#define WERR_IPSEC_IKE_INVALID_SIGNATURE W_ERROR(0x3602)
#define WERR_IPSEC_IKE_KERBEROS_ERROR W_ERROR(0x3603)
#define WERR_IPSEC_IKE_NO_PUBLIC_KEY W_ERROR(0x3604)
#define WERR_IPSEC_IKE_PROCESS_ERR W_ERROR(0x3605)
#define WERR_IPSEC_IKE_PROCESS_ERR_SA W_ERROR(0x3606)
#define WERR_IPSEC_IKE_PROCESS_ERR_PROP W_ERROR(0x3607)
#define WERR_IPSEC_IKE_PROCESS_ERR_TRANS W_ERROR(0x3608)
#define WERR_IPSEC_IKE_PROCESS_ERR_KE W_ERROR(0x3609)
#define WERR_IPSEC_IKE_PROCESS_ERR_ID W_ERROR(0x360a)
#define WERR_IPSEC_IKE_PROCESS_ERR_CERT W_ERROR(0x360b)
#define WERR_IPSEC_IKE_PROCESS_ERR_CERT_REQ W_ERROR(0x360c)
#define WERR_IPSEC_IKE_PROCESS_ERR_HASH W_ERROR(0x360d)
#define WERR_IPSEC_IKE_PROCESS_ERR_SIG W_ERROR(0x360e)
#define WERR_IPSEC_IKE_PROCESS_ERR_NONCE W_ERROR(0x360f)
#define WERR_IPSEC_IKE_PROCESS_ERR_NOTIFY W_ERROR(0x3610)
#define WERR_IPSEC_IKE_PROCESS_ERR_DELETE W_ERROR(0x3611)
#define WERR_IPSEC_IKE_PROCESS_ERR_VENDOR W_ERROR(0x3612)
#define WERR_IPSEC_IKE_INVALID_PAYLOAD W_ERROR(0x3613)
#define WERR_IPSEC_IKE_LOAD_SOFT_SA W_ERROR(0x3614)
#define WERR_IPSEC_IKE_SOFT_SA_TORN_DOWN W_ERROR(0x3615)
#define WERR_IPSEC_IKE_INVALID_COOKIE W_ERROR(0x3616)
#define WERR_IPSEC_IKE_NO_PEER_CERT W_ERROR(0x3617)
#define WERR_IPSEC_IKE_PEER_CRL_FAILED W_ERROR(0x3618)
#define WERR_IPSEC_IKE_POLICY_CHANGE W_ERROR(0x3619)
#define WERR_IPSEC_IKE_NO_MM_POLICY W_ERROR(0x361a)
#define WERR_IPSEC_IKE_NOTCBPRIV W_ERROR(0x361b)
#define WERR_IPSEC_IKE_SECLOADFAIL W_ERROR(0x361c)
#define WERR_IPSEC_IKE_FAILSSPINIT W_ERROR(0x361d)
#define WERR_IPSEC_IKE_FAILQUERYSSP W_ERROR(0x361e)
#define WERR_IPSEC_IKE_SRVACQFAIL W_ERROR(0x361f)
#define WERR_IPSEC_IKE_SRVQUERYCRED W_ERROR(0x3620)
#define WERR_IPSEC_IKE_GETSPIFAIL W_ERROR(0x3621)
#define WERR_IPSEC_IKE_INVALID_FILTER W_ERROR(0x3622)
#define WERR_IPSEC_IKE_OUT_OF_MEMORY W_ERROR(0x3623)
#define WERR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED W_ERROR(0x3624)
#define WERR_IPSEC_IKE_INVALID_POLICY W_ERROR(0x3625)
#define WERR_IPSEC_IKE_UNKNOWN_DOI W_ERROR(0x3626)
#define WERR_IPSEC_IKE_INVALID_SITUATION W_ERROR(0x3627)
#define WERR_IPSEC_IKE_DH_FAILURE W_ERROR(0x3628)
#define WERR_IPSEC_IKE_INVALID_GROUP W_ERROR(0x3629)
#define WERR_IPSEC_IKE_ENCRYPT W_ERROR(0x362a)
#define WERR_IPSEC_IKE_DECRYPT W_ERROR(0x362b)
#define WERR_IPSEC_IKE_POLICY_MATCH W_ERROR(0x362c)
#define WERR_IPSEC_IKE_UNSUPPORTED_ID W_ERROR(0x362d)
#define WERR_IPSEC_IKE_INVALID_HASH W_ERROR(0x362e)
#define WERR_IPSEC_IKE_INVALID_HASH_ALG W_ERROR(0x362f)
#define WERR_IPSEC_IKE_INVALID_HASH_SIZE W_ERROR(0x3630)
#define WERR_IPSEC_IKE_INVALID_ENCRYPT_ALG W_ERROR(0x3631)
#define WERR_IPSEC_IKE_INVALID_AUTH_ALG W_ERROR(0x3632)
#define WERR_IPSEC_IKE_INVALID_SIG W_ERROR(0x3633)
#define WERR_IPSEC_IKE_LOAD_FAILED W_ERROR(0x3634)
#define WERR_IPSEC_IKE_RPC_DELETE W_ERROR(0x3635)
#define WERR_IPSEC_IKE_BENIGN_REINIT W_ERROR(0x3636)
#define WERR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY W_ERROR(0x3637)
#define WERR_IPSEC_IKE_INVALID_CERT_KEYLEN W_ERROR(0x3639)
#define WERR_IPSEC_IKE_MM_LIMIT W_ERROR(0x363a)
#define WERR_IPSEC_IKE_NEGOTIATION_DISABLED W_ERROR(0x363b)
#define WERR_IPSEC_IKE_QM_LIMIT W_ERROR(0x363c)
#define WERR_IPSEC_IKE_MM_EXPIRED W_ERROR(0x363d)
#define WERR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID W_ERROR(0x363e)
#define WERR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH W_ERROR(0x363f)
#define WERR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID W_ERROR(0x3640)
#define WERR_IPSEC_IKE_INVALID_UMATTS W_ERROR(0x3641)
#define WERR_IPSEC_IKE_DOS_COOKIE_SENT W_ERROR(0x3642)
#define WERR_IPSEC_IKE_SHUTTING_DOWN W_ERROR(0x3643)
#define WERR_IPSEC_IKE_CGA_AUTH_FAILED W_ERROR(0x3644)
#define WERR_IPSEC_IKE_PROCESS_ERR_NATOA W_ERROR(0x3645)
#define WERR_IPSEC_IKE_INVALID_MM_FOR_QM W_ERROR(0x3646)
#define WERR_IPSEC_IKE_QM_EXPIRED W_ERROR(0x3647)
#define WERR_IPSEC_IKE_TOO_MANY_FILTERS W_ERROR(0x3648)
#define WERR_IPSEC_IKE_NEG_STATUS_END W_ERROR(0x3649)
#define WERR_SXS_SECTION_NOT_FOUND W_ERROR(0x36b0)
#define WERR_SXS_CANT_GEN_ACTCTX W_ERROR(0x36b1)
#define WERR_SXS_INVALID_ACTCTXDATA_FORMAT W_ERROR(0x36b2)
#define WERR_SXS_ASSEMBLY_NOT_FOUND W_ERROR(0x36b3)
#define WERR_SXS_MANIFEST_FORMAT_ERROR W_ERROR(0x36b4)
#define WERR_SXS_MANIFEST_PARSE_ERROR W_ERROR(0x36b5)
#define WERR_SXS_ACTIVATION_CONTEXT_DISABLED W_ERROR(0x36b6)
#define WERR_SXS_KEY_NOT_FOUND W_ERROR(0x36b7)
#define WERR_SXS_VERSION_CONFLICT W_ERROR(0x36b8)
#define WERR_SXS_WRONG_SECTION_TYPE W_ERROR(0x36b9)
#define WERR_SXS_THREAD_QUERIES_DISABLED W_ERROR(0x36ba)
#define WERR_SXS_PROCESS_DEFAULT_ALREADY_SET W_ERROR(0x36bb)
#define WERR_SXS_UNKNOWN_ENCODING_GROUP W_ERROR(0x36bc)
#define WERR_SXS_UNKNOWN_ENCODING W_ERROR(0x36bd)
#define WERR_SXS_INVALID_XML_NAMESPACE_URI W_ERROR(0x36be)
#define WERR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED W_ERROR(0x36bf)
#define WERR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED W_ERROR(0x36c0)
#define WERR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE W_ERROR(0x36c1)
#define WERR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE W_ERROR(0x36c2)
#define WERR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE W_ERROR(0x36c3)
#define WERR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT W_ERROR(0x36c4)
#define WERR_SXS_DUPLICATE_DLL_NAME W_ERROR(0x36c5)
#define WERR_SXS_DUPLICATE_WINDOWCLASS_NAME W_ERROR(0x36c6)
#define WERR_SXS_DUPLICATE_CLSID W_ERROR(0x36c7)
#define WERR_SXS_DUPLICATE_IID W_ERROR(0x36c8)
#define WERR_SXS_DUPLICATE_TLBID W_ERROR(0x36c9)
#define WERR_SXS_DUPLICATE_PROGID W_ERROR(0x36ca)
#define WERR_SXS_DUPLICATE_ASSEMBLY_NAME W_ERROR(0x36cb)
#define WERR_SXS_FILE_HASH_MISMATCH W_ERROR(0x36cc)
#define WERR_SXS_POLICY_PARSE_ERROR W_ERROR(0x36cd)
#define WERR_SXS_XML_E_MISSINGQUOTE W_ERROR(0x36ce)
#define WERR_SXS_XML_E_COMMENTSYNTAX W_ERROR(0x36cf)
#define WERR_SXS_XML_E_BADSTARTNAMECHAR W_ERROR(0x36d0)
#define WERR_SXS_XML_E_BADNAMECHAR W_ERROR(0x36d1)
#define WERR_SXS_XML_E_BADCHARINSTRING W_ERROR(0x36d2)
#define WERR_SXS_XML_E_XMLDECLSYNTAX W_ERROR(0x36d3)
#define WERR_SXS_XML_E_BADCHARDATA W_ERROR(0x36d4)
#define WERR_SXS_XML_E_MISSINGWHITESPACE W_ERROR(0x36d5)
#define WERR_SXS_XML_E_EXPECTINGTAGEND W_ERROR(0x36d6)
#define WERR_SXS_XML_E_MISSINGSEMICOLON W_ERROR(0x36d7)
#define WERR_SXS_XML_E_UNBALANCEDPAREN W_ERROR(0x36d8)
#define WERR_SXS_XML_E_INTERNALERROR W_ERROR(0x36d9)
#define WERR_SXS_XML_E_UNEXPECTED_WHITESPACE W_ERROR(0x36da)
#define WERR_SXS_XML_E_INCOMPLETE_ENCODING W_ERROR(0x36db)
#define WERR_SXS_XML_E_MISSING_PAREN W_ERROR(0x36dc)
#define WERR_SXS_XML_E_EXPECTINGCLOSEQUOTE W_ERROR(0x36dd)
#define WERR_SXS_XML_E_MULTIPLE_COLONS W_ERROR(0x36de)
#define WERR_SXS_XML_E_INVALID_DECIMAL W_ERROR(0x36df)
#define WERR_SXS_XML_E_INVALID_HEXIDECIMAL W_ERROR(0x36e0)
#define WERR_SXS_XML_E_INVALID_UNICODE W_ERROR(0x36e1)
#define WERR_SXS_XML_E_WHITESPACEORQUESTIONMARK W_ERROR(0x36e2)
#define WERR_SXS_XML_E_UNEXPECTEDENDTAG W_ERROR(0x36e3)
#define WERR_SXS_XML_E_UNCLOSEDTAG W_ERROR(0x36e4)
#define WERR_SXS_XML_E_DUPLICATEATTRIBUTE W_ERROR(0x36e5)
#define WERR_SXS_XML_E_MULTIPLEROOTS W_ERROR(0x36e6)
#define WERR_SXS_XML_E_INVALIDATROOTLEVEL W_ERROR(0x36e7)
#define WERR_SXS_XML_E_BADXMLDECL W_ERROR(0x36e8)
#define WERR_SXS_XML_E_MISSINGROOT W_ERROR(0x36e9)
#define WERR_SXS_XML_E_UNEXPECTEDEOF W_ERROR(0x36ea)
#define WERR_SXS_XML_E_BADPEREFINSUBSET W_ERROR(0x36eb)
#define WERR_SXS_XML_E_UNCLOSEDSTARTTAG W_ERROR(0x36ec)
#define WERR_SXS_XML_E_UNCLOSEDENDTAG W_ERROR(0x36ed)
#define WERR_SXS_XML_E_UNCLOSEDSTRING W_ERROR(0x36ee)
#define WERR_SXS_XML_E_UNCLOSEDCOMMENT W_ERROR(0x36ef)
#define WERR_SXS_XML_E_UNCLOSEDDECL W_ERROR(0x36f0)
#define WERR_SXS_XML_E_UNCLOSEDCDATA W_ERROR(0x36f1)
#define WERR_SXS_XML_E_RESERVEDNAMESPACE W_ERROR(0x36f2)
#define WERR_SXS_XML_E_INVALIDENCODING W_ERROR(0x36f3)
#define WERR_SXS_XML_E_INVALIDSWITCH W_ERROR(0x36f4)
#define WERR_SXS_XML_E_BADXMLCASE W_ERROR(0x36f5)
#define WERR_SXS_XML_E_INVALID_STANDALONE W_ERROR(0x36f6)
#define WERR_SXS_XML_E_UNEXPECTED_STANDALONE W_ERROR(0x36f7)
#define WERR_SXS_XML_E_INVALID_VERSION W_ERROR(0x36f8)
#define WERR_SXS_XML_E_MISSINGEQUALS W_ERROR(0x36f9)
#define WERR_SXS_PROTECTION_RECOVERY_FAILED W_ERROR(0x36fa)
#define WERR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT W_ERROR(0x36fb)
#define WERR_SXS_PROTECTION_CATALOG_NOT_VALID W_ERROR(0x36fc)
#define WERR_SXS_UNTRANSLATABLE_HRESULT W_ERROR(0x36fd)
#define WERR_SXS_PROTECTION_CATALOG_FILE_MISSING W_ERROR(0x36fe)
#define WERR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE W_ERROR(0x36ff)
#define WERR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME W_ERROR(0x3700)
#define WERR_SXS_ASSEMBLY_MISSING W_ERROR(0x3701)
#define WERR_SXS_CORRUPT_ACTIVATION_STACK W_ERROR(0x3702)
#define WERR_SXS_CORRUPTION W_ERROR(0x3703)
#define WERR_SXS_EARLY_DEACTIVATION W_ERROR(0x3704)
#define WERR_SXS_INVALID_DEACTIVATION W_ERROR(0x3705)
#define WERR_SXS_MULTIPLE_DEACTIVATION W_ERROR(0x3706)
#define WERR_SXS_PROCESS_TERMINATION_REQUESTED W_ERROR(0x3707)
#define WERR_SXS_RELEASE_ACTIVATION_ONTEXT W_ERROR(0x3708)
#define WERR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY W_ERROR(0x3709)
#define WERR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE W_ERROR(0x370a)
#define WERR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME W_ERROR(0x370b)
#define WERR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE W_ERROR(0x370c)
#define WERR_SXS_IDENTITY_PARSE_ERROR W_ERROR(0x370d)
#define WERR_MALFORMED_SUBSTITUTION_STRING W_ERROR(0x370e)
#define WERR_SXS_INCORRECT_PUBLIC_KEY_OKEN W_ERROR(0x370f)
#define WERR_UNMAPPED_SUBSTITUTION_STRING W_ERROR(0x3710)
#define WERR_SXS_ASSEMBLY_NOT_LOCKED W_ERROR(0x3711)
#define WERR_SXS_COMPONENT_STORE_CORRUPT W_ERROR(0x3712)
#define WERR_ADVANCED_INSTALLER_FAILED W_ERROR(0x3713)
#define WERR_XML_ENCODING_MISMATCH W_ERROR(0x3714)
#define WERR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT W_ERROR(0x3715)
#define WERR_SXS_IDENTITIES_DIFFERENT W_ERROR(0x3716)
#define WERR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT W_ERROR(0x3717)
#define WERR_SXS_FILE_NOT_PART_OF_ASSEMBLY W_ERROR(0x3718)
#define WERR_SXS_MANIFEST_TOO_BIG W_ERROR(0x3719)
#define WERR_SXS_SETTING_NOT_REGISTERED W_ERROR(0x371a)
#define WERR_SXS_TRANSACTION_CLOSURE_INCOMPLETE W_ERROR(0x371b)
#define WERR_EVT_INVALID_CHANNEL_PATH W_ERROR(0x3a98)
#define WERR_EVT_INVALID_QUERY W_ERROR(0x3a99)
#define WERR_EVT_PUBLISHER_METADATA_NOT_FOUND W_ERROR(0x3a9a)
#define WERR_EVT_EVENT_TEMPLATE_NOT_FOUND W_ERROR(0x3a9b)
#define WERR_EVT_INVALID_PUBLISHER_NAME W_ERROR(0x3a9c)
#define WERR_EVT_INVALID_EVENT_DATA W_ERROR(0x3a9d)
#define WERR_EVT_CHANNEL_NOT_FOUND W_ERROR(0x3a9f)
#define WERR_EVT_MALFORMED_XML_TEXT W_ERROR(0x3aa0)
#define WERR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL W_ERROR(0x3aa1)
#define WERR_EVT_CONFIGURATION_ERROR W_ERROR(0x3aa2)
#define WERR_EVT_QUERY_RESULT_STALE W_ERROR(0x3aa3)
#define WERR_EVT_QUERY_RESULT_INVALID_POSITION W_ERROR(0x3aa4)
#define WERR_EVT_NON_VALIDATING_MSXML W_ERROR(0x3aa5)
#define WERR_EVT_FILTER_ALREADYSCOPED W_ERROR(0x3aa6)
#define WERR_EVT_FILTER_NOTELTSET W_ERROR(0x3aa7)
#define WERR_EVT_FILTER_INVARG W_ERROR(0x3aa8)
#define WERR_EVT_FILTER_INVTEST W_ERROR(0x3aa9)
#define WERR_EVT_FILTER_INVTYPE W_ERROR(0x3aaa)
#define WERR_EVT_FILTER_PARSEERR W_ERROR(0x3aab)
#define WERR_EVT_FILTER_UNSUPPORTEDOP W_ERROR(0x3aac)
#define WERR_EVT_FILTER_UNEXPECTEDTOKEN W_ERROR(0x3aad)
#define WERR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL W_ERROR(0x3aae)
#define WERR_EVT_INVALID_CHANNEL_PROPERTY_VALUE W_ERROR(0x3aaf)
#define WERR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE W_ERROR(0x3ab0)
#define WERR_EVT_CHANNEL_CANNOT_ACTIVATE W_ERROR(0x3ab1)
#define WERR_EVT_FILTER_TOO_COMPLEX W_ERROR(0x3ab2)
#define WERR_EVT_MESSAGE_NOT_FOUND W_ERROR(0x3ab3)
#define WERR_EVT_MESSAGE_ID_NOT_FOUND W_ERROR(0x3ab4)
#define WERR_EVT_UNRESOLVED_VALUE_INSERT W_ERROR(0x3ab5)
#define WERR_EVT_UNRESOLVED_PARAMETER_INSERT W_ERROR(0x3ab6)
#define WERR_EVT_MAX_INSERTS_REACHED W_ERROR(0x3ab7)
#define WERR_EVT_EVENT_DEFINITION_NOT_OUND W_ERROR(0x3ab8)
#define WERR_EVT_MESSAGE_LOCALE_NOT_FOUND W_ERROR(0x3ab9)
#define WERR_EVT_VERSION_TOO_OLD W_ERROR(0x3aba)
#define WERR_EVT_VERSION_TOO_NEW W_ERROR(0x3abb)
#define WERR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY W_ERROR(0x3abc)
#define WERR_EVT_PUBLISHER_DISABLED W_ERROR(0x3abd)
#define WERR_EC_SUBSCRIPTION_CANNOT_ACTIVATE W_ERROR(0x3ae8)
#define WERR_EC_LOG_DISABLED W_ERROR(0x3ae9)
#define WERR_MUI_FILE_NOT_FOUND W_ERROR(0x3afc)
#define WERR_MUI_INVALID_FILE W_ERROR(0x3afd)
#define WERR_MUI_INVALID_RC_CONFIG W_ERROR(0x3afe)
#define WERR_MUI_INVALID_LOCALE_NAME W_ERROR(0x3aff)
#define WERR_MUI_INVALID_ULTIMATEFALLBACK_NAME W_ERROR(0x3b00)
#define WERR_MUI_FILE_NOT_LOADED W_ERROR(0x3b01)
#define WERR_RESOURCE_ENUM_USER_STOP W_ERROR(0x3b02)
#define WERR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED W_ERROR(0x3b03)
#define WERR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME W_ERROR(0x3b04)
#define WERR_MCA_INVALID_CAPABILITIES_STRING W_ERROR(0x3b60)
#define WERR_MCA_INVALID_VCP_VERSION W_ERROR(0x3b61)
#define WERR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION W_ERROR(0x3b62)
#define WERR_MCA_MCCS_VERSION_MISMATCH W_ERROR(0x3b63)
#define WERR_MCA_UNSUPPORTED_MCCS_VERSION W_ERROR(0x3b64)
#define WERR_MCA_INTERNAL_ERROR W_ERROR(0x3b65)
#define WERR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED W_ERROR(0x3b66)
#define WERR_MCA_UNSUPPORTED_COLOR_TEMPERATURE W_ERROR(0x3b67)
#define WERR_AMBIGUOUS_SYSTEM_DEVICE W_ERROR(0x3b92)
#define WERR_SYSTEM_DEVICE_NOT_FOUND W_ERROR(0x3bc3)

#endif /* _WERR_GEN_H */
